@@ -29,12 +29,36 @@ class DokuHTTPClient extends HTTPClient {
         $this->HTTPClient();
 
         // set some values from the config
-        $this->proxy_host = $conf['proxy']['host'];
-        $this->proxy_port = $conf['proxy']['port'];
-        $this->proxy_user = $conf['proxy']['user'];
-        $this->proxy_pass = conf_decodeString($conf['proxy']['pass']);
-        $this->proxy_ssl  = $conf['proxy']['ssl'];
+        $this->proxy_host   = $conf['proxy']['host'];
+        $this->proxy_port   = $conf['proxy']['port'];
+        $this->proxy_user   = $conf['proxy']['user'];
+        $this->proxy_pass   = conf_decodeString($conf['proxy']['pass']);
+        $this->proxy_ssl    = $conf['proxy']['ssl'];
+        $this->proxy_except = $conf['proxy']['except'];
     }
+
+
+    /**
+     * Wraps an event around the parent function
+     *
+     * @triggers HTTPCLIENT_REQUEST_SEND
+     * @author   Andreas Gohr <andi@splitbrain.org>
+     */
+    function sendRequest($url,$data='',$method='GET'){
+        $httpdata = array('url'    => $url,
+                          'data'   => $data,
+                          'method' => $method);
+        $evt = new Doku_Event('HTTPCLIENT_REQUEST_SEND',$httpdata);
+        if($evt->advise_before()){
+            $url    = $httpdata['url'];
+            $data   = $httpdata['data'];
+            $method = $httpdata['method'];
+        }
+        $evt->advise_after();
+        unset($evt);
+        return parent::sendRequest($url,$data,$method);
+    }
+
 }
 
 /**
@@ -47,6 +71,7 @@ class DokuHTTPClient extends HTTPClient {
  * @link   http://www.splitbrain.org/go/videodb
  * @author Andreas Goetz <cpuidle@gmx.de>
  * @author Andreas Gohr <andi@splitbrain.org>
+ * @author Tobias Sarnowski <sarnowski@new-thoughts.org>
  */
 class HTTPClient {
     //set these if you like
@@ -62,13 +87,14 @@ class HTTPClient {
     var $headers;
     var $debug;
     var $start = 0; // for timings
+    var $keep_alive = true; // keep alive rocks
 
     // don't set these, read on error
     var $error;
     var $redirect_count;
 
     // read these after a successful request
-    var $resp_status;
+    var $status;
     var $resp_body;
     var $resp_headers;
 
@@ -82,6 +108,13 @@ class HTTPClient {
     var $proxy_user;
     var $proxy_pass;
     var $proxy_ssl; //boolean set to true if your proxy needs SSL
+    var $proxy_except; // regexp of URLs to exclude from proxy
+
+    // list of kept alive connections
+    static $connections = array();
+
+    // what we use as boundary on multipart/form-data posts
+    var $boundary = '---DokuWikiHTTPClient--4523452351';
 
     /**
      * Constructor.
@@ -124,6 +157,29 @@ class HTTPClient {
         return $this->resp_body;
     }
 
+    /**
+     * Simple function to do a GET request with given parameters
+     *
+     * Returns the wanted page or false on an error.
+     *
+     * This is a convenience wrapper around get(). The given parameters
+     * will be correctly encoded and added to the given base URL.
+     *
+     * @param  string $url       The URL to fetch
+     * @param  array  $data      Associative array of parameters
+     * @param  bool   $sloppy304 Return body on 304 not modified
+     * @author Andreas Gohr <andi@splitbrain.org>
+     */
+    function dget($url,$data,$sloppy304=false){
+        if(strpos($url,'?')){
+            $url .= '&';
+        }else{
+            $url .= '?';
+        }
+        $url .= $this->_postEncode($data);
+        return $this->get($url,$sloppy304);
+    }
+
     /**
      * Simple function to do a POST request
      *
@@ -158,18 +214,25 @@ class HTTPClient {
         $this->error  = '';
         $this->status = 0;
 
+        // don't accept gzip if truncated bodies might occur
+        if($this->max_bodysize &&
+           !$this->max_bodysize_abort &&
+           $this->headers['Accept-encoding'] == 'gzip'){
+            unset($this->headers['Accept-encoding']);
+        }
+
         // parse URL into bits
         $uri = parse_url($url);
         $server = $uri['host'];
         $path   = $uri['path'];
         if(empty($path)) $path = '/';
         if(!empty($uri['query'])) $path .= '?'.$uri['query'];
-        $port = $uri['port'];
-        if($uri['user']) $this->user = $uri['user'];
-        if($uri['pass']) $this->pass = $uri['pass'];
+        if(isset($uri['port']) && !empty($uri['port'])) $port = $uri['port'];
+        if(isset($uri['user'])) $this->user = $uri['user'];
+        if(isset($uri['pass'])) $this->pass = $uri['pass'];
 
         // proxy setup
-        if($this->proxy_host){
+        if($this->proxy_host && (!$this->proxy_except || !preg_match('/'.$this->proxy_except.'/i',$url)) ){
             $request_url = $url;
             $server      = $this->proxy_host;
             $port        = $this->proxy_port;
@@ -177,7 +240,7 @@ class HTTPClient {
         }else{
             $request_url = $path;
             $server      = $server;
-            if (empty($port)) $port = ($uri['scheme'] == 'https') ? 443 : 80;
+            if (!isset($port)) $port = ($uri['scheme'] == 'https') ? 443 : 80;
         }
 
         // add SSL stream prefix if needed - needs SSL support in PHP
@@ -186,13 +249,23 @@ class HTTPClient {
         // prepare headers
         $headers               = $this->headers;
         $headers['Host']       = $uri['host'];
+        if($uri['port']) $headers['Host'].= ':'.$uri['port'];
         $headers['User-Agent'] = $this->agent;
         $headers['Referer']    = $this->referer;
-        $headers['Connection'] = 'Close';
+        if ($this->keep_alive) {
+            $headers['Connection'] = 'Keep-Alive';
+        } else {
+            $headers['Connection'] = 'Close';
+        }
         if($method == 'POST'){
             if(is_array($data)){
-                $headers['Content-Type']   = 'application/x-www-form-urlencoded';
-                $data = $this->_postEncode($data);
+                if($headers['Content-Type'] == 'multipart/form-data'){
+                    $headers['Content-Type']   = 'multipart/form-data; boundary='.$this->boundary;
+                    $data = $this->_postMultipartEncode($data);
+                }else{
+                    $headers['Content-Type']   = 'application/x-www-form-urlencoded';
+                    $data = $this->_postEncode($data);
+                }
             }
             $headers['Content-Length'] = strlen($data);
             $rmethod = 'POST';
@@ -209,15 +282,34 @@ class HTTPClient {
         // stop time
         $start = time();
 
-        // open socket
-        $socket = @fsockopen($server,$port,$errno, $errstr, $this->timeout);
-        if (!$socket){
-            $resp->status = '-100';
-            $this->error = "Could not connect to $server:$port\n$errstr ($errno)";
-            return false;
+        // already connected?
+        $connectionId = $this->_uniqueConnectionId($server,$port);
+        $this->_debug('connection pool', $this->connections);
+        $socket = null;
+        if (isset($this->connections[$connectionId])) {
+            $this->_debug('reusing connection', $connectionId);
+            $socket = $this->connections[$connectionId];
         }
-        //set non blocking
-        stream_set_blocking($socket,0);
+        if (is_null($socket) || feof($socket)) {
+            $this->_debug('opening connection', $connectionId);
+            // open socket
+            $socket = @fsockopen($server,$port,$errno, $errstr, $this->timeout);
+            if (!$socket){
+                $this->status = -100;
+                $this->error = "Could not connect to $server:$port\n$errstr ($errno)";
+                return false;
+            }
+
+            // keep alive?
+            if ($this->keep_alive) {
+                $this->connections[$connectionId] = $socket;
+            } else {
+                unset($this->connections[$connectionId]);
+            }
+        }
+
+        //set blocking
+        stream_set_blocking($socket,1);
 
         // build request
         $request  = "$method $request_url HTTP/".$this->http.HTTP_NL;
@@ -228,19 +320,42 @@ class HTTPClient {
 
         $this->_debug('request',$request);
 
+        // select parameters
+        $sel_r = null;
+        $sel_w = array($socket);
+        $sel_e = null;
+
         // send request
         $towrite = strlen($request);
         $written = 0;
         while($written < $towrite){
-            $ret = fwrite($socket, substr($request,$written));
+            // check timeout
+            if(time()-$start > $this->timeout){
+                $this->status = -100;
+                $this->error = sprintf('Timeout while sending request (%.3fs)',$this->_time() - $this->start);
+                unset($this->connections[$connectionId]);
+                return false;
+            }
+
+            // wait for stream ready or timeout (1sec)
+            if(@stream_select($sel_r,$sel_w,$sel_e,1) === false){
+                usleep(1000);
+                continue;
+            }
+
+            // write to stream
+            $ret = fwrite($socket, substr($request,$written,4096));
             if($ret === false){
                 $this->status = -100;
                 $this->error = 'Failed writing to socket';
+                unset($this->connections[$connectionId]);
                 return false;
             }
             $written += $ret;
         }
 
+        // continue non-blocking
+        stream_set_blocking($socket,0);
 
         // read headers from socket
         $r_headers = '';
@@ -248,12 +363,15 @@ class HTTPClient {
             if(time()-$start > $this->timeout){
                 $this->status = -100;
                 $this->error = sprintf('Timeout while reading headers (%.3fs)',$this->_time() - $this->start);
+                unset($this->connections[$connectionId]);
                 return false;
             }
             if(feof($socket)){
                 $this->error = 'Premature End of File (socket)';
+                unset($this->connections[$connectionId]);
                 return false;
             }
+            usleep(1000);
             $r_headers .= fgets($socket,1024);
         }while(!preg_match('/\r?\n\r?\n$/',$r_headers));
 
@@ -264,6 +382,7 @@ class HTTPClient {
             if($match[1] > $this->max_bodysize){
                 $this->error = 'Reported content length exceeds allowed response size';
                 if ($this->max_bodysize_abort)
+                    unset($this->connections[$connectionId]);
                     return false;
             }
         }
@@ -271,6 +390,7 @@ class HTTPClient {
         // get Status
         if (!preg_match('/^HTTP\/(\d\.\d)\s*(\d+).*?\n/', $r_headers, $m)) {
             $this->error = 'Server returned bad answer';
+            unset($this->connections[$connectionId]);
             return false;
         }
         $this->status = $m[2];
@@ -278,9 +398,17 @@ class HTTPClient {
         // handle headers and cookies
         $this->resp_headers = $this->_parseHeaders($r_headers);
         if(isset($this->resp_headers['set-cookie'])){
-            foreach ((array) $this->resp_headers['set-cookie'] as $c){
-                list($key, $value, $foo) = split('=', $cookie);
-                $this->cookies[$key] = $value;
+            foreach ((array) $this->resp_headers['set-cookie'] as $cookie){
+                list($cookie)   = explode(';',$cookie,2);
+                list($key,$val) = explode('=',$cookie,2);
+                $key = trim($key);
+                if($val == 'deleted'){
+                    if(isset($this->cookies[$key])){
+                        unset($this->cookies[$key]);
+                    }
+                }elseif($key){
+                    $this->cookies[$key] = $val;
+                }
             }
         }
 
@@ -288,6 +416,11 @@ class HTTPClient {
 
         // check server status code to follow redirect
         if($this->status == 301 || $this->status == 302 ){
+            // close the connection because we don't handle content retrieval here
+            // that's the easiest way to clean up the connection
+            fclose($socket);
+            unset($this->connections[$connectionId]);
+
             if (empty($this->resp_headers['location'])){
                 $this->error = 'Redirect but no Location Header found';
                 return false;
@@ -297,9 +430,15 @@ class HTTPClient {
             }else{
                 $this->redirect_count++;
                 $this->referer = $url;
+                // handle non-RFC-compliant relative redirects
                 if (!preg_match('/^http/i', $this->resp_headers['location'])){
-                    $this->resp_headers['location'] = $uri['scheme'].'://'.$uri['host'].
-                                                      $this->resp_headers['location'];
+                    if($this->resp_headers['location'][0] != '/'){
+                        $this->resp_headers['location'] = $uri['scheme'].'://'.$uri['host'].':'.$uri['port'].
+                                                          dirname($uri['path']).'/'.$this->resp_headers['location'];
+                    }else{
+                        $this->resp_headers['location'] = $uri['scheme'].'://'.$uri['host'].':'.$uri['port'].
+                                                          $this->resp_headers['location'];
+                    }
                 }
                 // perform redirected request, always via GET (required by RFC)
                 return $this->sendRequest($this->resp_headers['location'],array(),'GET');
@@ -309,22 +448,25 @@ class HTTPClient {
         // check if headers are as expected
         if($this->header_regexp && !preg_match($this->header_regexp,$r_headers)){
             $this->error = 'The received headers did not match the given regexp';
+            unset($this->connections[$connectionId]);
             return false;
         }
 
         //read body (with chunked encoding if needed)
         $r_body    = '';
-        if(preg_match('/transfer\-(en)?coding:\s*chunked\r\n/i',$r_header)){
+        if(preg_match('/transfer\-(en)?coding:\s*chunked\r\n/i',$r_headers)){
             do {
                 unset($chunk_size);
                 do {
                     if(feof($socket)){
                         $this->error = 'Premature End of File (socket)';
+                        unset($this->connections[$connectionId]);
                         return false;
                     }
                     if(time()-$start > $this->timeout){
                         $this->status = -100;
                         $this->error = sprintf('Timeout while reading chunk (%.3fs)',$this->_time() - $this->start);
+                        unset($this->connections[$connectionId]);
                         return false;
                     }
                     $byte = fread($socket,1);
@@ -341,10 +483,12 @@ class HTTPClient {
 
                 if($this->max_bodysize && strlen($r_body) > $this->max_bodysize){
                     $this->error = 'Allowed response size exceeded';
-                    if ($this->max_bodysize_abort)
+                    if ($this->max_bodysize_abort){
+                        unset($this->connections[$connectionId]);
                         return false;
-                    else
+                    } else {
                         break;
+                    }
                 }
             } while ($chunk_size);
         }else{
@@ -353,18 +497,22 @@ class HTTPClient {
                 if(time()-$start > $this->timeout){
                     $this->status = -100;
                     $this->error = sprintf('Timeout while reading response (%.3fs)',$this->_time() - $this->start);
+                    unset($this->connections[$connectionId]);
                     return false;
                 }
                 $r_body .= fread($socket,4096);
                 $r_size = strlen($r_body);
                 if($this->max_bodysize && $r_size > $this->max_bodysize){
                     $this->error = 'Allowed response size exceeded';
-                    if ($this->max_bodysize_abort)
+                    if ($this->max_bodysize_abort) {
+                        unset($this->connections[$connectionId]);
                         return false;
-                    else
+                    } else {
                         break;
+                    }
                 }
-                if($this->resp_headers['content-length'] && !$this->resp_headers['transfer-encoding'] &&
+                if(isset($this->resp_headers['content-length']) &&
+                   !isset($this->resp_headers['transfer-encoding']) &&
                    $this->resp_headers['content-length'] == $r_size){
                     // we read the content-length, finish here
                     break;
@@ -372,13 +520,23 @@ class HTTPClient {
             }
         }
 
-        // close socket
-        $status = socket_get_status($socket);
-        fclose($socket);
+        if (!$this->keep_alive ||
+                (isset($this->resp_headers['connection']) && $this->resp_headers['connection'] == 'Close')) {
+            // close socket
+            $status = socket_get_status($socket);
+            fclose($socket);
+            unset($this->connections[$connectionId]);
+        }
 
         // decode gzip if needed
-        if($this->resp_headers['content-encoding'] == 'gzip'){
-            $this->resp_body = gzinflate(substr($r_body, 10));
+        if(isset($this->resp_headers['content-encoding']) &&
+           $this->resp_headers['content-encoding'] == 'gzip' &&
+           strlen($r_body) > 10 && substr($r_body,0,3)=="\x1f\x8b\x08"){
+            $this->resp_body = @gzinflate(substr($r_body, 10));
+            if($this->resp_body === false){
+                $this->error = 'Failed to decompress gzip encoded content';
+                $this->resp_body = $r_body;
+            }
         }else{
             $this->resp_body = $r_body;
         }
@@ -422,12 +580,13 @@ class HTTPClient {
      */
     function _parseHeaders($string){
         $headers = array();
-        $lines = explode("\n",$string);
-        foreach($lines as $line){
-            list($key,$val) = explode(':',$line,2);
-            $key = strtolower(trim($key));
-            $val = trim($val);
-            if(empty($val)) continue;
+        if (!preg_match_all('/^\s*([\w-]+)\s*:\s*([\S \t]+)\s*$/m', $string,
+                            $matches, PREG_SET_ORDER)) {
+            return $headers;
+        }
+        foreach($matches as $match){
+            list(, $key, $val) = $match;
+            $key = strtolower($key);
             if(isset($headers[$key])){
                 if(is_array($headers[$key])){
                     $headers[$key][] = $val;
@@ -461,28 +620,67 @@ class HTTPClient {
      * @author Andreas Goetz <cpuidle@gmx.de>
      */
     function _getCookies(){
+        $headers = '';
         foreach ($this->cookies as $key => $val){
-            if ($headers) $headers .= '; ';
-            $headers .= $key.'='.$val;
+            $headers .= "$key=$val; ";
         }
-
-        if ($headers) $headers = "Cookie: $headers".HTTP_NL;
+        $headers = substr($headers, 0, -2);
+        if ($headers !== '') $headers = "Cookie: $headers".HTTP_NL;
         return $headers;
     }
 
     /**
      * Encode data for posting
      *
-     * @todo handle mixed encoding for file upoads
      * @author Andreas Gohr <andi@splitbrain.org>
      */
     function _postEncode($data){
+        $url = '';
         foreach($data as $key => $val){
             if($url) $url .= '&';
             $url .= urlencode($key).'='.urlencode($val);
         }
         return $url;
     }
+
+    /**
+     * Encode data for posting using multipart encoding
+     *
+     * @fixme use of urlencode might be wrong here
+     * @author Andreas Gohr <andi@splitbrain.org>
+     */
+    function _postMultipartEncode($data){
+        $boundary = '--'.$this->boundary;
+        $out = '';
+        foreach($data as $key => $val){
+            $out .= $boundary.HTTP_NL;
+            if(!is_array($val)){
+                $out .= 'Content-Disposition: form-data; name="'.urlencode($key).'"'.HTTP_NL;
+                $out .= HTTP_NL; // end of headers
+                $out .= $val;
+                $out .= HTTP_NL;
+            }else{
+                $out .= 'Content-Disposition: form-data; name="'.urlencode($key).'"';
+                if($val['filename']) $out .= '; filename="'.urlencode($val['filename']).'"';
+                $out .= HTTP_NL;
+                if($val['mimetype']) $out .= 'Content-Type: '.$val['mimetype'].HTTP_NL;
+                $out .= HTTP_NL; // end of headers
+                $out .= $val['body'];
+                $out .= HTTP_NL;
+            }
+        }
+        $out .= "$boundary--".HTTP_NL;
+        return $out;
+    }
+
+    /**
+     * Generates a unique identifier for a connection.
+     *
+     * @return string unique identifier
+     */
+    function _uniqueConnectionId($server, $port) {
+        return "$server:$port";
+    }
 }
 
-//Setup VIM: ex: et ts=4 enc=utf-8 :
+//Setup VIM: ex: et ts=4 :
