@@ -4,7 +4,7 @@
  * ----------
  * Author: Jason Dagit (dagit@codersbase.com) based on ocaml.php by Flaie (fireflaie@gmail.com)
  * Copyright: (c) 2005 Flaie, Nigel McNie (http://qbnz.com/highlighter)
- * Release Version: 1\.0\.8
+ * Release Version: 1.0.8.8
  * Date Started: 2005/08/27
  *
  * Haskell language file for GeSHi.
@@ -41,7 +41,10 @@ $language_data = array (
     'LANG_NAME' => 'Haskell',
     'COMMENT_SINGLE' => array( 1 => '--'),
     'COMMENT_MULTI' => array('{-' => '-}'),
-    'COMMENT_REGEXP' => array(2 => "/-->/"),
+    'COMMENT_REGEXP' => array(
+        2 => "/-->/",
+        3 => "/{-(?:(?R)|.)-}/s", //Nested Comments
+        ),
     'CASE_KEYWORDS' => 0,
     'QUOTEMARKS' => array('"'),
     'ESCAPE_CHAR' => "\\",
@@ -146,7 +149,8 @@ $language_data = array (
         'COMMENTS' => array(
             1 => 'color: #5d478b; font-style: italic;',
             2 => 'color: #339933; font-weight: bold;',
-            'MULTI' => 'color: #5d478b; font-style: italic;' /* light purpHle */
+            3 => 'color: #5d478b; font-style: italic;', /* light purple */
+            'MULTI' => 'color: #5d478b; font-style: italic;' /* light purple */
             ),
         'ESCAPE_CHAR' => array(
             0 => 'background-color: #3cb371; font-weight: bold;'
@@ -195,4 +199,4 @@ $language_data = array (
         )
 );
 
-?>
+?>
\ No newline at end of file
