@@ -9,6 +9,7 @@
  * @author Felipe Castro <fefcas@gmail.com>
  * @author Robert Bogenschneider <robog@gmx.de>
  * @author Erik Pedersen <erik.pedersen@shaw.ca>
+ * @author Robert BOGENSCHNEIDER <bogi@UEA.org>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -50,7 +51,9 @@ $lang['btn_recover']           = 'Restarigi skizon';
 $lang['btn_draftdel']          = 'Forigi skizon';
 $lang['btn_revert']            = 'Restarigi';
 $lang['btn_register']          = 'Registriĝi';
-$lang['loggedinas']            = 'Ensalutita kiel';
+$lang['btn_apply']             = 'Apliki';
+$lang['btn_media']             = 'Medio-administrilo';
+$lang['loggedinas']            = 'Ensalutinta kiel';
 $lang['user']                  = 'Uzant-nomo';
 $lang['pass']                  = 'Pasvorto';
 $lang['newpass']               = 'Nova pasvorto';
@@ -63,16 +66,16 @@ $lang['profile']               = 'Uzanto-profilo';
 $lang['badlogin']              = 'Pardonu, uzant-nomo aŭ pasvorto estis erara.';
 $lang['minoredit']             = 'Etaj modifoj';
 $lang['draftdate']             = 'Lasta konservo de la skizo:';
-$lang['nosecedit']             = 'La paĝo ŝanĝiĝis intertempe, sekcio-informo estis malĝisdata, ni ŝargas la tutan paĝon anstataŭe.';
+$lang['nosecedit']             = 'La paĝo ŝanĝiĝis intertempe, sekcio-informo estis malĝisdata, tial la tuta paĝo estas reŝargita.';
 $lang['regmissing']            = 'Pardonu, vi devas plenigi ĉiujn kampojn.';
-$lang['reguexists']            = 'Pardonu, ĉi tiu uzanto-nomo jam estas okupita.';
+$lang['reguexists']            = 'Pardonu, ĉi tiu uzanto-nomo jam ekzistas.';
 $lang['regsuccess']            = 'La uzanto estas kreita kaj la pasvorto estis elsendita per retpoŝto.';
 $lang['regsuccess2']           = 'La uzanto estas kreita.';
 $lang['regmailfail']           = 'Ŝajne okazis eraro dum elsendo de la pasvorto. Bonvolu informi administranton pri tio!';
 $lang['regbadmail']            = 'Entajpita retpoŝta adreso ne ŝajnas valida. Se vi pensas, ke tio estas eraro, kontaktu la administranton.';
 $lang['regbadpass']            = 'La du pasvortoj ne samas, bonvolu provi refoje.';
 $lang['regpwmail']             = 'Via DokuWiki-pasvorto';
-$lang['reghere']               = 'Se vi ne havas konton, do vi povas akiri ĝin';
+$lang['reghere']               = 'Se vi ne havas konton, vi povas akiri ĝin';
 $lang['profna']                = 'Tiu ĉi vikio ne ebligas modifon en la profiloj.';
 $lang['profnochange']          = 'Neniu ŝanĝo, nenio farinda.';
 $lang['profnoempty']           = 'Malplena nomo aŭ retadreso ne estas permesataj.';
@@ -94,7 +97,7 @@ $lang['txt_filename']          = 'Alŝuti kiel (laŭvole)';
 $lang['txt_overwrt']           = 'Anstataŭigi ekzistantan dosieron';
 $lang['lockedby']              = 'Nune ŝlosita de';
 $lang['lockexpire']            = 'Ŝlosado ĉesos en';
-$lang['willexpire']            = 'Vi povos redakti ĉi tiun paĝon post unu minuto.\nSe vi volas nuligi tempkontrolon de la ŝlosado, do premu butonon "Antaŭrigardi".';
+$lang['js']['willexpire']      = 'Vi povos redakti ĉi tiun paĝon post unu minuto.\nSe vi volas nuligi tempkontrolon de la ŝlosado, do premu butonon "Antaŭrigardi".';
 $lang['js']['notsavedyet']     = 'Ne konservitaj modifoj perdiĝos.
 Ĉu vi certe volas daŭrigi la procezon?';
 $lang['js']['searchmedia']     = 'Serĉi dosierojn';
@@ -121,12 +124,21 @@ $lang['js']['medialeft']       = 'Meti la bildon maldekstren.';
 $lang['js']['mediaright']      = 'Meti la bildon dekstren.';
 $lang['js']['mediacenter']     = 'Meti la bildon mezen.';
 $lang['js']['medianoalign']    = 'Ne uzi poziciigon.';
-$lang['js']['nosmblinks']      = 'Tio ĉi nur funkcias en la Vindozaĉa "Microsoft Internet Explorer".
-Vi ankoraŭ povas kopii kaj almeti la ligilon.';
+$lang['js']['nosmblinks']      = 'Tio ĉi nur funkcias en la Vindozaĉa "Microsoft Internet Explorer".\nVi ankoraŭ povas kopii kaj almeti la ligilon.';
 $lang['js']['linkwiz']         = 'Ligil-Asistanto';
 $lang['js']['linkto']          = 'Ligilo al:';
 $lang['js']['del_confirm']     = 'Ĉu vere forigi elektitajn ero(j)n?';
-$lang['js']['mu_btn']          = 'Alŝuti plurajn dosierojn multope.';
+$lang['js']['restore_confirm'] = 'Ĉu vere restarigi ĉi tiun version?';
+$lang['js']['media_diff']      = 'Rigardu la diferencojn:';
+$lang['js']['media_diff_both'] = 'Flankon apud flanko';
+$lang['js']['media_diff_opacity'] = 'Unu super la alia';
+$lang['js']['media_diff_portions'] = 'Ŝovilo';
+$lang['js']['media_select']    = 'Elektu dosierojn...';
+$lang['js']['media_upload_btn'] = 'Alŝuto';
+$lang['js']['media_done_btn']  = 'Finita';
+$lang['js']['media_drop']      = 'Demetu ĉi-tien por alŝuti';
+$lang['js']['media_cancel']    = 'forigi';
+$lang['js']['media_overwrt']   = 'Anstataûi ekzistantajn dosierojn';
 $lang['rssfailed']             = 'Okazis eraro dum ricevado de la novaĵ-fluo: ';
 $lang['nothingfound']          = 'Ankoraŭ nenio troviĝas tie ĉi.';
 $lang['mediaselect']           = 'Elekto de aŭdvidaĵa dosiero';
@@ -153,11 +165,11 @@ $lang['mediaextchange']        = 'La dosiersufikso ŝanĝis de .%s al .%s!';
 $lang['reference']             = 'Referencoj por';
 $lang['ref_inuse']             = 'La dosiero ne povas esti forigita, ĉar ĝi ankoraŭ estas uzata de la jenaj paĝoj:';
 $lang['ref_hidden']            = 'Kelkaj referencoj estas en paĝoj, kiujn vi ne rajtas legi';
-$lang['hits']                  = 'Kongruoj';
-$lang['quickhits']             = 'Kongruoj trovitaj en paĝnomoj';
+$lang['hits']                  = 'Trafoj';
+$lang['quickhits']             = 'Trafoj trovitaj en paĝnomoj';
 $lang['toc']                   = 'Enhavtabelo';
 $lang['current']               = 'aktuala';
-$lang['yours']                 = 'Via Versio';
+$lang['yours']                 = 'Via versio';
 $lang['diff']                  = 'Montri diferencojn el la aktuala versio';
 $lang['diff2']                 = 'Montri diferencojn inter la elektitaj revizioj';
 $lang['difflink']              = 'Ligilo al kompara rigardo';
@@ -181,6 +193,10 @@ $lang['mail_changed']          = 'paĝo modifita:';
 $lang['mail_subscribe_list']   = 'ŝanĝitaj paĝoj en nomspaco:';
 $lang['mail_new_user']         = 'Nova uzanto:';
 $lang['mail_upload']           = 'dosiero alŝutita:';
+$lang['changes_type']          = 'Rigardi ŝanĝojn de';
+$lang['pages_changes']         = 'Paĝoj';
+$lang['media_changes']         = 'Mediaj dosieroj';
+$lang['both_changes']          = 'Ambaû - paĝojn kaj mediajn dosierojn';
 $lang['qb_bold']               = 'Dika teksto';
 $lang['qb_italic']             = 'Dekliva teksto';
 $lang['qb_underl']             = 'Substrekita teksto';
@@ -221,6 +237,9 @@ $lang['img_copyr']             = 'Kopirajtoj';
 $lang['img_format']            = 'Formato';
 $lang['img_camera']            = 'Kamerao';
 $lang['img_keywords']          = 'Ŝlosilvortoj';
+$lang['img_width']             = 'Larĝeco';
+$lang['img_height']            = 'Alteco';
+$lang['img_manager']           = 'Rigardi en media-administrilo';
 $lang['subscr_subscribe_success'] = 'Aldonis %s al la abonlisto por %s';
 $lang['subscr_subscribe_error'] = 'Eraro dum aldono de %s al la abonlisto por %s';
 $lang['subscr_subscribe_noaddress'] = 'Ne estas adreso ligita al via ensaluto, ne eblas aldoni vin al la abonlisto';
@@ -235,8 +254,8 @@ $lang['subscr_m_unsubscribe']  = 'Malaboni';
 $lang['subscr_m_subscribe']    = 'Aboni';
 $lang['subscr_m_receive']      = 'Ricevi';
 $lang['subscr_style_every']    = 'retpoŝtaĵo pro ĉiu ŝanĝo';
-$lang['subscr_style_digest']   = 'kolekta retpoŝtaĵo de ŝanĝoj por ĉiu paĝo';
-$lang['subscr_style_list']     = 'listo de ŝanĝitaj paĝoj ekde la lasta retpoŝtaĵo';
+$lang['subscr_style_digest']   = 'resuma retpoŝtaĵo de ŝanĝoj por ĉiu paĝo (je %.2f tagoj)';
+$lang['subscr_style_list']     = 'listo de ŝanĝitaj paĝoj ekde la lasta retpoŝtaĵo (je %.2f tagoj)';
 $lang['authmodfailed']         = 'Malbona agordo por identigi la uzanton. Bonvolu informi la administranton de la vikio.';
 $lang['authtempfail']          = 'La identigo de via uzantonomo estas intertempe maldisponebla. Se tiu ĉi situacio daŭros, bonvolu informi la adminstranton de la vikio.';
 $lang['i_chooselang']          = 'Elektu vian lingvon';
@@ -245,38 +264,23 @@ $lang['i_wikiname']            = 'Nomo de la vikio';
 $lang['i_enableacl']           = 'Ebligi "ACL" (alirkontrolo, rekomendinde)';
 $lang['i_superuser']           = 'Superuzanto';
 $lang['i_problems']            = 'La instalilo trovis kelkajn problemojn, indikitaj sube. Vi ne povas pluiri ĝis ili estos iel korektitaj.';
-$lang['i_modified']            = 'Pro sekureco tiu ĉi instalilo nur funkcias por nova kaj nemodifita Dokuwiki-pakaĵo.
+$lang['i_modified']            = 'Pro sekureco tiu ĉi instalilo nur funkcias por nova kaj nemodifita DokuWiki-pakaĵo.
 Vi devas aŭ redemeti la dosierojn el la elŝutita pakaĵo aŭ plibone informiĝi pri la instalada procezo.';
 $lang['i_funcna']              = 'La PHP-a funkcio <code>%s</code> ne estas uzebla. Eble via retprovizanto ial malpermesis tion?';
 $lang['i_phpver']              = 'La versio de la PHP <code>%s</code> estas pli malnova ol la bezonata <code>%s</code>. Vi bezonas ĝisdatigi la PHP-an instalon.';
 $lang['i_permfail']            = '<code>%s</code> ne estas skribebla por DokuWiki. Vi devas redifini la permes-atributojn de tiu ĉi dosierujo!';
 $lang['i_confexists']          = '<code>%s</code> jam ekzistas';
-$lang['i_writeerr']            = 'Ne eblas krei "<code>%s</code>"-on. Vi bezonas kontroli la permesojn de la dosier(uj)oj kaj mem krej la dosieron.';
+$lang['i_writeerr']            = 'Ne eblas krei "<code>%s</code>". Vi bezonas kontroli la permesojn de la dosier(uj)oj kaj mem krej la dosieron.';
 $lang['i_badhash']             = 'dokuwiki.php ne estas rekonebla aŭ ĝi estas modifita (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - malvalida aŭ malplena valoro';
 $lang['i_success']             = 'La agordado estas sukcese kompletita. Vi povas forigi la dosieron nun. Pluiru al <a href="doku.php">via nova DokuWiki</a>.';
 $lang['i_failure']             = 'Kelkaj eraroj okazis dum la konservo de la agordaj dosieroj. Vi devas senpere korekti ilin antaŭ ol vi povos uzi <a href="doku.php">vian novan DokuWiki-on</a>.                       ';
-$lang['i_policy']              = 'Apriora ACL-a agordo';
+$lang['i_policy']              = 'Komenca ACL-a agordo';
 $lang['i_pol0']                = 'Malferma Vikio (legi, skribi, alŝuti povas ĉiuj)';
 $lang['i_pol1']                = 'Publika Vikio (legi povas ĉiuj, skribi kaj alŝuti povas registritaj uzantoj)';
 $lang['i_pol2']                = 'Ferma Vikio (legi, skribi, alŝuti nur povas registritaj uzantoj)';
 $lang['i_retry']               = 'Reprovi';
 $lang['i_license']             = 'Bonvolu elekti la permesilon, sub kiun vi volas meti vian enhavon:';
-$lang['mu_intro']              = 'Ĉi tie vi povas alŝuti plurajn dosierojn multope. Klaku la esplor-butonon por aldoni ilin al la vico. Premu alŝuti kiam prete.';
-$lang['mu_gridname']           = 'Dosiernomo';
-$lang['mu_gridsize']           = 'Grandeco';
-$lang['mu_gridstat']           = 'Stato';
-$lang['mu_namespace']          = 'Nomspaco';
-$lang['mu_browse']             = 'Esplori';
-$lang['mu_toobig']             = 'tro granda';
-$lang['mu_ready']              = 'preta por alŝuti';
-$lang['mu_done']               = 'plenumite';
-$lang['mu_fail']               = 'malsukcesinte';
-$lang['mu_authfail']           = 'sekcio tro longdaŭris';
-$lang['mu_progress']           = '@PCT@% alŝutite';
-$lang['mu_filetypes']          = 'Permesitaj dosiertipoj';
-$lang['mu_info']               = 'alŝutitaj dosieroj.';
-$lang['mu_lasterr']            = 'Lasta eraro:';
 $lang['recent_global']         = 'Vi nun rigardas la ŝanĝojn ene de la nomspaco <b>%s</b>. Vi povas ankaŭ <a href="%s">vidi la freŝajn ŝanĝojn de la tuta vikio</a>.';
 $lang['years']                 = 'antaŭ %d jaroj';
 $lang['months']                = 'antaŭ %d monatoj';
@@ -286,3 +290,27 @@ $lang['hours']                 = 'antaŭ %d horoj';
 $lang['minutes']               = 'antaŭ %d minutoj';
 $lang['seconds']               = 'antaŭ %d sekundoj';
 $lang['wordblock']             = 'Via ŝanĝo ne estis savita, ĉar ĝi enhavas blokitan tekston (spamon).';
+$lang['media_uploadtab']       = 'Alŝuto';
+$lang['media_searchtab']       = 'Serĉo';
+$lang['media_file']            = 'Dosiero';
+$lang['media_viewtab']         = 'Rigardi';
+$lang['media_edittab']         = 'Modifi';
+$lang['media_historytab']      = 'Historio';
+$lang['media_list_thumbs']     = 'Bildeto';
+$lang['media_list_rows']       = 'Kolumnoj';
+$lang['media_sort_name']       = 'per nomo';
+$lang['media_sort_date']       = 'per dato';
+$lang['media_namespaces']      = 'Elektu nomspacon';
+$lang['media_files']           = 'Dosieroj en %s';
+$lang['media_upload']          = 'Alŝuti al la nomspaco <strong>%s</strong>.';
+$lang['media_search']          = 'Serĉi en la nomspaco <strong>%s</strong>.';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s ĉe %s';
+$lang['media_edit']            = 'Modifi %s';
+$lang['media_history']         = 'Protokolo de %s';
+$lang['media_meta_edited']     = 'metadatumoj ŝanĝitaj';
+$lang['media_perm_read']       = 'Bedaûrinde viaj rajtoj ne sufiĉas por legi dosierojn.';
+$lang['media_perm_upload']     = 'Bedaûrinde viaj rajtoj ne sufiĉas por alŝuti dosierojn.';
+$lang['media_update']          = 'Alŝuti novan version';
+$lang['media_restore']         = 'Restarigi ĉi tiun version';
+$lang['plugin_install_err']    = 'Kromaĵo instalita malĝuste. Renomu la kromaĵan dosierujon \'%s\' al \'%s\'.';
