@@ -10,8 +10,8 @@
  * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesFa.php?view=co
  * @author behrad eslamifar <behrad_es@yahoo.com)
  * @author Mohsen Firoozmandan <info@mambolearn.com>
- * @author omidmr@gmail.com
  * @author Omid Mottaghi <omidmr@gmail.com>
+ * @author Mohammad Reza Shoaei <shoaei@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'rtl';
@@ -45,15 +45,14 @@ $lang['btn_back']              = 'عقب';
 $lang['btn_backlink']          = 'پیوندهای به این صفحه';
 $lang['btn_backtomedia']       = 'بازگشت به انتخاب فایل';
 $lang['btn_subscribe']         = 'عضویت در تغییرات صفحه';
-$lang['btn_unsubscribe']       = 'لغو عضویت در تغییرات صفحه';
-$lang['btn_subscribens']       = 'عضویت در تغییرات فضای‌نام';
-$lang['btn_unsubscribens']     = 'عضویت در تغییرات فضای‌نام';
 $lang['btn_profile']           = 'به روز رسانی پروفایل';
 $lang['btn_reset']             = 'بازنشاندن';
 $lang['btn_resendpwd']         = 'یک گذرواژه‌ی جدید برای شما فرستاده شود';
 $lang['btn_draft']             = 'ویرایش پیش‌نویس';
 $lang['btn_recover']           = 'بازیابی پیش‌نویس';
 $lang['btn_draftdel']          = 'حذف پیش‌نویس';
+$lang['btn_revert']            = 'بازیابی';
+$lang['btn_register']          = 'یک حساب جدید بسازید';
 $lang['loggedinas']            = 'به عنوان کاربر روبرو وارد شده‌اید:';
 $lang['user']                  = 'نام کاربری:';
 $lang['pass']                  = 'گذرواژه‌ی شما';
@@ -63,7 +62,6 @@ $lang['passchk']               = 'گذرواژه را دوباره وارد کن
 $lang['remember']              = 'گذرواژه را به یاد بسپار.';
 $lang['fullname']              = '*نام واقعی شما';
 $lang['email']                 = 'ایمیل شما*';
-$lang['register']              = 'یک حساب جدید بسازید';
 $lang['profile']               = 'پروفایل کاربر';
 $lang['badlogin']              = 'خطا در ورود به سیستم';
 $lang['minoredit']             = 'این ویرایش خُرد است';
@@ -92,13 +90,45 @@ $lang['resendpwdconfirm']      = 'یک ایمیل تاییدیه‌ی آدرس 
 $lang['resendpwdsuccess']      = 'گذرواژه‌ی جدید شما توسط ایمیل ارسال شد';
 $lang['license']               = 'به جز مواردی که ذکر می‌شود، مابقی محتویات ویکی تحت مجوز زیر می‌باشند:';
 $lang['licenseok']             = 'توجه: با ویرایش این صفحه، شما مجوز زیر را تایید می‌کنید:';
+$lang['searchmedia']           = 'نام فایل برای جستجو:';
+$lang['searchmedia_in']        = 'جستجو در %s';
 $lang['txt_upload']            = 'فایل را برای ارسال انتخاب کنید';
 $lang['txt_filename']          = 'ارسال به صورت (اختیاری)';
 $lang['txt_overwrt']           = 'بر روی فایل موجود بنویس';
 $lang['lockedby']              = 'در حال حاضر قفل شده است';
 $lang['lockexpire']            = 'قفل منقضی شده است';
-$lang['willexpire']            = 'حالت قفل شما مدتی است منقضی شده است \n برای جلوگیری از تداخل دکمه‌ی پیش‌نمایش را برای صفر شدن ساعت قفل بزنید.';
-$lang['notsavedyet']           = 'تغییرات ذخیره شده از بین خواهد رفت. \n می‌خواهید ادامه دهید؟';
+$lang['js']['willexpire']            = 'حالت قفل شما مدتی است منقضی شده است \n برای جلوگیری از تداخل دکمه‌ی پیش‌نمایش را برای صفر شدن ساعت قفل بزنید.';
+$lang['js']['notsavedyet']     = 'تغییرات ذخیره شده از بین خواهد رفت.
+ می‌خواهید ادامه دهید؟';
+$lang['js']['searchmedia']     = 'جستجو برای فایل';
+$lang['js']['keepopen']        = 'پنجره را ر زمان انتخاب باز نگه‌دار';
+$lang['js']['hidedetails']     = 'پتهان کردن جزییات';
+$lang['js']['mediatitle']      = 'تنظیمات پیوند';
+$lang['js']['mediadisplay']    = 'نوع پیوند';
+$lang['js']['mediaalign']      = 'هم‌ترازی';
+$lang['js']['mediasize']       = 'اندازه تصویر';
+$lang['js']['mediatarget']     = 'هدف پیوند';
+$lang['js']['mediaclose']      = 'بستن';
+$lang['js']['mediainsert']     = 'درج کردن';
+$lang['js']['mediadisplayimg'] = 'نمایش تصویر';
+$lang['js']['mediadisplaylnk'] = 'فقط پیوند را نمایش بده.';
+$lang['js']['mediasmall']      = 'نگارش کوچک';
+$lang['js']['mediamedium']     = 'نگارش متوسط';
+$lang['js']['medialarge']      = 'نگارش بزرگ';
+$lang['js']['mediaoriginal']   = 'نگارش اصلی';
+$lang['js']['medialnk']        = 'پیوند به صفحه‌ی جزییات';
+$lang['js']['mediadirect']     = 'پیوند مستقیم به اصلی';
+$lang['js']['medianolnk']      = 'بدون پیوند';
+$lang['js']['medianolink']     = 'تصویر را پیوند نکن';
+$lang['js']['medialeft']       = 'تصویر را با چپ هم‌تراز کن.';
+$lang['js']['mediaright']      = 'تصویر را با راست هم‌تراز کن.';
+$lang['js']['mediacenter']     = 'تصویر را با وسط هم‌تراز کن.';
+$lang['js']['medianoalign']    = 'هم‌تراز نکن.';
+$lang['js']['nosmblinks']      = 'پیوند به Windows share فقط در اینترنت‌اکسپلورر قابل استفاده است.
+شما می‌توانید پیوند‌ها رو کپی کنید.';
+$lang['js']['linkwiz']         = 'ویزارد پیوند';
+$lang['js']['linkto']          = 'پیوند به:';
+$lang['js']['del_confirm']     = 'واقعن تصمیم به حذف این موارد دارید؟';
 $lang['rssfailed']             = 'بروز خطا در هنگام واکشی';
 $lang['nothingfound']          = 'چیزی پیدا نشد';
 $lang['mediaselect']           = 'فایل‌ها';
@@ -116,11 +146,7 @@ $lang['deletefail']            = '«%s» حذف نمی‌شود، دسترسی
 $lang['mediainuse']            = 'فایل «%s» حذف نمی‌شود، چون هنوز در حال استفاده است.';
 $lang['namespaces']            = 'فضای‌نام';
 $lang['mediafiles']            = 'فایل‌های موجود در';
-$lang['js']['keepopen']        = 'پنجره را ر زمان انتخاب باز نگه‌دار';
-$lang['js']['hidedetails']     = 'پتهان کردن جزییات';
-$lang['js']['nosmblinks']      = 'پیوند به Windows share فقط در اینترنت‌اکسپلورر قابل استفاده است.
-شما می‌توانید پیوند‌ها رو کپی کنید.';
-$lang['js']['mu_btn']          = 'ارسال هم‌زمان چندین فایل ';
+$lang['accessdenied']          = 'شما اجازه‌ی مشاهده‌ی این صفحه را ندارید.';
 $lang['mediausage']            = 'برای ارجاع دادن به فایل از نگارش زیر استفاده کنید.';
 $lang['mediaview']             = 'مشاهده‌ی فایل اصلی';
 $lang['mediaroot']             = 'ریشه';
@@ -136,6 +162,10 @@ $lang['current']               = 'فعلی';
 $lang['yours']                 = 'نسخه‌ی شما';
 $lang['diff']                  = 'تفاوت‌ها را با نگارش کنونی نمایش بده.';
 $lang['diff2']                 = 'تفاوت‌ها را با نگارش انتخابی نمایش بده.';
+$lang['difflink']              = 'پیوند به صفحه‌ی تفاوت‌ها';
+$lang['diff_type']             = 'مشاهده تغییرات:';
+$lang['diff_inline']           = 'خطی';
+$lang['diff_side']             = 'کلی';
 $lang['line']                  = 'خط';
 $lang['breadcrumb']            = 'ردپا';
 $lang['youarehere']            = 'محل شما';
@@ -147,11 +177,12 @@ $lang['restored']              = 'یک نگارش پیشین واگردانی ش
 $lang['external_edit']         = 'ویرایش خارجی';
 $lang['summary']               = 'پیش‌نمایش';
 $lang['noflash']               = 'برای نمایش محتویات <a href="http://www.adobe.com/products/flashplayer/">افزونه‌ی فلش</a> مورد نیاز است.';
+$lang['download']              = 'دیافت فایل منقطع گردید';
 $lang['mail_newpage']          = 'صفحه اضافه شد:';
 $lang['mail_changed']          = 'صفحه تغییر داده شد:';
+$lang['mail_subscribe_list']   = 'صفحات تغییر داده شده در فضای‌نام';
 $lang['mail_new_user']         = 'کاربر جدید:';
 $lang['mail_upload']           = 'فایل ارسال شده:';
-$lang['qb_alert']              = 'خواهشمندیم متنی را که می‌خواهید در قالب مناسب در بیاورید را وارد کنید.\nاین متن به آخر مطلب اضافه خواهد شد.';
 $lang['qb_bold']               = 'متن پُررنگ';
 $lang['qb_italic']             = 'متن ایتالیک';
 $lang['qb_underl']             = 'متن زیرخط‌دار';
@@ -162,6 +193,11 @@ $lang['qb_h2']                 = 'عنوان سطح ۲';
 $lang['qb_h3']                 = 'عنوان سطح ۳';
 $lang['qb_h4']                 = 'عنوان سطح ۴';
 $lang['qb_h5']                 = 'عنوان سطح ۵';
+$lang['qb_h']                  = 'تیتر';
+$lang['qb_hs']                 = 'تیتر مورد نظر را انتخاب نمایید';
+$lang['qb_hplus']              = 'تیتر بالاتر';
+$lang['qb_hminus']             = 'تیتر پایین تر';
+$lang['qb_hequal']             = 'تیتر در یک سطح';
 $lang['qb_link']               = 'پیوند داخلی';
 $lang['qb_extlink']            = 'پیوند به بیرون (پیشوند http:// را فراموش نکنید)';
 $lang['qb_hr']                 = 'خط افقی';
@@ -171,7 +207,7 @@ $lang['qb_media']              = 'افزودن تصویر و فایل';
 $lang['qb_sig']                = 'افزودن امضا';
 $lang['qb_smileys']            = 'شکلک';
 $lang['qb_chars']              = 'حروف ویژه';
-$lang['del_confirm']           = 'واقعن تصمیم به حذف این موارد دارید؟';
+$lang['upperns']               = 'پرش به فضای‌نام بالا';
 $lang['admin_register']        = 'یک حساب جدید بسازید';
 $lang['metaedit']              = 'ویرایش داده‌های متا';
 $lang['metasaveerr']           = 'نوشتن داده‌نما با مشکل مواجه شد';
@@ -187,11 +223,22 @@ $lang['img_copyr']             = 'دارنده‌ی حق تکثیر';
 $lang['img_format']            = 'فرمت';
 $lang['img_camera']            = 'دوربین';
 $lang['img_keywords']          = 'واژه‌های کلیدی';
-$lang['subscribe_success']     = '%s با موفقیت به عضویت %s درآمد';
-$lang['subscribe_error']       = 'عضویت %s در %s با مشکل مواجه شد';
-$lang['subscribe_noaddress']   = 'هیچ آدرس ایمیلی ثبت نکرده‌اید و نمی‌توانید عضو شوید';
-$lang['unsubscribe_success']   = '%s با موفقیت از عضویت %s خارج شد';
-$lang['unsubscribe_error']     = 'خارج کردن %s از عضویت %s با مشکل مواجه شد.';
+$lang['subscr_subscribe_success'] = '%s به لیست آبونه %s افزوده شد';
+$lang['subscr_subscribe_error'] = 'اشکال در افزودن %s به لیست آبونه %s';
+$lang['subscr_subscribe_noaddress'] = 'هیچ آدرسی برای این عضویت اضافه نشده است، شما نمی‌توانید به لیست آبونه اضافه شوید';
+$lang['subscr_unsubscribe_success'] = '%s از لیست آبونه %s پاک شد';
+$lang['subscr_unsubscribe_error'] = 'اشکال در پاک کردن %s از لیست آبونه %s';
+$lang['subscr_already_subscribed'] = '%s پیش‌تر در %s آبونه شده است';
+$lang['subscr_not_subscribed'] = '%s در %s آبونه نشده است';
+$lang['subscr_m_not_subscribed'] = 'شما در این صفحه یا فضای‌نام آبونه نشده‌اید';
+$lang['subscr_m_new_header']   = 'افزودن آبونه';
+$lang['subscr_m_current_header'] = 'آبونه‌های کنونی';
+$lang['subscr_m_unsubscribe']  = 'لغو آبونه';
+$lang['subscr_m_subscribe']    = 'آبونه شدن';
+$lang['subscr_m_receive']      = 'دریافت کردن';
+$lang['subscr_style_every']    = 'ارسال رای‌نامه در تمامی تغییرات';
+$lang['subscr_style_digest']   = 'ارسال ایمیل‌های فشرده برای تغییرات هر صفحه';
+$lang['subscr_style_list']     = 'لیست صفحات تغییر داده شده از آخرین رای‌نامه';
 $lang['authmodfailed']         = 'اشکال در نوع معتبرسازی کاربران، مدیر ویکی را باخبر سازید.';
 $lang['authtempfail']          = 'معتبرسازی کابران موقتن مسدود می‌باشد. اگر این حالت پایدار بود، مدیر ویکی را باخبر سازید.';
 $lang['i_chooselang']          = 'انتخاب زبان';
@@ -215,17 +262,13 @@ $lang['i_pol0']                = 'ویکی باز (همه می‌توانند ب
 $lang['i_pol1']                = 'ویکی عمومی (همه می‌توانند بخوانند، کاربران ثبت شده می‌توانند بنویسند و فایل ارسال کنند)';
 $lang['i_pol2']                = 'ویکی بسته (فقط کاربران ثبت شده می‌توانند بخوانند، بنویسند و فایل ارسال کنند)';
 $lang['i_retry']               = 'تلاش مجدد';
-$lang['mu_intro']              = 'شما می‌توانید چندین فایل را با یک حرکت ارسال کنید. روی دکمه‌ی «بچر» کلیک کنید و فایل‌ها را به صف ارسال اضافه نمایید. سپس دکمه‌ی «ارسال» را فشار دهید. ';
-$lang['mu_gridname']           = 'نام فایل';
-$lang['mu_gridsize']           = 'اندازه';
-$lang['mu_gridstat']           = 'وضعیت';
-$lang['mu_namespace']          = 'فضای‌نام';
-$lang['mu_browse']             = 'بچر';
-$lang['mu_toobig']             = 'خیلی بزرگ';
-$lang['mu_ready']              = 'آماده‌ی ارسال';
-$lang['mu_done']               = 'کامل';
-$lang['mu_fail']               = 'شکست خورد';
-$lang['mu_authfail']           = 'سشن به پایان رسید';
-$lang['mu_progress']           = '@PCT@% ارسال شد';
-$lang['mu_filetypes']          = 'توسعه‌های مجاز';
+$lang['i_license']             = 'لطفن مجوز این محتوا را وارد کنید:';
 $lang['recent_global']         = 'شما هم‌اکنون تغییرات فضای‌نام <b>%s</b> را مشاهده می‌کنید. شما هم‌چنین می‌توانید <a href="%s">تغییرات اخیر در کل ویکی را مشاهده نمایید</a>.';
+$lang['years']                 = '%d سال پیش';
+$lang['months']                = '%d ماه پیش';
+$lang['weeks']                 = '%d هفته‌ی پیش';
+$lang['days']                  = '%d روز پیش';
+$lang['hours']                 = '%d ساعت پیش';
+$lang['minutes']               = '%d دقیقه‌ی پیش';
+$lang['seconds']               = '%d ثانیه‌ی پیش';
+$lang['wordblock']             = 'تغییرات شما به دلیل داشتن محتوای مشکوک (مثل اسپم) ذخیره نشد.';
