@@ -7,7 +7,7 @@
  * @author jk Lee
  * @author dongnak@gmail.com
  * @author Song Younghwan <purluno@gmail.com>
- * @author SONG Younghwan <purluno@gmail.com>
+ * @author Seung-Chul Yoo  <dryoo@live.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -41,15 +41,14 @@ $lang['btn_back']              = '뒤로';
 $lang['btn_backlink']          = '이전 링크';
 $lang['btn_backtomedia']       = '미디어 파일 선택으로 돌아가기';
 $lang['btn_subscribe']         = '구독 신청';
-$lang['btn_unsubscribe']       = '구독 신청 해지';
-$lang['btn_subscribens']       = '네임스페이스 구독 신청';
-$lang['btn_unsubscribens']     = '네임스페이스 구독 신청 해지';
 $lang['btn_profile']           = '개인정보 변경';
 $lang['btn_reset']             = '초기화';
 $lang['btn_resendpwd']         = '새 패스워드 보내기';
 $lang['btn_draft']             = '문서초안 편집';
 $lang['btn_recover']           = '문서초안 복구';
 $lang['btn_draftdel']          = '문서초안 삭제';
+$lang['btn_revert']            = '복원';
+$lang['btn_register']          = '등록';
 $lang['loggedinas']            = '다음 사용자로 로그인';
 $lang['user']                  = '사용자';
 $lang['pass']                  = '패스워드';
@@ -59,7 +58,6 @@ $lang['passchk']               = '패스워드 다시 확인';
 $lang['remember']              = '기억하기';
 $lang['fullname']              = '실제 이름';
 $lang['email']                 = '이메일';
-$lang['register']              = '등록';
 $lang['profile']               = '개인 정보';
 $lang['badlogin']              = '잘못된 사용자 이름이거나 패스워드입니다.';
 $lang['minoredit']             = '일부 내용 변경';
@@ -88,13 +86,45 @@ $lang['resendpwdconfirm']      = '확인 링크를 이메일로 보냈습니다.
 $lang['resendpwdsuccess']      = '새로운 패스워드는 이메일로 보내드립니다.';
 $lang['license']               = '이 위키의 내용은 다음의 라이센스에 따릅니다 :';
 $lang['licenseok']             = '주의 : 이 페이지를 수정한다는 다음의 라이센스에 동의함을 의미합니다 :';
+$lang['searchmedia']           = '파일이름 찾기:';
+$lang['searchmedia_in']        = ' %s에서 검색';
 $lang['txt_upload']            = '업로드 파일을 선택합니다.';
 $lang['txt_filename']          = '업로드 파일 이름을 입력합니다.(선택 사항)';
 $lang['txt_overwrt']           = '새로운 파일로 이전 파일을 교체합니다.';
 $lang['lockedby']              = '현재 잠금 사용자';
 $lang['lockexpire']            = '잠금 해제 시간';
-$lang['willexpire']            = '잠시 후 편집 잠금이 해제됩니다.\n편집 충돌을 피하려면 미리보기를 눌러 잠금 시간을 다시 설정하기 바랍니다.';
-$lang['notsavedyet']           = '저장하지 않은 변경은 지워집니다.\n계속하시겠습니까?';
+$lang['js']['willexpire']            = '잠시 후 편집 잠금이 해제됩니다.\n편집 충돌을 피하려면 미리보기를 눌러 잠금 시간을 다시 설정하기 바랍니다.';
+$lang['js']['notsavedyet']     = '저장하지 않은 변경은 지워집니다.
+계속하시겠습니까?';
+$lang['js']['searchmedia']     = '파일 찾기';
+$lang['js']['keepopen']        = '선택할 때 윈도우를 열어놓으시기 바랍니다.';
+$lang['js']['hidedetails']     = '자세한 정보 감추기';
+$lang['js']['mediatitle']      = '링크 설정';
+$lang['js']['mediadisplay']    = '링크 형태';
+$lang['js']['mediaalign']      = '배치';
+$lang['js']['mediasize']       = '그림 크기';
+$lang['js']['mediatarget']     = '링크 목표';
+$lang['js']['mediaclose']      = '닫기';
+$lang['js']['mediainsert']     = '삽입';
+$lang['js']['mediadisplayimg'] = '그림보기';
+$lang['js']['mediadisplaylnk'] = '링크만 보여줍니다.';
+$lang['js']['mediasmall']      = '작게';
+$lang['js']['mediamedium']     = '중간';
+$lang['js']['medialarge']      = '크게';
+$lang['js']['mediaoriginal']   = '원본';
+$lang['js']['medialnk']        = '세부정보페이지로 링크';
+$lang['js']['mediadirect']     = '원본으로 직접 링크';
+$lang['js']['medianolnk']      = '링크 없슴';
+$lang['js']['medianolink']     = '그림을 링크하지 않음';
+$lang['js']['medialeft']       = '왼쪽 배치';
+$lang['js']['mediaright']      = '오른쪽 배치';
+$lang['js']['mediacenter']     = '중앙 배치';
+$lang['js']['medianoalign']    = '배치 없슴';
+$lang['js']['nosmblinks']      = '윈도우 공유 파일과의 연결은 MS 인터넷 익스플로러에서만 동작합니다.
+그러나 링크를 복사하거나 붙여넣기를 할 수 있습니다.';
+$lang['js']['linkwiz']         = '링크 마법사';
+$lang['js']['linkto']          = '다음으로 연결:';
+$lang['js']['del_confirm']     = '정말로 선택된 항목(들)을 삭제하시겠습니까?';
 $lang['rssfailed']             = 'feed 가져오기 실패: ';
 $lang['nothingfound']          = '아무 것도 없습니다.';
 $lang['mediaselect']           = '미디어 파일 선택';
@@ -112,11 +142,7 @@ $lang['deletefail']            = '"%s" 파일을 삭제할 수 없습니다. - 
 $lang['mediainuse']            = '"%s" 파일을 삭제할 수 없습니다. - 아직 사용 중입니다.';
 $lang['namespaces']            = '네임스페이스';
 $lang['mediafiles']            = '사용 가능한 파일 목록';
-$lang['js']['keepopen']        = '선택할 때 윈도우를 열어놓으시기 바랍니다.';
-$lang['js']['hidedetails']     = '자세한 정보 감추기';
-$lang['js']['nosmblinks']      = '윈도우 공유 파일과의 연결은 MS 인터넷 익스플로러에서만 동작합니다.
-그러나 링크를 복사하거나 붙여넣기를 할 수 있습니다.';
-$lang['js']['mu_btn']          = '여러 파일들을 한번에 업로드합니다.';
+$lang['accessdenied']          = '이 페이지를 볼 권한이 없습니다.';
 $lang['mediausage']            = '이 파일을 참조하려면 다음 문법을 사용하기 바랍니다:';
 $lang['mediaview']             = '원본 파일 보기';
 $lang['mediaroot']             = '루트(root)';
@@ -132,6 +158,10 @@ $lang['current']               = '현재';
 $lang['yours']                 = '버전';
 $lang['diff']                  = '현재 버전과의 차이 보기';
 $lang['diff2']                 = '선택된 버전들 간 차이 보기';
+$lang['difflink']              = '차이 보기로 연결';
+$lang['diff_type']             = '버전간 차이 표시:';
+$lang['diff_inline']           = '인라인 방식';
+$lang['diff_side']             = '다중창 방식';
 $lang['line']                  = '줄';
 $lang['breadcrumb']            = '추적';
 $lang['youarehere']            = '현재 위치';
@@ -143,11 +173,12 @@ $lang['restored']              = '옛 버전 복구';
 $lang['external_edit']         = '외부 편집기';
 $lang['summary']               = '편집 요약';
 $lang['noflash']               = '이 컨텐츠를 표시하기 위해서 <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>이 필요합니다.';
+$lang['download']              = '조각 다운로드';
 $lang['mail_newpage']          = '페이지 추가:';
 $lang['mail_changed']          = '페이지 변경:';
+$lang['mail_subscribe_list']   = '네임스페이스에서 변경된 페이지:';
 $lang['mail_new_user']         = '새로운 사용자:';
 $lang['mail_upload']           = '파일 첨부:';
-$lang['qb_alert']              = '포맷하려는 텍스트를 선택하세요.\n문서 맨 끝에 추가됩니다.';
 $lang['qb_bold']               = '굵은 글';
 $lang['qb_italic']             = '이탤릭체 글';
 $lang['qb_underl']             = '밑줄 그어진 글';
@@ -158,6 +189,11 @@ $lang['qb_h2']                 = '2단계 헤드라인';
 $lang['qb_h3']                 = '3단계 헤드라인';
 $lang['qb_h4']                 = '4단계 헤드라인';
 $lang['qb_h5']                 = '5단계 헤드라인';
+$lang['qb_h']                  = '표제';
+$lang['qb_hs']                 = '표제 선택';
+$lang['qb_hplus']              = '상위 표제';
+$lang['qb_hminus']             = '하위 표제';
+$lang['qb_hequal']             = '동급 표제';
 $lang['qb_link']               = '내부 링크';
 $lang['qb_extlink']            = '외부 링크';
 $lang['qb_hr']                 = '수평선';
@@ -167,7 +203,7 @@ $lang['qb_media']              = '이미지와 기타 파일 추가';
 $lang['qb_sig']                = '서명 추가';
 $lang['qb_smileys']            = '이모티콘';
 $lang['qb_chars']              = '특수문자';
-$lang['del_confirm']           = '정말로 선택된 항목(들)을 삭제하시겠습니까?';
+$lang['upperns']               = '상위 네임스페이스로 이동';
 $lang['admin_register']        = '새로운 사용자 추가';
 $lang['metaedit']              = '메타 데이타를 편집합니다.';
 $lang['metasaveerr']           = '메타 데이타 쓰기가 실패했습니다.';
@@ -183,11 +219,22 @@ $lang['img_copyr']             = '저작권';
 $lang['img_format']            = '포맷';
 $lang['img_camera']            = '카메라';
 $lang['img_keywords']          = '키워드';
-$lang['subscribe_success']     = '%s를 추가했습니다. (%s의 구독 목록)';
-$lang['subscribe_error']       = '%s를 추가하는데 실패했습니다.(%s의 구독 목록)';
-$lang['subscribe_noaddress']   = '로그인 정보에 이메일 주소가 없습니다, 구독 목록에 추가할 수 없습니다.';
-$lang['unsubscribe_success']   = '%s를 제외시켰습니다. (%s의 구독 목록)';
-$lang['unsubscribe_error']     = '%s를 제외시키는데 실패했습니다.(%s의 구독 목록)';
+$lang['subscr_subscribe_success'] = '%s을(를) 구독목록 %s에 추가하였습니다';
+$lang['subscr_subscribe_error'] = '%s을(를) 구독목록 %s에 추가하는데 실패했습니다';
+$lang['subscr_subscribe_noaddress'] = '등록된 주소가 없기 때문에 구독목록에 등록되지 않았습니다';
+$lang['subscr_unsubscribe_success'] = '%s을(를) 구독목록 %s에서 제거하였습니다';
+$lang['subscr_unsubscribe_error'] = '%s을(를) 구독목록 %s에서 제거하는데 실패했습니다';
+$lang['subscr_already_subscribed'] = '%s은(는) 이미 %s에 구독되고 있습니다';
+$lang['subscr_not_subscribed'] = '%s은(는) 이미 %s에 구독되어 있지 않습니다';
+$lang['subscr_m_not_subscribed'] = '현재의 페이지나 네임스페이스에 구독등록이 되어있지 않습니다.';
+$lang['subscr_m_new_header']   = '구독 추가';
+$lang['subscr_m_current_header'] = '현재 구독중인 것들';
+$lang['subscr_m_unsubscribe']  = '구독 취소';
+$lang['subscr_m_subscribe']    = '구독';
+$lang['subscr_m_receive']      = '받기';
+$lang['subscr_style_every']    = '모든 변화를 이메일로 받기';
+$lang['subscr_style_digest']   = '각 페이지의 변화를 요약 (매 %.2f 일 마다)';
+$lang['subscr_style_list']     = '마지막 이메일 이후 변화된 페이지의 목록 (매 %.2f 일 마다)';
 $lang['authmodfailed']         = '잘못된 사용자 인증 설정입니다. 관리자에게 문의하기 바랍니다.';
 $lang['authtempfail']          = '사용자 인증이 일시적으로 불가능합니다. 만일 계속해서 문제가 발생하면 관리자에게 문의하기 바랍니다.';
 $lang['i_chooselang']          = '사용하는 언어를 선택합니다.';
@@ -214,17 +261,13 @@ $lang['i_pol0']                = '개방형 위키 (누구나 읽기/쓰기/업
 $lang['i_pol1']                = '공개형 위키 (누구나 읽을 수 있지만, 등록된 사용자만 쓰기/업로드가 가능합니다.)';
 $lang['i_pol2']                = '폐쇄형 위키 (등록된 사용자만 읽기/쓰기/업로드가 가능합니다.)';
 $lang['i_retry']               = '다시 시도';
-$lang['mu_intro']              = '여러 파일을 한번에 업로드할 수 있습니다. 파일 목록에 추가하려면 "찾기" 버튼을 클릭합니다. 파일 목록 추가 작업이 끝나면 "업로드" 버튼을 클릭하기 바랍니다. ';
-$lang['mu_gridname']           = '파일명';
-$lang['mu_gridsize']           = '크기';
-$lang['mu_gridstat']           = '상태';
-$lang['mu_namespace']          = '네임스페이스';
-$lang['mu_browse']             = '찾기';
-$lang['mu_toobig']             = '업로드 가능 크기를 초과했습니다.';
-$lang['mu_ready']              = '업로드가 가능합니다.';
-$lang['mu_done']               = '업로드가 완료되었습니다.';
-$lang['mu_fail']               = '업로드가 실패했습니다.';
-$lang['mu_authfail']           = '세션 기간이 종료되었습니다.';
-$lang['mu_progress']           = '@PCT@% 업로드되었습니다.';
-$lang['mu_filetypes']          = '허용된 파일타입';
+$lang['i_license']             = '내용의 배포를 위한 라이센스를 선택하세요.';
 $lang['recent_global']         = '<b>%s</b> 네임스페이스를 구독중입니다. <a href="%s">전체위키 변경사항 </a>도 보실수 있습니다.';
+$lang['years']                 = '%d 년 전';
+$lang['months']                = '%d 개월 전';
+$lang['weeks']                 = '%d 주 전';
+$lang['days']                  = '%d 일 전';
+$lang['hours']                 = '%d 시간 전';
+$lang['minutes']               = '%d 분 전';
+$lang['seconds']               = '%d 초 전';
+$lang['wordblock']             = '스팸 문구를 포함하고 있어서 저장되지 않았습니다.';
