@@ -37,15 +37,16 @@ $lang['btn_back']              = 'Atpakaļ';
 $lang['btn_backlink']          = 'Norādes uz lapu';
 $lang['btn_backtomedia']       = 'Atpakaļ uz mēdiju failu izvēli';
 $lang['btn_subscribe']         = 'Abonēt izmaiņu paziņojumus';
-$lang['btn_unsubscribe']       = 'Atteikties no izmaiņu paziņojumiem';
-$lang['btn_subscribens']       = 'Abonēt nodaļas izmaiņu paziņojumus';
-$lang['btn_unsubscribens']     = 'Atteikties no nodaļas izmaiņu paziņojumiem';
 $lang['btn_profile']           = 'Labot savu profilu';
 $lang['btn_reset']             = 'Atsaukt izmaiņas';
 $lang['btn_resendpwd']         = 'Nosūtīt jaunu paroli';
 $lang['btn_draft']             = 'Labot melnrakstu';
 $lang['btn_recover']           = 'Atjaunot melnrakstu';
 $lang['btn_draftdel']          = 'Dzēst melnrakstu';
+$lang['btn_revert']            = 'Atjaunot';
+$lang['btn_register']          = 'Reģistrēties';
+$lang['btn_apply']             = 'Labi';
+$lang['btn_media']             = 'Mēdiju pārvaldnieks';
 $lang['loggedinas']            = 'Pieteicies kā';
 $lang['user']                  = 'Lietotājvārds';
 $lang['pass']                  = 'Parole';
@@ -55,7 +56,6 @@ $lang['passchk']               = 'vēlreiz';
 $lang['remember']              = 'Atceries mani';
 $lang['fullname']              = 'Pilns vārds';
 $lang['email']                 = 'E-pasts';
-$lang['register']              = 'Reģistrēties';
 $lang['profile']               = 'Lietotāja vārds';
 $lang['badlogin']              = 'Atvaino, lietotājvārds vai parole aplama.';
 $lang['minoredit']             = 'Sīki labojumi';
@@ -67,7 +67,7 @@ $lang['regsuccess']            = 'Lietotājs izveidots. Parole nosūtīta pa pas
 $lang['regsuccess2']           = 'Lietotājs izveidots.';
 $lang['regmailfail']           = 'Šķiet, ka ir problēmas nosūtīt pastu. Lūdzu sazinies ar administratoru!';
 $lang['regbadmail']            = 'Uzdotā epasta adrese izskatās aplama. Ja tas nav tiesa, sazinies ar administratoru.';
-$lang['regbadpass']            = 'Abas ierakstītās paroles nav vienādas, lūduz atkārto.';
+$lang['regbadpass']            = 'Abas ierakstītās paroles nav vienādas, lūdzu atkārto.';
 $lang['regpwmail']             = 'Tava DokuWiki parole';
 $lang['reghere']               = 'Tev vēl nav sava konta? Izveido!';
 $lang['profna']                = 'Labot profilu nav iespējams';
@@ -75,7 +75,7 @@ $lang['profnochange']          = 'Izmaiņu nav. Nav, ko darīt.';
 $lang['profnoempty']           = 'Bez vārda vai e-pasta adreses nevar.';
 $lang['profchanged']           = 'Profils veiksmīgi izlabots.';
 $lang['pwdforget']             = 'Aizmirsi paroli? Saņem jaunu';
-$lang['resendna']              = 'Paroļu izsītīšanu nepiedāvāju.';
+$lang['resendna']              = 'Paroļu izsūtīšanu nepiedāvāju.';
 $lang['resendpwd']             = 'Nosūtīt jaunu paroli lietotājam';
 $lang['resendpwdmissing']      = 'Atvaino, jāizpilda visas ailes.';
 $lang['resendpwdnouser']       = 'Atvaino, tāda lietotāja nav.';
@@ -84,20 +84,61 @@ $lang['resendpwdconfirm']      = 'Apstiprināšanas adrese nosūtīta pa epastu.
 $lang['resendpwdsuccess']      = 'Jaunā parole nosūtīta pa e-pastu.';
 $lang['license']               = 'Ja nav norādīts citādi, viki saturs pieejams ar šādas licenzes  noteikumiem:';
 $lang['licenseok']             = 'Ievēro: Labojot lapu, tu piekrīti šādiem licenzes noteikumiem.';
+$lang['searchmedia']           = 'Meklētais faila vārds: ';
+$lang['searchmedia_in']        = 'Meklēt iekš %s';
 $lang['txt_upload']            = 'Norādi augšupielādējamo failu';
-$lang['txt_filename']          = 'Ievadi wikivārdu (nav obligāts)';
+$lang['txt_filename']          = 'Ievadi vikivārdu (nav obligāts)';
 $lang['txt_overwrt']           = 'Aizstāt esošo failu';
 $lang['lockedby']              = 'Patlaban bloķējis ';
 $lang['lockexpire']            = 'Bloķējums beigsies ';
-$lang['willexpire']            = 'Tavs bloķējums uz šo lapu pēc minūtes beigsies.\nLai izvairītos no konflikta, nospied Iepriekšapskata pogu\n un bloķējuma laiku sāks skaitīt no jauna.';
-$lang['notsavedyet']           = 'Veiktas bet nav saglabātas izmaiņas.\nVai tiešām tās nevajag?';
+$lang['js']['willexpire']      = 'Tavs bloķējums uz šo lapu pēc minūtes beigsies.\nLai izvairītos no konflikta, nospied Iepriekšapskata pogu\n un bloķējuma laiku sāks skaitīt no jauna.';
+$lang['js']['notsavedyet']     = 'Veiktas bet nav saglabātas izmaiņas.
+Vai tiešām tās nevajag?';
+$lang['js']['searchmedia']     = 'Meklēt failus';
+$lang['js']['keepopen']        = 'Pēc faila izvēles logu paturēt atvērtu';
+$lang['js']['hidedetails']     = 'Slēpt detaļas';
+$lang['js']['mediatitle']      = 'Saites īpašības';
+$lang['js']['mediadisplay']    = 'Saites tips';
+$lang['js']['mediaalign']      = 'Slēgums';
+$lang['js']['mediasize']       = 'Attēla izmērs';
+$lang['js']['mediatarget']     = 'Saite ved uz ';
+$lang['js']['mediaclose']      = 'Aizvērt';
+$lang['js']['mediainsert']     = 'Ievietot';
+$lang['js']['mediadisplayimg'] = 'Rādīt attēlu';
+$lang['js']['mediadisplaylnk'] = 'Rādīt tikai saiti';
+$lang['js']['mediasmall']      = 'Mazs';
+$lang['js']['mediamedium']     = 'Vidējs';
+$lang['js']['medialarge']      = 'Liels';
+$lang['js']['mediaoriginal']   = 'Oriģināls';
+$lang['js']['medialnk']        = 'Saite uz detaļām';
+$lang['js']['mediadirect']     = 'Tieša saite uz oriģinālu';
+$lang['js']['medianolnk']      = 'Bez saites';
+$lang['js']['medianolink']     = 'Bez saites uz attēlu';
+$lang['js']['medialeft']       = 'kreisais';
+$lang['js']['mediaright']      = 'labais';
+$lang['js']['mediacenter']     = 'centra';
+$lang['js']['medianoalign']    = 'neizlīdzināt';
+$lang['js']['nosmblinks']      = 'Saites uz Windows resursiem darbojas tikai Microsoft Internet Explorer.
+Protams, ka vari saiti kopēt un iespraust citā programmā.';
+$lang['js']['linkwiz']         = 'Saišu vednis';
+$lang['js']['linkto']          = 'Saite uz: ';
+$lang['js']['del_confirm']     = 'Dzēst šo šķirkli?';
+$lang['js']['restore_confirm'] = 'Tiešām atjaunot šo versiju';
+$lang['js']['media_diff']      = 'Skatīt atšķirību';
+$lang['js']['media_diff_both'] = 'Blakus';
+$lang['js']['media_diff_opacity'] = 'Pārklāti';
+$lang['js']['media_select']    = 'Norādīt failus...';
+$lang['js']['media_upload_btn'] = 'Augšuplādēt';
+$lang['js']['media_done_btn']  = 'Gatavs';
+$lang['js']['media_drop']      = 'Nomet te augšuplādējamos failus';
+$lang['js']['media_overwrt']   = 'Rakstīt pāri esošajiem failiem';
 $lang['rssfailed']             = 'Kļūda saņemot saturu no ';
 $lang['nothingfound']          = 'Nekas nav atrasts.';
 $lang['mediaselect']           = 'Mēdiju faila izvēle';
 $lang['fileupload']            = 'Mēdiju faila augšupielāde';
 $lang['uploadsucc']            = 'Veiksmīgi ielādēts';
 $lang['uploadfail']            = 'Ielādes kļūme. Varbūt aplamas tiesības?';
-$lang['uploadwrong']           = 'Ielāde aizliegta. Neatļauts faila palšinājums';
+$lang['uploadwrong']           = 'Ielāde aizliegta. Neatļauts faila paplašinājums';
 $lang['uploadexist']           = 'Neko nedarīju, jo fails jau ir.';
 $lang['uploadbadcontent']      = 'Augšupielādētā saturs neatbilst faila paplašinājumam %s.';
 $lang['uploadspam']            = 'Augšupielāde bloķēta ar melno sarakstu.';
@@ -108,11 +149,7 @@ $lang['deletefail']            = 'Nevar dzēst "%s". Pārbaudi tiesības.';
 $lang['mediainuse']            = 'Fails "%s" nav izdzēsts, to lieto.';
 $lang['namespaces']            = 'Nodaļas';
 $lang['mediafiles']            = 'Pieejamie faili';
-$lang['js']['keepopen']        = 'Pēc faila izvēles logu paturēt atvērtu';
-$lang['js']['hidedetails']     = 'Slēpt detaļas';
-$lang['js']['nosmblinks']      = 'Saites uz Windows resursiem darbojas tikai Microsoft Internet Explorer.
-Protams, ka vari saiti kopēt un iespraust citā programmā.';
-$lang['js']['mu_btn']          = 'Augšuplādēt uzreiz vairākus failus.';
+$lang['accessdenied']          = 'Šo lapu nav atļauts skatīt.';
 $lang['mediausage']            = 'Atsaucei uz failu lietot šādu sintaksi:';
 $lang['mediaview']             = 'Skatīt oriģinālo failu';
 $lang['mediaroot']             = 'sakne';
@@ -128,8 +165,12 @@ $lang['current']               = 'patlaban';
 $lang['yours']                 = 'Tava versija';
 $lang['diff']                  = 'atšķirības no patreizējas versijas';
 $lang['diff2']                 = 'norādīto versiju atšķirības';
+$lang['difflink']              = 'Saite uz salīdzināšanas skatu.';
+$lang['diff_type']             = 'Skatīt atšķirības:';
+$lang['diff_inline']           = 'Iekļauti';
+$lang['diff_side']             = 'Blakus';
 $lang['line']                  = 'Rinda';
-$lang['breadcrumb']            = 'Ceļš';
+$lang['breadcrumb']            = 'Apmeklēts';
 $lang['youarehere']            = 'Tu atrodies šeit';
 $lang['lastmod']               = 'Labota';
 $lang['by']                    = ', labojis';
@@ -139,11 +180,16 @@ $lang['restored']              = 'vecā versija atjaunota';
 $lang['external_edit']         = 'ārpussistēmas labojums';
 $lang['summary']               = 'Anotācija';
 $lang['noflash']               = 'Lai attēlotu lapas saturu, vajag <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
+$lang['download']              = 'Lejuplādēt «kodiņu»((snippet))';
 $lang['mail_newpage']          = 'lapa pievienota:';
 $lang['mail_changed']          = 'lapa mainīta:';
+$lang['mail_subscribe_list']   = 'Nodaļā mainītās lapas:';
 $lang['mail_new_user']         = 'Jauns lietotājs:';
 $lang['mail_upload']           = 'augšupielādētais fails:';
-$lang['qb_alert']              = 'Lūdzu ieraksti formatējamo teku.\nTo pievienos dokumenta galā.';
+$lang['changes_type']          = 'Skatīt izmaiņas';
+$lang['pages_changes']         = 'Lapās';
+$lang['media_changes']         = 'Mēdiju failos';
+$lang['both_changes']          = 'Gan lapās, gan mēdiju failos';
 $lang['qb_bold']               = 'Trekninājums';
 $lang['qb_italic']             = 'Kursīvs';
 $lang['qb_underl']             = 'Pasvītrojums';
@@ -154,6 +200,11 @@ $lang['qb_h2']                 = '2. līmeņa virsraksts';
 $lang['qb_h3']                 = '3. līmeņa virsraksts';
 $lang['qb_h4']                 = '4. līmeņa virsraksts';
 $lang['qb_h5']                 = '5. līmeņa virsraksts';
+$lang['qb_h']                  = 'Virsraksts';
+$lang['qb_hs']                 = 'Izraudzīties virsrakstu';
+$lang['qb_hplus']              = 'Lielāks virsraksts';
+$lang['qb_hminus']             = 'Mazāks virsraksts';
+$lang['qb_hequal']             = 'Tāds pats virsraksts';
 $lang['qb_link']               = 'Iekšēja saite';
 $lang['qb_extlink']            = 'Ārēja saite';
 $lang['qb_hr']                 = 'Horizontāla līnija';
@@ -163,7 +214,7 @@ $lang['qb_media']              = 'Pielikt attēlus un citus failus.';
 $lang['qb_sig']                = 'Ievietot parakstu';
 $lang['qb_smileys']            = 'Emotikoni';
 $lang['qb_chars']              = 'Īpašās zīmes';
-$lang['del_confirm']           = 'Dzēst šo šķirkli?';
+$lang['upperns']               = 'vienu nodaļu līmeni augstāk';
 $lang['admin_register']        = 'Pievienot jaunu lietotāju';
 $lang['metaedit']              = 'Labot metadatus';
 $lang['metasaveerr']           = 'Metadati nav saglabāti';
@@ -179,12 +230,26 @@ $lang['img_copyr']             = 'Autortiesības';
 $lang['img_format']            = 'Formāts';
 $lang['img_camera']            = 'Fotoaparāts';
 $lang['img_keywords']          = 'Atslēgvārdi';
-$lang['subscribe_success']     = '%s pievienots  %s abonentu sarakstam';
-$lang['subscribe_error']       = 'Kļūme pievienojot %s  %s abonentu sarakstam';
-$lang['subscribe_noaddress']   = 'Nav zināma adrese, ko pievienot abonentu sarakstam';
-$lang['unsubscribe_success']   = ' %s svītrots no %s abonentu saraksta';
-$lang['unsubscribe_error']     = 'Kļūme svītrojot %s  no %s abonentu saraksta';
-$lang['authmodfailed']         = 'Aplami konfigurēta lietotāju autentifikācija. Lūdzo ziņo Wiki administratoram.';
+$lang['img_width']             = 'Platums';
+$lang['img_height']            = 'Augstums';
+$lang['img_manager']           = 'Skatīt mēdiju pārvaldniekā';
+$lang['subscr_subscribe_success'] = '%s pievienots %s abonēšanas sarakstam';
+$lang['subscr_subscribe_error'] = 'Kļūme pievienojot %s %s abonēšanas sarakstam.';
+$lang['subscr_subscribe_noaddress'] = 'Nav zināma jūsu e-pasta adrese, tāpēc nevarat abonēt.';
+$lang['subscr_unsubscribe_success'] = '%s abonements uz %s atsaukts';
+$lang['subscr_unsubscribe_error'] = 'Kļūme svītrojot %s no %s abonēšanas saraksta';
+$lang['subscr_already_subscribed'] = '%s jau abonē %s';
+$lang['subscr_not_subscribed'] = '%s neabonē %s';
+$lang['subscr_m_not_subscribed'] = 'Šī lapa vai nodaļa nav abonēta';
+$lang['subscr_m_new_header']   = 'Pievienot abonementu';
+$lang['subscr_m_current_header'] = 'Patlaban ir abonēts';
+$lang['subscr_m_unsubscribe']  = 'Atteikties no abonēšanas';
+$lang['subscr_m_subscribe']    = 'Abonēt';
+$lang['subscr_m_receive']      = 'Saņemt';
+$lang['subscr_style_every']    = 'vēstuli par katru izmaiņu';
+$lang['subscr_style_digest']   = 'kopsavilkumu par katru lapu (reizi %.2f dienās)';
+$lang['subscr_style_list']     = 'kopš pēdējās vēstules notikušo labojumu sarakstu (reizi %.2f dienās)';
+$lang['authmodfailed']         = 'Aplami konfigurēta lietotāju autentifikācija. Lūdzu ziņo Wiki administratoram.';
 $lang['authtempfail']          = 'Lietotāju autentifikācija pašlaik nedarbojas. Ja tas turpinās ilgstoši, lūduz ziņo Wiki administratoram.';
 $lang['i_chooselang']          = 'Izvēlies valodu';
 $lang['i_installer']           = 'DokuWiki instalētājs';
@@ -193,34 +258,52 @@ $lang['i_enableacl']           = 'Lietot ACL (ieteikts)';
 $lang['i_superuser']           = 'Superuser';
 $lang['i_problems']            = 'Instalētājs atrada zemāk minētās problēmas. Kamēr tās nenovērš, nav iespējam turpināt.';
 $lang['i_modified']            = 'Drošības nolūkos šis skripts darbosies tika ar jaunu nemodificētu Dokuwiki instalāciju.
-                         Vai nu no jauna jāatarhivē faili no lejupielādētās pakas vai jāraugās pēc padoma pilnā Dokuwiki instalācijas instrukcijā 
-                         <a href="http://dokuwiki.org/install"></a>';
+Vai nu no jauna jāatarhivē faili no lejupielādētās pakas vai jāraugās pēc padoma pilnā Dokuwiki instalācijas instrukcijā <a href="http://dokuwiki.org/install"></a>';
 $lang['i_funcna']              = 'PHP funkcija <code>%s</code> nav pieejama. Varbūt jūsu servera īpašnieks to kāda iemesla dēļ atslēdzis?';
 $lang['i_phpver']              = 'Jūsu PHP versija <code>%s</code> ir par vecu. Vajag versiju <code>%s</code>. Atjaunojiet savu PHP instalāciju.';
 $lang['i_permfail']            = 'Dokuwiki nevar ierakstīt <code>%s</code>. Jālabo direktorijas tiesības!';
 $lang['i_confexists']          = '<code>%s</code> jau ir';
 $lang['i_writeerr']            = 'Nevar izveidot <code>%s</code>. Jāpārbauda direktorijas/faila tiesības un fails jāizveido pašam.';
-$lang['i_badhash']             = 'nepazīstams via izmainīts dokuwiki.php (hash=<code>%s</code>)';
+$lang['i_badhash']             = 'nepazīstams vai izmainīts dokuwiki.php fails (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - neatļauta vai tukša vērtība';
 $lang['i_success']             = 'Konfigurēšana veiksmīgi pabeigta. Tagad vari nodzēst failu install.php. Tālāk turpini <a href="doku.php">savā jaunajā DokuWiki</a>.';
-$lang['i_failure']             = 'Rakstot konfigurācijas failu, gadījās dažas kļūmes. 
-                         Pirms lieto <a href="doku.php">savu jauno DokuWiki</a>, tās varbūt jāizlabo.';
+$lang['i_failure']             = 'Rakstot konfigurācijas failu, gadījās dažas kļūmes. Pirms lieto <a href="doku.php">savu jauno DokuWiki</a>, tās varbūt jāizlabo.';
 $lang['i_policy']              = 'Sākotnējā ACL politika';
 $lang['i_pol0']                = 'Atvērts Wiki (raksta, lasa un augšupielādē ikviens)';
 $lang['i_pol1']                = 'Publisks Wiki (lasa ikviens, raksta un augšupielādē reģistrēti lietotāji)';
 $lang['i_pol2']                = 'Slēgts Wiki (raksta, lasa un augšupielādē tikai reģistrēti lietotāji)';
 $lang['i_retry']               = 'Atkārtot';
-$lang['mu_intro']              = 'Šeit var augšupielādēt uzreiz vairāku failus. Uzklikšķini Pārlūkot pogai, lai tos ieliktu rindā. Nospied Augšupielādēt, kad rinda sastādīta.';
-$lang['mu_gridname']           = 'Faila vārds';
-$lang['mu_gridsize']           = 'Izmērs';
-$lang['mu_gridstat']           = 'Statuss';
-$lang['mu_namespace']          = 'Nodaļa';
-$lang['mu_browse']             = 'Pārlūkot';
-$lang['mu_toobig']             = 'par lielu';
-$lang['mu_ready']              = 'gatavs augšupielādei';
-$lang['mu_done']               = 'pabeigts';
-$lang['mu_fail']               = 'neizdevās';
-$lang['mu_authfail']           = 'sesijas laiks iztecējis';
-$lang['mu_progress']           = '@PCT@% augšupielādēts';
-$lang['mu_filetypes']          = 'Atļautie failu tipi';
+$lang['i_license']             = 'Ar kādu licenci saturs tiks publicēts:';
 $lang['recent_global']         = 'Tu skati izmaiņas nodaļā <b>%s</b>. Ir iespējams <a href="%s">skatīt jaunākos grozījums visā viki</a>. ';
+$lang['years']                 = 'pirms %d gadiem';
+$lang['months']                = 'pirms %d mēnešiem';
+$lang['weeks']                 = 'pirms %d nedēļām';
+$lang['days']                  = 'pirms %d  dienām';
+$lang['hours']                 = 'pirms %d stundām';
+$lang['minutes']               = 'pirms %d minūtēm';
+$lang['seconds']               = 'pirms %d sekundēm';
+$lang['wordblock']             = 'Grozījumus nevarēju saglabāt, jo tie satur aizliegto vārdu (spamu).';
+$lang['media_uploadtab']       = 'Augšuplādēt';
+$lang['media_searchtab']       = 'Meklēt';
+$lang['media_file']            = 'Fails';
+$lang['media_viewtab']         = 'Skatīt';
+$lang['media_edittab']         = 'Labot';
+$lang['media_historytab']      = 'Vēsture';
+$lang['media_list_thumbs']     = 'Sīktēli';
+$lang['media_list_rows']       = 'Rindas';
+$lang['media_sort_name']       = 'Nosaukums';
+$lang['media_sort_date']       = 'Datums';
+$lang['media_namespaces']      = 'Norādīt nodaļu';
+$lang['media_files']           = 'Faili nodaļā %s';
+$lang['media_upload']          = 'Augšuplādēt nodaļā %s';
+$lang['media_search']          = 'Meklēt nodaļā %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s nodaļā %s';
+$lang['media_edit']            = 'Labot %s';
+$lang['media_history']         = '%s vēsture';
+$lang['media_meta_edited']     = 'metadati laboti';
+$lang['media_perm_read']       = 'Atvainojiet, jums nav tiesību skatīt failus. ';
+$lang['media_perm_upload']     = 'Atvainojiet, jums nav tiesību augšupielādēt. ';
+$lang['media_update']          = 'Augšupielādēt jaunu versiju';
+$lang['media_restore']         = 'Atjaunot šo versiju';
+$lang['plugin_install_err']    = 'Modulis aplami instalēts.  Pārdēvē moduļa direktoriju %s par %s.';
