@@ -10,6 +10,12 @@
  * @author Wouter Schoot <wouter@schoot.org>
  * @author John de Graaff <john@de-graaff.net>
  * @author Dion Nicolaas <dion@nicolaas.net>
+ * @author Danny Rotsaert <danny.rotsaert@edpnet.be>
+ * @author Matthias Carchon <webmaster@c-mattic.be>
+ * @author Marijn Hofstra <hofstra.m@gmail.com>
+ * @author Timon Van Overveldt <timonvo@gmail.com>
+ * @author Jeroen
+ * @author Ricardo Guijt <ricardoguijt@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -43,15 +49,16 @@ $lang['btn_back']              = 'Terug';
 $lang['btn_backlink']          = 'Referenties';
 $lang['btn_backtomedia']       = 'Terug naar Bestandsselectie';
 $lang['btn_subscribe']         = 'Inschrijven wijzigingen';
-$lang['btn_unsubscribe']       = 'Opzeggen wijzigingen';
-$lang['btn_subscribens']       = 'Inschrijven namespace-wijzigingen';
-$lang['btn_unsubscribens']     = 'Opzeggen namespace-wijzigingen';
 $lang['btn_profile']           = 'Profiel aanpassen';
 $lang['btn_reset']             = 'Wissen';
 $lang['btn_resendpwd']         = 'Stuur een nieuw wachtwoord';
 $lang['btn_draft']             = 'Bewerk concept';
 $lang['btn_recover']           = 'Herstel concept';
 $lang['btn_draftdel']          = 'Verwijder concept';
+$lang['btn_revert']            = 'Herstellen';
+$lang['btn_register']          = 'Registreren';
+$lang['btn_apply']             = 'Toepassen';
+$lang['btn_media']             = 'Media beheerder';
 $lang['loggedinas']            = 'Ingelogd als';
 $lang['user']                  = 'Gebruikersnaam';
 $lang['pass']                  = 'Wachtwoord';
@@ -61,12 +68,11 @@ $lang['passchk']               = 'nogmaals';
 $lang['remember']              = 'Bewaar';
 $lang['fullname']              = 'Volledige naam';
 $lang['email']                 = 'E-mail';
-$lang['register']              = 'Registreren';
 $lang['profile']               = 'Gebruikersprofiel';
 $lang['badlogin']              = 'Sorry, gebruikersnaam of wachtwoord onjuist';
 $lang['minoredit']             = 'Kleine wijziging';
 $lang['draftdate']             = 'Concept automatisch opgeslagen op';
-$lang['nosecedit']             = 'De pagina is tussentijds veranderd, sectie informatie was verouderd, volledige pagina geladen.';
+$lang['nosecedit']             = 'De pagina is tussentijds veranderd, sectie-informatie was verouderd, volledige pagina geladen.';
 $lang['regmissing']            = 'Vul alle velden in';
 $lang['reguexists']            = 'Er bestaat al een gebruiker met deze loginnaam.';
 $lang['regsuccess']            = 'De gebruiker is aangemaakt. Het wachtwoord is per e-mail verzonden.';
@@ -88,15 +94,58 @@ $lang['resendpwdnouser']       = 'Sorry, we kunnen deze gebruikersnaam niet vind
 $lang['resendpwdbadauth']      = 'Sorry, deze authentiecatiecode is niet geldig. Controleer of je de volledige bevestigings-link hebt gebruikt.';
 $lang['resendpwdconfirm']      = 'Een bevestigingslink is per e-mail verzonden.';
 $lang['resendpwdsuccess']      = 'Je nieuwe wachtwoord is per e-mail verzonden.';
-$lang['license']               = 'Tenzij anders vermeld, inhoud van deze wiki is voorzien van de volgende licentie:';
-$lang['licenseok']             = 'Let op: Door deze pagina aan te passen ga je akkoord met het licenseren van de inhoud onder de volgende licentie:';
+$lang['license']               = 'Tenzij anders vermeld valt de inhoud van deze wiki onder de volgende licentie:';
+$lang['licenseok']             = 'Let op: Door deze pagina aan te passen geef je de inhoud vrij onder de volgende licentie:';
+$lang['searchmedia']           = 'Bestandsnaam zoeken:';
+$lang['searchmedia_in']        = 'Zoek in %s';
 $lang['txt_upload']            = 'Selecteer een bestand om te uploaden';
 $lang['txt_filename']          = 'Vul nieuwe naam in (optioneel)';
 $lang['txt_overwrt']           = 'Overschrijf bestaand bestand';
 $lang['lockedby']              = 'Momenteel in gebruik door';
 $lang['lockexpire']            = 'Exclusief gebruiksrecht vervalt op';
-$lang['willexpire']            = 'Je exclusieve gebruiksrecht voor het aanpassen van deze pagina verloopt over een minuut.\nKlik op de Voorbeeld-knop om het exclusieve gebruiksrecht te verlengen.';
-$lang['notsavedyet']           = 'Nog niet bewaarde wijzigingen zullen verloren gaan.\nWeet je zeker dat je wilt doorgaan?';
+$lang['js']['willexpire']      = 'Je exclusieve gebruiksrecht voor het aanpassen van deze pagina verloopt over een minuut.\nKlik op de Voorbeeld-knop om het exclusieve gebruiksrecht te verlengen.';
+$lang['js']['notsavedyet']     = 'Nog niet bewaarde wijzigingen zullen verloren gaan.
+Weet je zeker dat je wilt doorgaan?';
+$lang['js']['searchmedia']     = 'Zoek naar bestanden';
+$lang['js']['keepopen']        = 'Houd scherm open bij selectie';
+$lang['js']['hidedetails']     = 'Verberg details';
+$lang['js']['mediatitle']      = 'Linkinstellingen';
+$lang['js']['mediadisplay']    = 'Linktype';
+$lang['js']['mediaalign']      = 'Uitlijning';
+$lang['js']['mediasize']       = 'Afbeeldingsomvang';
+$lang['js']['mediatarget']     = 'Linkdoel';
+$lang['js']['mediaclose']      = 'Sluiten';
+$lang['js']['mediainsert']     = 'Invoegen';
+$lang['js']['mediadisplayimg'] = 'De afbeelding weergeven';
+$lang['js']['mediadisplaylnk'] = 'Alleen de link weergeven';
+$lang['js']['mediasmall']      = 'Kleine versie';
+$lang['js']['mediamedium']     = 'Middelgrote versie';
+$lang['js']['medialarge']      = 'Grote versie';
+$lang['js']['mediaoriginal']   = 'Originele versie';
+$lang['js']['medialnk']        = 'Link naar detailpagina';
+$lang['js']['mediadirect']     = 'Directe link naar origineel';
+$lang['js']['medianolnk']      = 'Geen link';
+$lang['js']['medianolink']     = 'Link niet naar de afbeelding';
+$lang['js']['medialeft']       = 'Afbeelding links uitlijnen';
+$lang['js']['mediaright']      = 'Afbeelding rechts uitlijnen';
+$lang['js']['mediacenter']     = 'Afbeelding centreren';
+$lang['js']['medianoalign']    = 'Geen uitlijning gebruiken';
+$lang['js']['nosmblinks']      = 'Linken naar Windows shares werkt alleen in Microsoft Internet Explorer.
+Je kan de link wel kopiëren en plakken.';
+$lang['js']['linkwiz']         = 'Linkwizard';
+$lang['js']['linkto']          = 'Link naar:';
+$lang['js']['del_confirm']     = 'Item(s) verwijderen?';
+$lang['js']['restore_confirm'] = 'Werkelijk deze versie terugzetten?';
+$lang['js']['media_diff']      = 'Verschillen bekijken:';
+$lang['js']['media_diff_both'] = 'Naast elkaar';
+$lang['js']['media_diff_opacity'] = 'Doorschijnend';
+$lang['js']['media_diff_portions'] = 'Swipe';
+$lang['js']['media_select']    = 'Selecteer bestanden';
+$lang['js']['media_upload_btn'] = 'Uploaden';
+$lang['js']['media_done_btn']  = 'Klaar';
+$lang['js']['media_drop']      = 'Sleep bestanden hierheen om ze te uploaden';
+$lang['js']['media_cancel']    = 'Verwijderen';
+$lang['js']['media_overwrt']   = 'Bestaande bestanden overschrijven';
 $lang['rssfailed']             = 'Er is een fout opgetreden bij het ophalen van de feed: ';
 $lang['nothingfound']          = 'Er werd niets gevonden.';
 $lang['mediaselect']           = 'Bestandsselectie';
@@ -114,11 +163,7 @@ $lang['deletefail']            = '"%s" kan niet worden verwijderd - controleer p
 $lang['mediainuse']            = 'Het bestand "%s" is niet verwijderd - het is nog in gebruik.';
 $lang['namespaces']            = 'Namespaces';
 $lang['mediafiles']            = 'Beschikbare bestanden in';
-$lang['js']['keepopen']        = 'Houd scherm open bij selectie';
-$lang['js']['hidedetails']     = 'Verberg details';
-$lang['js']['nosmblinks']      = 'Linken naar Windows shares werkt alleen in Microsoft Internet Explorer.
-Je kan de link wel kopiëren en plakken.';
-$lang['js']['mu_btn']          = 'Meerdere files tegelijk uploaden';
+$lang['accessdenied']          = 'U heeft geen toegang tot deze pagina.';
 $lang['mediausage']            = 'Gebruik de volgende syntax om aan het bestand te refereren:';
 $lang['mediaview']             = 'Bekijk het orginele bestand';
 $lang['mediaroot']             = 'root';
@@ -134,6 +179,10 @@ $lang['current']               = 'huidige';
 $lang['yours']                 = 'Jouw versie';
 $lang['diff']                  = 'Toon verschillen met huidige revisie';
 $lang['diff2']                 = 'Toon verschillen tussen geselecteerde revisies';
+$lang['difflink']              = 'Link naar deze vergelijking';
+$lang['diff_type']             = 'Bekijk verschillen:';
+$lang['diff_inline']           = 'Inline';
+$lang['diff_side']             = 'Zij aan zij';
 $lang['line']                  = 'Regel';
 $lang['breadcrumb']            = 'Spoor';
 $lang['youarehere']            = 'Je bent hier';
@@ -145,11 +194,16 @@ $lang['restored']              = 'oude revisie hersteld';
 $lang['external_edit']         = 'Externe bewerking';
 $lang['summary']               = 'Samenvatting wijziging';
 $lang['noflash']               = 'De <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> is vereist om de pagina te kunnen weergeven.';
+$lang['download']              = 'Download fragment';
 $lang['mail_newpage']          = 'pagina toegevoegd:';
 $lang['mail_changed']          = 'pagina aangepast:';
+$lang['mail_subscribe_list']   = 'Pagina\'s veranderd in namespace:';
 $lang['mail_new_user']         = 'nieuwe gebruiker:';
 $lang['mail_upload']           = 'bestand geüpload:';
-$lang['qb_alert']              = 'Voer de tekst in die je wilt opmaken.\nDe tekst wordt toegevoegd aan het eind van het document.';
+$lang['changes_type']          = 'Bekijk wijzigingen van';
+$lang['pages_changes']         = 'Pagina\'s';
+$lang['media_changes']         = 'Media bestanden';
+$lang['both_changes']          = 'Zowel pagina\'s als media bestanden';
 $lang['qb_bold']               = 'Vette tekst';
 $lang['qb_italic']             = 'Cursieve tekst';
 $lang['qb_underl']             = 'Onderstreepte tekst';
@@ -160,6 +214,11 @@ $lang['qb_h2']                 = 'Niveau 2 kop';
 $lang['qb_h3']                 = 'Niveau 3 kop';
 $lang['qb_h4']                 = 'Niveau 4 kop';
 $lang['qb_h5']                 = 'Niveau 5 kop';
+$lang['qb_h']                  = 'Koptekst';
+$lang['qb_hs']                 = 'Kies koptekst';
+$lang['qb_hplus']              = 'Hogere koptekst';
+$lang['qb_hminus']             = 'Lagere koptekst';
+$lang['qb_hequal']             = 'Koptekst op zelfde niveau';
 $lang['qb_link']               = 'Interne link';
 $lang['qb_extlink']            = 'Externe link';
 $lang['qb_hr']                 = 'Horizontale lijn';
@@ -169,7 +228,7 @@ $lang['qb_media']              = 'Voeg plaatjes en andere bestanden toe';
 $lang['qb_sig']                = 'Handtekening invoegen';
 $lang['qb_smileys']            = 'Smileys';
 $lang['qb_chars']              = 'Speciale tekens';
-$lang['del_confirm']           = 'Item(s) verwijderen?';
+$lang['upperns']               = 'Spring naar bovenliggende namespace';
 $lang['admin_register']        = 'Nieuwe gebruiker toevoegen';
 $lang['metaedit']              = 'Metadata wijzigen';
 $lang['metasaveerr']           = 'Schrijven van metadata mislukt';
@@ -185,11 +244,25 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formaat';
 $lang['img_camera']            = 'Camera';
 $lang['img_keywords']          = 'Trefwoorden';
-$lang['subscribe_success']     = '%s toegevoegd aan de lijst voor %s';
-$lang['subscribe_error']       = 'Fout bij toevoegen van %s aan de lijst voor %s';
-$lang['subscribe_noaddress']   = 'Er is geen adres dat overeenkomt met je login, je kan niet toegevoegd worden aan de lijst';
-$lang['unsubscribe_success']   = '%s verwijderd van de lijst voor %s';
-$lang['unsubscribe_error']     = 'Fout bij verwijderen van %s van de lijst voor %s';
+$lang['img_width']             = 'Breedte';
+$lang['img_height']            = 'Hoogte';
+$lang['img_manager']           = 'In media beheerder bekijken';
+$lang['subscr_subscribe_success'] = '%s is ingeschreven voor %s';
+$lang['subscr_subscribe_error'] = 'Fout bij inschrijven van %s voor %s';
+$lang['subscr_subscribe_noaddress'] = 'Er is geen emailadres geassocieerd met uw account, u kunt daardoor niet worden ingeschreven.';
+$lang['subscr_unsubscribe_success'] = '%s is nu uitgeschreven bij %s.';
+$lang['subscr_unsubscribe_error'] = 'Fout bij uitschrijven van %s bij %s.';
+$lang['subscr_already_subscribed'] = '%s is reeds ingeschreven bij %s.';
+$lang['subscr_not_subscribed'] = '%s is niet ingeschreven bij %s.';
+$lang['subscr_m_not_subscribed'] = 'Je bent momenteel niet ingeschreven bij de huidige pagina of namespace.';
+$lang['subscr_m_new_header']   = 'Inschrijving toevoegen';
+$lang['subscr_m_current_header'] = 'Huidige inschrijvingen';
+$lang['subscr_m_unsubscribe']  = 'Uitschrijven';
+$lang['subscr_m_subscribe']    = 'Inschrijven';
+$lang['subscr_m_receive']      = 'Ontvang';
+$lang['subscr_style_every']    = 'Email bij iedere wijziging';
+$lang['subscr_style_digest']   = 'Samenvattings-email met wijzigingen per pagina (elke %.2f dagen)';
+$lang['subscr_style_list']     = 'Lijst van veranderde pagina\'s sinds laatste email (elke %.2f dagen)';
 $lang['authmodfailed']         = 'Ongeldige gebruikersauthenticatie-configuratie. Informeer de wikibeheerder.';
 $lang['authtempfail']          = 'Gebruikersauthenticatie is tijdelijk niet beschikbaar. Als deze situatie zich blijft voordoen, informeer dan de wikibeheerder.';
 $lang['i_chooselang']          = 'Kies je taal';
@@ -213,17 +286,37 @@ $lang['i_pol0']                = 'Open wiki (lezen, schrijven, uploaden voor ied
 $lang['i_pol1']                = 'Publieke wiki (lezen voor iedereen, schrijven en uploaden voor geregistreerde gebruikers)';
 $lang['i_pol2']                = 'Besloten wiki (lezen, schrijven en uploaden alleen voor geregistreerde gebruikers)';
 $lang['i_retry']               = 'Opnieuw';
-$lang['mu_intro']              = 'Hiier kun je meerdere bestanden tegelijk uploaden. Klik de blader-knop om ze aan de lijst toe te voegen. Klik Upload als je klaar bent.';
-$lang['mu_gridname']           = 'Bestandsnaam';
-$lang['mu_gridsize']           = 'Grootte';
-$lang['mu_gridstat']           = 'Status';
-$lang['mu_namespace']          = 'Namespace';
-$lang['mu_browse']             = 'Blader';
-$lang['mu_toobig']             = 'te groot';
-$lang['mu_ready']              = 'Klaar om te uploaden';
-$lang['mu_done']               = 'klaar';
-$lang['mu_fail']               = 'mislukt';
-$lang['mu_authfail']           = 'sessie beëindigd';
-$lang['mu_progress']           = '@PCT@% geüpload';
-$lang['mu_filetypes']          = 'Toegestane bestandstypes';
+$lang['i_license']             = 'Kies a.u.b. een licentie die u voor uw inhoud wilt gebruiken:';
 $lang['recent_global']         = 'Je bekijkt momenteel de wijzigingen binnen de <b>%s</b> namespace. Je kunt ook de <a href="%s">recente wijzigingen van de hele wiki</a> bekijken.';
+$lang['years']                 = '%d jaar geleden';
+$lang['months']                = '%d maand geleden';
+$lang['weeks']                 = '%d weken geleden';
+$lang['days']                  = '%d dagen geleden';
+$lang['hours']                 = '%d uren geleden';
+$lang['minutes']               = '%d minuten geleden';
+$lang['seconds']               = '%d seconden geleden';
+$lang['wordblock']             = 'Uw wijziging is niet opgeslagen omdat deze niet-toegestane tekst bevat (spam).';
+$lang['media_uploadtab']       = 'Uploaden';
+$lang['media_searchtab']       = 'Zoeken';
+$lang['media_file']            = 'Bestand';
+$lang['media_viewtab']         = 'Beeld';
+$lang['media_edittab']         = 'Bewerken';
+$lang['media_historytab']      = 'Geschiedenis';
+$lang['media_list_thumbs']     = 'Miniatuurweergaven';
+$lang['media_list_rows']       = 'Regels';
+$lang['media_sort_name']       = 'Naam';
+$lang['media_sort_date']       = 'Datum';
+$lang['media_namespaces']      = 'Kies naamruimte';
+$lang['media_files']           = 'Bestanden in %s';
+$lang['media_upload']          = 'Upload naar %s';
+$lang['media_search']          = 'Zoeken in %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s bij %s';
+$lang['media_edit']            = '%s bewerken';
+$lang['media_history']         = 'Geschiedenis van %s';
+$lang['media_meta_edited']     = 'Metagegevens bewerkt';
+$lang['media_perm_read']       = 'Sorry, u heeft niet voldoende rechten om bestanden te lezen.';
+$lang['media_perm_upload']     = 'Sorry, u heeft niet voldoende rechten om bestanden te uploaden.';
+$lang['media_update']          = 'Upload nieuwe versie';
+$lang['media_restore']         = 'Deze versie terugzetten';
+$lang['plugin_install_err']    = 'Plugin is juist geinstalleerd. Hernoem plugin map \'%s\' naar \'%s\'.';
