@@ -38,7 +38,7 @@ $lang['btn_update']            = 'Aktualizovať';
 $lang['btn_delete']            = 'Zmazať';
 $lang['btn_back']              = 'Späť';
 $lang['btn_backlink']          = 'Spätné odkazy';
-$lang['btn_backtomedia']       = 'Späť na výber média';
+$lang['btn_backtomedia']       = 'Späť na výber súboru';
 $lang['btn_subscribe']         = 'Sledovať zmeny';
 $lang['btn_profile']           = 'Aktualizovať profil';
 $lang['btn_reset']             = 'Zrušiť';
@@ -48,6 +48,8 @@ $lang['btn_recover']           = 'Obnoviť koncept';
 $lang['btn_draftdel']          = 'Zmazať koncept';
 $lang['btn_revert']            = 'Obnoviť';
 $lang['btn_register']          = 'Registrovať';
+$lang['btn_apply']             = 'Použiť';
+$lang['btn_media']             = 'Správa médií';
 $lang['loggedinas']            = 'Prihlásený(á) ako';
 $lang['user']                  = 'Užívateľské meno';
 $lang['pass']                  = 'Heslo';
@@ -92,7 +94,7 @@ $lang['txt_filename']          = 'Uložiť ako (voliteľné)';
 $lang['txt_overwrt']           = 'Prepísať existujúci súbor';
 $lang['lockedby']              = 'Práve zamknuté:';
 $lang['lockexpire']            = 'Zámok stratí platnosť:';
-$lang['willexpire']            = 'Váš zámok pre editáciu za chvíľu stratí platnosť.\nAby ste predišli konfliktom, stlačte tlačítko Náhľad a zámok sa predĺži.';
+$lang['js']['willexpire']      = 'Váš zámok pre editáciu za chvíľu stratí platnosť.\nAby ste predišli konfliktom, stlačte tlačítko Náhľad a zámok sa predĺži.';
 $lang['js']['notsavedyet']     = 'Neuložené zmeny budú stratené.
 Chcete naozaj pokračovať?';
 $lang['js']['searchmedia']     = 'Hľadať súbory';
@@ -101,7 +103,7 @@ $lang['js']['hidedetails']     = 'Skryť detaily';
 $lang['js']['mediatitle']      = 'Nastavenia odkazu';
 $lang['js']['mediadisplay']    = 'Typ odkazu';
 $lang['js']['mediaalign']      = 'Zarovnanie';
-$lang['js']['mediasize']       = 'Veľkosť obrázku';
+$lang['js']['mediasize']       = 'Veľkosť obrázka';
 $lang['js']['mediatarget']     = 'Cieľ odkazu';
 $lang['js']['mediaclose']      = 'Zatvoriť';
 $lang['js']['mediainsert']     = 'Vložiť';
@@ -124,11 +126,21 @@ Aj napriek tomu tento odkaz môžete skopírovať a vložiť inde.';
 $lang['js']['linkwiz']         = 'Sprievodca odkazmi';
 $lang['js']['linkto']          = 'Odkaz na:';
 $lang['js']['del_confirm']     = 'Zmazať túto položku?';
-$lang['js']['mu_btn']          = 'Nahrať viac súborov súčasne';
+$lang['js']['restore_confirm'] = 'Skutočne obnoviť túto verziu?';
+$lang['js']['media_diff']      = 'Zobraziť rozdiely:';
+$lang['js']['media_diff_both'] = 'Vedľa seba';
+$lang['js']['media_diff_opacity'] = 'Presvitaním';
+$lang['js']['media_diff_portions'] = 'Potiahnutím';
+$lang['js']['media_select']    = 'Vybrať súbory...';
+$lang['js']['media_upload_btn'] = 'Nahrať';
+$lang['js']['media_done_btn']  = 'Hotovo';
+$lang['js']['media_drop']      = 'Pridajte súbory potiahnutím myšou';
+$lang['js']['media_cancel']    = 'odstrániť';
+$lang['js']['media_overwrt']   = 'Prepísať existujúce súbory';
 $lang['rssfailed']             = 'Nastala chyba pri vytváraní tohto RSS: ';
 $lang['nothingfound']          = 'Nič nenájdené.';
-$lang['mediaselect']           = 'Výber dokumentu';
-$lang['fileupload']            = 'Nahrávanie dokumentu';
+$lang['mediaselect']           = 'Výber súboru';
+$lang['fileupload']            = 'Nahrávanie súboru';
 $lang['uploadsucc']            = 'Prenos prebehol v poriadku';
 $lang['uploadfail']            = 'Chyba pri nahrávaní. Možno kvôli zle nastaveným právam?';
 $lang['uploadwrong']           = 'Prenos súboru s takouto príponou nie je dovolený.';
@@ -179,6 +191,10 @@ $lang['mail_changed']          = 'stránka zmenená:';
 $lang['mail_subscribe_list']   = 'stránky zmenené v mennom priestore:';
 $lang['mail_new_user']         = 'nový užívateľ:';
 $lang['mail_upload']           = 'nahraný súbor:';
+$lang['changes_type']          = 'Prehľad zmien';
+$lang['pages_changes']         = 'Stránok';
+$lang['media_changes']         = 'Súbory';
+$lang['both_changes']          = 'Stránok spolu s média súbormi';
 $lang['qb_bold']               = 'Tučné';
 $lang['qb_italic']             = 'Kurzíva';
 $lang['qb_underl']             = 'Podčiarknutie';
@@ -219,6 +235,9 @@ $lang['img_copyr']             = 'Kopírovacie práva';
 $lang['img_format']            = 'Formát';
 $lang['img_camera']            = 'Fotoaparát';
 $lang['img_keywords']          = 'Kľúčové slová';
+$lang['img_width']             = 'Šírka';
+$lang['img_height']            = 'Výška';
+$lang['img_manager']           = 'Prezrieť v správcovi médií';
 $lang['subscr_subscribe_success'] = 'Používateľ %s bol pridaný do zoznamu hlásení o zmenách %s';
 $lang['subscr_subscribe_error'] = 'Chyba pri pridaní používateľa %s do zoznamu hlásení o zmenách %s';
 $lang['subscr_subscribe_noaddress'] = 'Vaše prihlasovacie meno nemá priradenú žiadnu email adresu, nemôžete byť pridaný do zoznamu hlásení o zmenách';
@@ -259,21 +278,6 @@ $lang['i_pol1']                = 'Verejná Wiki (čítanie pre každého, zápis
 $lang['i_pol2']                = 'Uzatvorená Wiki (čítanie, zápis a nahrávanie len pre registrovaných užívateľov)';
 $lang['i_retry']               = 'Skúsiť znovu';
 $lang['i_license']             = 'Vyberte licenciu, pod ktorou chcete uložiť váš obsah:';
-$lang['mu_intro']              = 'Na tomto mieste môžete nahrávať viac súborov súčasne. Tlačidlom Prehľadávať pridáte súbory do zoznamu. Tlačidlom Nahrať vykonáte prenos súborov.';
-$lang['mu_gridname']           = 'Názov súboru';
-$lang['mu_gridsize']           = 'Veľkosť';
-$lang['mu_gridstat']           = 'Status';
-$lang['mu_namespace']          = 'Menný priestor';
-$lang['mu_browse']             = 'Prehľadávať';
-$lang['mu_toobig']             = 'príliš veľký';
-$lang['mu_ready']              = 'pripravený na nahratie';
-$lang['mu_done']               = 'dokončený';
-$lang['mu_fail']               = 'neúspešný';
-$lang['mu_authfail']           = 'spojenie stratilo platnosť';
-$lang['mu_progress']           = '@PCT@% nahraných';
-$lang['mu_filetypes']          = 'Povolené typy súborov';
-$lang['mu_info']               = 'nahraných súborov.';
-$lang['mu_lasterr']            = 'Posledná chyba:';
 $lang['recent_global']         = 'Práve prehliadate zmeny v mennom priestore <b>%s</b>. Môžete si tiež pozrieť <a href="%s">aktuálne zmeny celej wiki</a>.';
 $lang['years']                 = 'pred %d rokmi';
 $lang['months']                = 'pred %d mesiacmi';
@@ -283,3 +287,27 @@ $lang['hours']                 = 'pred %d hodinami';
 $lang['minutes']               = 'pred %d minútami';
 $lang['seconds']               = 'pred %d sekundami';
 $lang['wordblock']             = 'Vaše zmeny neboli uložené, pretože obsahovali nepovolený text (spam).';
+$lang['media_uploadtab']       = 'Nahrať';
+$lang['media_searchtab']       = 'Hľadať';
+$lang['media_file']            = 'Súbor';
+$lang['media_viewtab']         = 'Náhľad';
+$lang['media_edittab']         = 'Upraviť';
+$lang['media_historytab']      = 'História';
+$lang['media_list_thumbs']     = 'Miniatúry';
+$lang['media_list_rows']       = 'Zoznam';
+$lang['media_sort_name']       = 'Meno';
+$lang['media_sort_date']       = 'Dátum';
+$lang['media_namespaces']      = 'Vybrať priestor';
+$lang['media_files']           = 'Súbory v %s';
+$lang['media_upload']          = 'Nahrať do %s';
+$lang['media_search']          = 'Hľadať v %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s v %s';
+$lang['media_edit']            = 'Upraviť %s';
+$lang['media_history']         = 'História %s';
+$lang['media_meta_edited']     = 'metadáta upravené';
+$lang['media_perm_read']       = 'Prepáčte, ale nemáte dostatočné oprávnenie na čítanie súborov.';
+$lang['media_perm_upload']     = 'Prepáčte, ale nemáte dostatočné oprávnenie na nahrávanie súborov.';
+$lang['media_update']          = 'Nahrať novú verziu';
+$lang['media_restore']         = 'Obnoviť túto verziu';
+$lang['plugin_install_err']    = 'Plugin nebol nainštalovaný úspešne. Premenujte adresár s pluginom \'%s\' na \'%s\'.';
