@@ -4,10 +4,10 @@
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Selim Farsakoğlu <farsakogluselim@yahoo.de>
- * @author Aydın Coşkuner aydinweb@gmail.com
  * @author Aydın Coşkuner <aydinweb@gmail.com>
- * @author yavuzselim@gmail.com
- * @author Cihan Kahveci kahvecicihan@gmail.com
+ * @author Cihan Kahveci <kahvecicihan@gmail.com>
+ * @author Yavuz Selim <yavuzselim@gmail.com>
+ * @author Caleb Maclennan <caleb@alerque.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -16,7 +16,7 @@ $lang['doublequoteclosing']    = '”';
 $lang['singlequoteopening']    = '‘';
 $lang['singlequoteclosing']    = '’';
 $lang['apostrophe']            = '’';
-$lang['btn_edit']              = 'Sayfayı değiştir';
+$lang['btn_edit']              = 'Sayfayı düzenle';
 $lang['btn_source']            = 'Kaynağı göster';
 $lang['btn_show']              = 'Sayfayı göster';
 $lang['btn_create']            = 'Bu sayfayı oluştur';
@@ -31,7 +31,7 @@ $lang['btn_recent']            = 'En son değişiklikler';
 $lang['btn_upload']            = 'Yükle';
 $lang['btn_cancel']            = 'İptal';
 $lang['btn_index']             = 'İndeks';
-$lang['btn_secedit']           = 'Değiştir';
+$lang['btn_secedit']           = 'Düzenle';
 $lang['btn_login']             = 'Giriş yap';
 $lang['btn_logout']            = 'Çıkış yap';
 $lang['btn_admin']             = 'Yönetici';
@@ -41,15 +41,14 @@ $lang['btn_back']              = 'Geri';
 $lang['btn_backlink']          = 'Geri linkler';
 $lang['btn_backtomedia']       = 'Çokluortam dosyası seçimine dön';
 $lang['btn_subscribe']         = 'Sayfa Değişikliklerini Bildir';
-$lang['btn_unsubscribe']       = 'Sayfa Değişikliklerini Bildirme';
-$lang['btn_subscribens']       = 'Namespace Değişikliklerini Bildir';
-$lang['btn_unsubscribens']     = 'Namespace Değişikliklerini Bildirme';
 $lang['btn_profile']           = 'Kullanıcı Bilgilerini Güncelle';
 $lang['btn_reset']             = 'Sıfırla';
 $lang['btn_resendpwd']         = 'Yeni parola gönder';
 $lang['btn_draft']             = 'Taslağı düzenle';
 $lang['btn_recover']           = 'Taslağı geri yükle';
 $lang['btn_draftdel']          = 'Taslağı sil';
+$lang['btn_revert']            = 'Geri Yükle';
+$lang['btn_register']          = 'Kayıt ol';
 $lang['loggedinas']            = 'Giriş ismi';
 $lang['user']                  = 'Kullanıcı ismi';
 $lang['pass']                  = 'Parola';
@@ -59,7 +58,6 @@ $lang['passchk']               = 'Bir kez daha girin';
 $lang['remember']              = 'Beni hatırla';
 $lang['fullname']              = 'Tam isim';
 $lang['email']                 = 'E-posta';
-$lang['register']              = 'Kayıt ol';
 $lang['profile']               = 'Kullanıcı Bilgileri';
 $lang['badlogin']              = 'Üzgünüz, Kullanıcı adı veya şifre yanlış oldu.';
 $lang['minoredit']             = 'Küçük Değişiklikler';
@@ -88,13 +86,44 @@ $lang['resendpwdconfirm']      = 'Doğrulama linki e-posta adresinize gönderild
 $lang['resendpwdsuccess']      = 'Yeni parolanız e-posta adresinize gönderildi.';
 $lang['license']               = 'Aksi belirtilmediği halde, bu wikinin içeriğinin telif hakları şu lisans ile korunmaktadır:';
 $lang['licenseok']             = 'Not: Bu sayfayı değiştirerek yazınızın şu lisans ile yayınlanmasını kabul etmiş olacaksınız:';
+$lang['searchmedia']           = 'Dosya Adı Ara:';
+$lang['searchmedia_in']        = '%s içinde ara';
 $lang['txt_upload']            = 'Yüklenecek dosyayı seç';
 $lang['txt_filename']          = 'Dosya adı (zorunlu değil)';
 $lang['txt_overwrt']           = 'Mevcut dosyanın üstüne yaz';
 $lang['lockedby']              = 'Şu an şunun tarafından kilitli:';
 $lang['lockexpire']            = 'Kilitin açılma tarihi:';
-$lang['willexpire']            = 'Bu sayfayı değiştirme kilidinin süresi yaklaşık bir dakika içinde geçecek.\nÇakışmaları önlemek için önizleme tuşunu kullanarak kilit sayacını sıfırla.';
-$lang['notsavedyet']           = 'Kaydedilmemiş değişiklikler kaybolacak.\nDevam etmek istiyor musunuz?';
+$lang['js']['willexpire']            = 'Bu sayfayı değiştirme kilidinin süresi yaklaşık bir dakika içinde geçecek.\nÇakışmaları önlemek için önizleme tuşunu kullanarak kilit sayacını sıfırla.';
+$lang['js']['notsavedyet']     = 'Kaydedilmemiş değişiklikler kaybolacak.
+Devam etmek istiyor musunuz?';
+$lang['js']['searchmedia']     = 'Dosyalar için Ara';
+$lang['js']['keepopen']        = 'Seçim yapıldığında bu pencereyi açık tut';
+$lang['js']['hidedetails']     = 'Ayrıntıları gizle';
+$lang['js']['mediatitle']      = 'Bağlantı Ayarları';
+$lang['js']['mediadisplay']    = 'Bağlantı Tipi';
+$lang['js']['mediaalign']      = 'Hizalama';
+$lang['js']['mediasize']       = 'Resim büyüklüğü';
+$lang['js']['mediatarget']     = 'Bağlantı hedefi';
+$lang['js']['mediaclose']      = 'Kapat';
+$lang['js']['mediainsert']     = 'Ekle';
+$lang['js']['mediadisplayimg'] = 'Resmi görüntüle';
+$lang['js']['mediadisplaylnk'] = 'Sadece bağlantıyı görüntüle ';
+$lang['js']['mediasmall']      = 'Küçük versiyon';
+$lang['js']['mediamedium']     = 'Orta versiyon';
+$lang['js']['medialarge']      = 'Büyük versiyon';
+$lang['js']['mediaoriginal']   = 'Orjinal versiyon';
+$lang['js']['medialnk']        = 'Detay sayfasına bağlantı';
+$lang['js']['mediadirect']     = 'Orjinal sayfaya bağlantı';
+$lang['js']['medianolnk']      = 'Bağlantı yok';
+$lang['js']['medianolink']     = 'Resme bağlantı verme';
+$lang['js']['medialeft']       = 'Resmi sola hizala';
+$lang['js']['mediaright']      = 'Resmi sağa hizala';
+$lang['js']['mediacenter']     = 'Resmi ortaya hizala';
+$lang['js']['medianoalign']    = 'Hizalama kullanma';
+$lang['js']['nosmblinks']      = 'Windows paylaşımı sadece Microsoft Internet Explorer ile çalışmaktadır. Yine de hala bağlantıyı kopyalayıp yapıştırarak kullanabilirsiniz. ';
+$lang['js']['linkwiz']         = 'Bağlantı sihirbazı';
+$lang['js']['linkto']          = 'Bağlantı:';
+$lang['js']['del_confirm']     = 'Bu girişi sil?';
 $lang['rssfailed']             = 'Bu beslemeyi çekerken hata oluştu: ';
 $lang['nothingfound']          = 'Hiçbir şey yok.';
 $lang['mediaselect']           = 'Çokluortam dosyası seçimi';
@@ -112,10 +141,7 @@ $lang['deletefail']            = '"%s" silinemedi - yetkileri kontrol et.';
 $lang['mediainuse']            = '"%s" dosyası silinmedi, hala kullanımda.';
 $lang['namespaces']            = 'Namespaces';
 $lang['mediafiles']            = 'Şuradaki kullanıma hazır dosyalar:';
-$lang['js']['keepopen']        = 'Seçim yapıldığında bu pencereyi açık tut';
-$lang['js']['hidedetails']     = 'Ayrıntıları gizle';
-$lang['js']['nosmblinks']      = 'Windows paylaşımı sadece Microsoft Internet Explorer ile çalışmaktadır. Yine de hala bağlantıyı kopyalayıp yapıştırarak kullanabilirsiniz. ';
-$lang['js']['mu_btn']          = 'Birden fazla dosyayı bir seferde gönder';
+$lang['accessdenied']          = 'Bu sayfayı görüntüleme yetkiniz bulunmamaktadır';
 $lang['mediausage']            = 'Şu ';
 $lang['mediaview']             = 'Özgün dosyayı göster';
 $lang['mediaroot']             = 'Kök dizini';
@@ -131,6 +157,7 @@ $lang['current']               = 'mevcut';
 $lang['yours']                 = 'Senin Sürümün';
 $lang['diff']                  = 'Kullanılan sürüm ile farkları göster';
 $lang['diff2']                 = 'Seçili sürümler arasındaki farkı göster';
+$lang['difflink']              = 'Karşılaştırma görünümüne bağlantı';
 $lang['line']                  = 'Satır';
 $lang['breadcrumb']            = 'İz';
 $lang['youarehere']            = 'Buradasınız';
@@ -142,11 +169,11 @@ $lang['restored']              = 'eski sürüme dönüldü';
 $lang['external_edit']         = 'Dışarıdan düzenle';
 $lang['summary']               = 'Özeti düzenle';
 $lang['noflash']               = 'Bu içeriği göstermek için <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Eklentisi</a> gerekmektedir.';
+$lang['download']              = 'Parçacığı indir';
 $lang['mail_newpage']          = 'sayfa eklenme:';
 $lang['mail_changed']          = 'sayfa değiştirilme:';
 $lang['mail_new_user']         = 'yeni kullanıcı';
 $lang['mail_upload']           = 'dosya yüklendi:';
-$lang['qb_alert']              = 'Lütfen biçimlendirmek istediğin yazıyı gir.\nSayfanın sonuna eklenecektir.';
 $lang['qb_bold']               = 'Kalın Yazı';
 $lang['qb_italic']             = 'Eğik Yazı';
 $lang['qb_underl']             = 'Altı Çizgili Yazı';
@@ -157,6 +184,9 @@ $lang['qb_h2']                 = '2. Seviye Başlık';
 $lang['qb_h3']                 = '3. Seviye Başlık';
 $lang['qb_h4']                 = '4. Seviye Başlık';
 $lang['qb_h5']                 = '5. Seviye Başlık';
+$lang['qb_h']                  = 'Başlık';
+$lang['qb_hs']                 = 'Başlığı seç';
+$lang['qb_hplus']              = 'Daha yüksek başlık';
 $lang['qb_link']               = 'İç Bağlantı';
 $lang['qb_extlink']            = 'Dış Bağlantı';
 $lang['qb_hr']                 = 'Yatay Çizgi';
@@ -166,7 +196,6 @@ $lang['qb_media']              = 'Resim ve başka dosyalar ekle';
 $lang['qb_sig']                = 'İmza Ekle';
 $lang['qb_smileys']            = 'Gülen Yüzler';
 $lang['qb_chars']              = 'Özel Karakterler';
-$lang['del_confirm']           = 'Bu girişi sil?';
 $lang['admin_register']        = 'Yeni kullanıcı ekle...';
 $lang['metaedit']              = 'Metaverileri Değiştir';
 $lang['metasaveerr']           = 'Metaveri yazma başarısız ';
@@ -182,11 +211,6 @@ $lang['img_copyr']             = 'Telif Hakkı';
 $lang['img_format']            = 'Biçim';
 $lang['img_camera']            = 'Fotoğraf Makinası';
 $lang['img_keywords']          = 'Anahtar Sözcükler';
-$lang['subscribe_success']     = '%s, %s\'in abonelik listesine eklendi';
-$lang['subscribe_error']       = '%s; %s\'in abonelik listesine eklenirken hata oluştu';
-$lang['subscribe_noaddress']   = 'Giriş bilgilerinizle ilişkili bir adres yok, abonelik listesine eklenemezsiniz';
-$lang['unsubscribe_success']   = '%s, %s\'in abonelik listesinden çıkartıldı';
-$lang['unsubscribe_error']     = '%s, %s\'in listesinden çıkartılırken hata oluştu';
 $lang['authmodfailed']         = 'Yanlış kullanıcı onaylama ayarı. Lütfen Wiki yöneticisine bildiriniz.';
 $lang['authtempfail']          = 'Kullanıcı doğrulama geçici olarak yapılamıyor. Eğer bu durum devam ederse lütfen Wiki yöneticine haber veriniz.';
 $lang['i_chooselang']          = 'Dili seçiniz';
@@ -210,17 +234,4 @@ $lang['i_pol0']                = 'Tamamen Açık Wiki (herkes okuyabilir, yazabi
 $lang['i_pol1']                = 'Açık Wiki (herkes okuyabilir, ancak  sadece üye olanlar yazabilir ve dosya yükleyebilir)';
 $lang['i_pol2']                = 'Kapalı Wiki (sadece üye olanlar okuyabilir, yazabilir ve dosya yükleyebilir)';
 $lang['i_retry']               = 'Tekrar Dene';
-$lang['mu_intro']              = 'Burada birden fazla dosyayı bir seferde yükleyebilirsiniz. Sıraya eklemek için Gözat butonuna tıklayın. Bitince yükleye tıklayın';
-$lang['mu_gridname']           = 'Dosya Adı';
-$lang['mu_gridsize']           = 'Boyutu';
-$lang['mu_gridstat']           = 'Durumu';
-$lang['mu_namespace']          = 'Namespace';
-$lang['mu_browse']             = 'Gözat';
-$lang['mu_toobig']             = 'çok büyük';
-$lang['mu_ready']              = 'yüklenmeye hazır';
-$lang['mu_done']               = 'tamamlandı';
-$lang['mu_fail']               = 'başarısız';
-$lang['mu_authfail']           = 'oturum zaman aşımına uğradı';
-$lang['mu_progress']           = '@PCT@% yüklendi';
-$lang['mu_filetypes']          = 'İzin verilen Dosya Türleri';
 $lang['recent_global']         = '<b>%s</b> namespace\'i içerisinde yapılan değişiklikleri görüntülemektesiniz. Wiki\'deki tüm değişiklikleri de <a href="%s">bu adresten</a> görebilirsiniz. ';
