@@ -411,6 +411,7 @@ function p_set_metadata($id, $data, $render=false, $persistent=true){
         // set both keys individually as the renderer has references to the individual keys
         $METADATA_RENDERERS[$id]['current']    = $meta['current'];
         $METADATA_RENDERERS[$id]['persistent'] = $meta['persistent'];
+        return true;
     } else {
         return p_save_metadata($id, $meta);
     }
@@ -676,12 +677,16 @@ function & p_get_renderer($mode) {
     global $conf, $plugin_controller;
 
     $rname = !empty($conf['renderer_'.$mode]) ? $conf['renderer_'.$mode] : $mode;
+    $rclass = "Doku_Renderer_$rname";
+
+    if( class_exists($rclass) ) {
+        return new $rclass();
+    }
 
     // try default renderer first:
     $file = DOKU_INC."inc/parser/$rname.php";
     if(@file_exists($file)){
         require_once $file;
-        $rclass = "Doku_Renderer_$rname";
 
         if ( !class_exists($rclass) ) {
             trigger_error("Unable to resolve render class $rclass",E_USER_WARNING);
