@@ -1,8 +1,8 @@
 <?php
 /**
- *  Dokuwiki installation assistance
+ * Dokuwiki installation assistance
  *
- *  @author      Chris Smith <chris@jalakai.co.uk>
+ * @author      Chris Smith <chris@jalakai.co.uk>
  */
 
 if(!defined('DOKU_INC')) define('DOKU_INC',dirname(__FILE__).'/');
@@ -44,7 +44,12 @@ $dokuwiki_hash = array(
     '2007-05-24'   => 'd80f2740c84c4a6a791fd3c7a353536f',
     '2007-06-26'   => 'b3ca19c7a654823144119980be73cd77',
     '2008-05-04'   => '1e5c42eac3219d9e21927c39e3240aad',
-    'rc2009-02-06' => 'ec8c04210732a14fdfce0f7f6eead865',
+    '2009-02-14'   => 'ec8c04210732a14fdfce0f7f6eead865',
+    '2009-12-25'   => '993c4b2b385643efe5abf8e7010e11f4',
+    '2010-11-07'   => '7921d48195f4db21b8ead6d9bea801b8',
+    '2011-05-25'   => '4241865472edb6fa14a1227721008072',
+    '2011-11-10'   => 'b46ff19a7587966ac4df61cbab1b8b31',
+    '2012-01-25'   => '72c083c73608fc43c586901fd5dabb74',
 );
 
 
@@ -67,6 +72,7 @@ header('Content-Type: text/html; charset=utf-8');
         fieldset { border: none }
         label { display: block; margin-top: 0.5em; }
         select.text, input.text { width: 30em; margin: 0 0.5em; }
+        a {text-decoration: none}
     </style>
     <script type="text/javascript" language="javascript">
         function acltoggle(){
@@ -107,6 +113,10 @@ header('Content-Type: text/html; charset=utf-8');
                 print "</div>\n";
             }
         ?>
+        <a style="background: transparent url(data/security.png) left top no-repeat;
+                  display: block; width:380px; height:73px; border:none; clear:both;"
+           target="_blank"
+           href="http://www.dokuwiki.org/security#web_access_security"></a>
     </div>
 
     <div style="float: left; width: 58%;">
@@ -134,6 +144,7 @@ header('Content-Type: text/html; charset=utf-8');
         ?>
     </div>
 
+
 <div style="clear: both">
   <a href="http://dokuwiki.org/"><img src="lib/tpl/default/images/button-dw.png" alt="driven by DokuWiki" /></a>
   <a href="http://www.php.net"><img src="lib/tpl/default/images/button-php.gif" alt="powered by PHP" /></a>
@@ -149,6 +160,8 @@ function print_form($d){
     global $lang;
     global $LC;
 
+    include(DOKU_CONF.'license.php');
+
     if(!is_array($d)) $d = array();
     $d = array_map('htmlspecialchars',$d);
 
@@ -189,9 +202,26 @@ function print_form($d){
                     <option value="1" <?php echo ($d['policy'] == 1)?'selected="selected"':'' ?>><?php echo $lang['i_pol1']?></option>
                     <option value="2" <?php echo ($d['policy'] == 2)?'selected="selected"':'' ?>><?php echo $lang['i_pol2']?></option>
                 </select>
+
             </fieldset>
         </fieldset>
 
+        <fieldset>
+            <p><?php echo $lang['i_license']?></p>
+            <?php
+            array_unshift($license,array('name' => 'None', 'url'=>''));
+            if(!isset($d['license'])) $d['license'] = 'cc-by-sa';
+            foreach($license as $key => $lic){
+                echo '<label for="lic_'.$key.'">';
+                echo '<input type="radio" name="d[license]" value="'.htmlspecialchars($key).'" id="lic_'.$key.'"'.
+                     (($d['license'] == $key)?'checked="checked"':'').'>';
+                echo htmlspecialchars($lic['name']);
+                if($lic['url']) echo ' <a href="'.$lic['url'].'" target="_blank"><sup>[?]</sup></a>';
+                echo '</label>';
+            }
+            ?>
+        </fieldset>
+
     </fieldset>
     <fieldset id="process">
         <input class="button" type="submit" name="submit" value="<?php echo $lang['btn_save']?>" />
@@ -201,16 +231,16 @@ function print_form($d){
 }
 
 function print_retry() {
-  global $lang;
-  global $LC;
-?>
+    global $lang;
+    global $LC;
+    ?>
     <form action="" method="get">
       <fieldset>
         <input type="hidden" name="l" value="<?php echo $LC ?>" />
         <input class="button" type="submit" value="<?php echo $lang['i_retry'];?>" />
       </fieldset>
     </form>
-<?php
+    <?php
 }
 
 /**
@@ -233,7 +263,7 @@ function check_data(&$d){
         $ok      = false;
     }
     if($d['acl']){
-        if(!preg_match('/^[a-z1-9_]+$/',$d['superuser'])){
+        if(!preg_match('/^[a-z0-9_]+$/',$d['superuser'])){
             $error[] = sprintf($lang['i_badval'],$lang['i_superuser']);
             $ok      = false;
         }
@@ -268,7 +298,7 @@ function store_data($d){
     $d['policy'] = (int) $d['policy'];
 
     // create local.php
-    $now    = date('r');
+    $now    = gmdate('r');
     $output = <<<EOT
 <?php
 /**
@@ -280,13 +310,13 @@ function store_data($d){
 EOT;
     $output .= '$conf[\'title\'] = \''.addslashes($d['title'])."';\n";
     $output .= '$conf[\'lang\'] = \''.addslashes($LC)."';\n";
+    $output .= '$conf[\'license\'] = \''.addslashes($d['license'])."';\n";
     if($d['acl']){
         $output .= '$conf[\'useacl\'] = 1'.";\n";
         $output .= "\$conf['superuser'] = '@admin';\n";
     }
     $ok = $ok && fileWrite(DOKU_LOCAL.'local.php',$output);
 
-
     if ($d['acl']) {
         // create users.auth.php
         // --- user:MD5password:Real Name:email:groups,comma,seperated
@@ -360,7 +390,6 @@ function check_configs(){
         'auth'  => DOKU_LOCAL.'acl.auth.php'
     );
 
-
     // main dokuwiki config file (conf/dokuwiki.php) must not have been modified
     $installation_hash = md5(preg_replace("/(\015\012)|(\015)/","\012",
                              @file_get_contents(DOKU_CONF.'dokuwiki.php')));
@@ -391,16 +420,18 @@ function check_permissions(){
     global $lang;
 
     $dirs = array(
-        'conf'      => DOKU_LOCAL,
-        'data'      => DOKU_INC.'data',
-        'pages'     => DOKU_INC.'data/pages',
-        'attic'     => DOKU_INC.'data/attic',
-        'media'     => DOKU_INC.'data/media',
-        'meta'      => DOKU_INC.'data/meta',
-        'cache'     => DOKU_INC.'data/cache',
-        'locks'     => DOKU_INC.'data/locks',
-        'index'     => DOKU_INC.'data/index',
-        'tmp'       => DOKU_INC.'data/tmp'
+        'conf'        => DOKU_LOCAL,
+        'data'        => DOKU_INC.'data',
+        'pages'       => DOKU_INC.'data/pages',
+        'attic'       => DOKU_INC.'data/attic',
+        'media'       => DOKU_INC.'data/media',
+        'media_attic' => DOKU_INC.'data/media_attic',
+        'media_meta'  => DOKU_INC.'data/media_meta',
+        'meta'        => DOKU_INC.'data/meta',
+        'cache'       => DOKU_INC.'data/cache',
+        'locks'       => DOKU_INC.'data/locks',
+        'index'       => DOKU_INC.'data/index',
+        'tmp'         => DOKU_INC.'data/tmp'
     );
 
     $ok = true;
@@ -424,8 +455,8 @@ function check_functions(){
     global $lang;
     $ok = true;
 
-    if(version_compare(phpversion(),'4.3.3','<')){
-        $error[] = sprintf($lang['i_phpver'],phpversion(),'4.3.3');
+    if(version_compare(phpversion(),'5.1.2','<')){
+        $error[] = sprintf($lang['i_phpver'],phpversion(),'5.1.2');
         $ok = false;
     }
 
@@ -434,11 +465,12 @@ function check_functions(){
                          'glob header ignore_user_abort ini_get mail mkdir '.
                          'ob_start opendir parse_ini_file readfile realpath '.
                          'rename rmdir serialize session_start unlink usleep '.
-                         'preg_replace file_get_contents');
+                         'preg_replace file_get_contents htmlspecialchars_decode '.
+                         'spl_autoload_register');
 
     if (!function_exists('mb_substr')) {
-      $funcs[] = 'utf8_encode';
-      $funcs[] = 'utf8_decode';
+        $funcs[] = 'utf8_encode';
+        $funcs[] = 'utf8_decode';
     }
 
     foreach($funcs as $func){
@@ -473,7 +505,6 @@ function langsel(){
     closedir($dh);
     sort($langs);
 
-
     echo '<form action="">';
     echo $lang['i_chooselang'];
     echo ': <select name="l" onchange="submit()">';
@@ -487,7 +518,7 @@ function langsel(){
 }
 
 /**
- * Print gloabl error array
+ * Print global error array
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
@@ -506,12 +537,12 @@ function print_errors(){
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function remove_magic_quotes(&$array) {
-  foreach (array_keys($array) as $key) {
-    if (is_array($array[$key])) {
-      remove_magic_quotes($array[$key]);
-    }else {
-      $array[$key] = stripslashes($array[$key]);
+    foreach (array_keys($array) as $key) {
+        if (is_array($array[$key])) {
+            remove_magic_quotes($array[$key]);
+        }else {
+            $array[$key] = stripslashes($array[$key]);
+        }
     }
-  }
 }
 
