@@ -1,29 +1,67 @@
 <?php
 if(!defined('DOKU_INC')) define('DOKU_INC',dirname(__FILE__).'/../../');
 
-// fix when '<?xml' isn't on the very first line
+// fix when '< ?xml' isn't on the very first line
 if(isset($HTTP_RAW_POST_DATA)) $HTTP_RAW_POST_DATA = trim($HTTP_RAW_POST_DATA);
 
+/**
+ * Increased whenever the API is changed
+ */
+define('DOKU_XMLRPC_API_VERSION', 6);
 
 require_once(DOKU_INC.'inc/init.php');
-require_once(DOKU_INC.'inc/common.php');
-require_once(DOKU_INC.'inc/auth.php');
 session_write_close();  //close session
 
-if(!$conf['xmlrpc']) {
-    die('XML-RPC server not enabled.');
-    // FIXME check for groups allowed
-}
-
-require_once(DOKU_INC.'inc/IXR_Library.php');
-
+if(!$conf['xmlrpc']) die('XML-RPC server not enabled.');
 
 /**
  * Contains needed wrapper functions and registers all available
  * XMLRPC functions.
  */
 class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
-    var $methods = array();
+    var $methods       = array();
+    var $public_methods = array();
+
+    /**
+     * Checks if the current user is allowed to execute non anonymous methods
+     */
+    function checkAuth(){
+        global $conf;
+        global $USERINFO;
+
+        if(!$conf['useacl']) return true; //no ACL - then no checks
+        if(trim($conf['xmlrpcuser']) == '') return true; //no restrictions
+
+        return auth_isMember($conf['xmlrpcuser'],$_SERVER['REMOTE_USER'],(array) $USERINFO['grps']);
+    }
+
+    /**
+     * Adds a callback, extends parent method
+     *
+     * add another parameter to define if anonymous access to
+     * this method should be granted.
+     */
+    function addCallback($method, $callback, $args, $help, $public=false){
+        if($public) $this->public_methods[] = $method;
+        return parent::addCallback($method, $callback, $args, $help);
+    }
+
+    /**
+     * Execute a call, extends parent method
+     *
+     * Checks for authentication first
+     */
+    function call($methodname, $args){
+        if(!in_array($methodname,$this->public_methods) && !$this->checkAuth()){
+            if (!isset($_SERVER['REMOTE_USER'])) {
+                header('HTTP/1.1 401 Unauthorized');
+            } else {
+                header('HTTP/1.1 403 Forbidden');
+            }
+            return new IXR_Error(-32603, 'server error. not authorized to call method "'.$methodname.'".');
+        }
+        return parent::call($methodname, $args);
+    }
 
     /**
      * Constructor. Register methods and run Server
@@ -32,11 +70,72 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
         $this->IXR_IntrospectionServer();
 
         /* DokuWiki's own methods */
+        $this->addCallback(
+            'dokuwiki.getXMLRPCAPIVersion',
+            'this:getAPIVersion',
+            array('integer'),
+            'Returns the XMLRPC API version.',
+            true
+        );
+
         $this->addCallback(
             'dokuwiki.getVersion',
             'getVersion',
             array('string'),
-            'Returns the running DokuWiki version.'
+            'Returns the running DokuWiki version.',
+            true
+        );
+
+        $this->addCallback(
+            'dokuwiki.login',
+            'this:login',
+            array('integer','string','string'),
+            'Tries to login with the given credentials and sets auth cookies.',
+            true
+        );
+
+        $this->addCallback(
+            'dokuwiki.getPagelist',
+            'this:readNamespace',
+            array('struct','string','struct'),
+            'List all pages within the given namespace.'
+        );
+
+        $this->addCallback(
+            'dokuwiki.search',
+            'this:search',
+            array('struct','string'),
+            'Perform a fulltext search and return a list of matching pages'
+        );
+
+        $this->addCallback(
+            'dokuwiki.getTime',
+            'time',
+            array('int'),
+            'Return the current time at the wiki server.'
+        );
+
+        $this->addCallback(
+            'dokuwiki.setLocks',
+            'this:setLocks',
+            array('struct','struct'),
+            'Lock or unlock pages.'
+        );
+
+
+        $this->addCallback(
+            'dokuwiki.getTitle',
+            'this:getTitle',
+            array('string'),
+            'Returns the wiki title.',
+            true
+        );
+
+        $this->addCallback(
+            'dokuwiki.appendPage',
+            'this:appendPage',
+            array('int', 'string', 'string', 'struct'),
+            'Append text to a wiki page.'
         );
 
         /* Wiki API v2 http://www.jspwiki.org/wiki/WikiRPCInterface2 */
@@ -44,7 +143,8 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
             'wiki.getRPCVersionSupported',
             'this:wiki_RPCVersion',
             array('int'),
-            'Returns 2 with the supported RPC API version.'
+            'Returns 2 with the supported RPC API version.',
+            true
         );
         $this->addCallback(
             'wiki.getPage',
@@ -162,17 +262,17 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
         );
 
         /**
-         * Trigger XMLRPC_CALLBACK_REGISTER, action plugins can use this event 
+         * Trigger XMLRPC_CALLBACK_REGISTER, action plugins can use this event
          * to extend the XMLRPC interface and register their own callbacks.
          *
          * Event data:
          *  The XMLRPC server object:
          *
-         *  $event->data->addCallback() - register a callback, the second 
-         *  paramter has to be of the form "plugin:<pluginname>:<plugin 
+         *  $event->data->addCallback() - register a callback, the second
+         *  paramter has to be of the form "plugin:<pluginname>:<plugin
          *  method>"
          *
-         *  $event->data->callbacks - an array which holds all awaylable 
+         *  $event->data->callbacks - an array which holds all awaylable
          *  callbacks
          */
         trigger_event('XMLRPC_CALLBACK_REGISTER', $this);
@@ -184,40 +284,40 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
      * Return a raw wiki page
      */
     function rawPage($id,$rev=''){
+        $id = cleanID($id);
         if(auth_quickaclcheck($id) < AUTH_READ){
             return new IXR_Error(1, 'You are not allowed to read this page');
         }
         $text = rawWiki($id,$rev);
         if(!$text) {
-            $data = array($id);
-            return trigger_event('HTML_PAGE_FROMTEMPLATE',$data,'pageTemplate',true);
+            return pageTemplate($id);
         } else {
             return $text;
         }
     }
-    
+
     /**
      * Return a media file encoded in base64
-     * 
+     *
      * @author Gina Haeussge <osd@foosel.net>
      */
     function getAttachment($id){
         $id = cleanID($id);
         if (auth_quickaclcheck(getNS($id).':*') < AUTH_READ)
             return new IXR_Error(1, 'You are not allowed to read this file');
-        
+
         $file = mediaFN($id);
         if (!@ file_exists($file))
             return new IXR_Error(1, 'The requested file does not exist');
-        
+
         $data = io_readFile($file, false);
         $base64 = base64_encode($data);
         return $base64;
     }
-    
+
     /**
      * Return info about a media file
-     * 
+     *
      * @author Gina Haeussge <osd@foosel.net>
      */
     function getAttachmentInfo($id){
@@ -226,7 +326,7 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
             'lastModified' => 0,
             'size' => 0,
         );
-        
+
         $file = mediaFN($id);
         if ((auth_quickaclcheck(getNS($id).':*') >= AUTH_READ) && file_exists($file)){
             $info['lastModified'] = new IXR_Date(filemtime($file));
@@ -240,6 +340,7 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
      * Return a wiki page rendered to html
      */
     function htmlPage($id,$rev=''){
+        $id = cleanID($id);
         if(auth_quickaclcheck($id) < AUTH_READ){
             return new IXR_Error(1, 'You are not allowed to read this page');
         }
@@ -250,36 +351,91 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
      * List all pages - we use the indexer list here
      */
     function listPages(){
-        global $conf;
-
         $list  = array();
-        $pages = file($conf['indexdir'] . '/page.idx');
-        $pages = array_filter($pages, 'isVisiblePage');
+        $pages = idx_get_indexer()->getPages();
+        $pages = array_filter(array_filter($pages,'isVisiblePage'),'page_exists');
 
         foreach(array_keys($pages) as $idx) {
-            if(page_exists($pages[$idx])) {
-                $perm = auth_quickaclcheck($pages[$idx]);
-                if($perm >= AUTH_READ) {
-                    $page = array();
-                    $page['id'] = trim($pages[$idx]);
-                    $page['perms'] = $perm;
-                    $page['size'] = @filesize(wikiFN($pages[$idx]));
-                    $page['lastModified'] = new IXR_Date(@filemtime(wikiFN($pages[$idx])));
-                    $list[] = $page;
-                }
+            $perm = auth_quickaclcheck($pages[$idx]);
+            if($perm < AUTH_READ) {
+                continue;
             }
+            $page = array();
+            $page['id'] = trim($pages[$idx]);
+            $page['perms'] = $perm;
+            $page['size'] = @filesize(wikiFN($pages[$idx]));
+            $page['lastModified'] = new IXR_Date(@filemtime(wikiFN($pages[$idx])));
+            $list[] = $page;
         }
 
         return $list;
     }
 
+    /**
+     * List all pages in the given namespace (and below)
+     */
+    function readNamespace($ns,$opts){
+        global $conf;
+
+        if(!is_array($opts)) $opts=array();
+
+        $ns = cleanID($ns);
+        $dir = utf8_encodeFN(str_replace(':', '/', $ns));
+        $data = array();
+        $opts['skipacl'] = 0; // no ACL skipping for XMLRPC
+        search($data, $conf['datadir'], 'search_allpages', $opts, $dir);
+        return $data;
+    }
+
+    /**
+     * List all pages in the given namespace (and below)
+     */
+    function search($query){
+        require_once(DOKU_INC.'inc/fulltext.php');
+
+        $regex = '';
+        $data  = ft_pageSearch($query,$regex);
+        $pages = array();
+
+        // prepare additional data
+        $idx = 0;
+        foreach($data as $id => $score){
+            $file = wikiFN($id);
+
+            if($idx < FT_SNIPPET_NUMBER){
+                $snippet = ft_snippet($id,$regex);
+                $idx++;
+            }else{
+                $snippet = '';
+            }
+
+            $pages[] = array(
+                'id'      => $id,
+                'score'   => intval($score),
+                'rev'     => filemtime($file),
+                'mtime'   => filemtime($file),
+                'size'    => filesize($file),
+                'snippet' => $snippet,
+            );
+        }
+        return $pages;
+    }
+
+    /**
+     * Returns the wiki title.
+     */
+    function getTitle(){
+        global $conf;
+        return $conf['title'];
+    }
+
     /**
      * List all media files.
-     * 
+     *
      * Available options are 'recursive' for also including the subnamespaces
      * in the listing, and 'pattern' for filtering the returned files against
      * a regular expression matching their name.
-     * 
+     *
      * @author Gina Haeussge <osd@foosel.net>
      */
     function listAttachments($ns, $options = array()) {
@@ -288,38 +444,23 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
 
         $ns = cleanID($ns);
 
-        if (!is_array($options))
-            $options = array();
+        if (!is_array($options)) $options = array();
+        $options['skipacl'] = 0; // no ACL skipping for XMLRPC
 
-        if (!isset($options['recursive'])) $options['recursive'] = false;
 
         if(auth_quickaclcheck($ns.':*') >= AUTH_READ) {
             $dir = utf8_encodeFN(str_replace(':', '/', $ns));
 
             $data = array();
-            require_once(DOKU_INC.'inc/search.php');
-            search($data, $conf['mediadir'], 'search_media', array('recursive' => $options['recursive']), $dir);
+            search($data, $conf['mediadir'], 'search_media', $options, $dir);
+            $len = count($data);
+            if(!$len) return array();
 
-            if(!count($data)) {
-                return array();
+            for($i=0; $i<$len; $i++) {
+                unset($data[$i]['meta']);
+                $data[$i]['lastModified'] = new IXR_Date($data[$i]['mtime']);
             }
-
-            $files = array();
-            foreach($data as $item) {
-                if (isset($options['pattern']) && !@preg_match($options['pattern'], $item['id']))
-                    continue;
-                $file = array();
-                $file['id']       = $item['id'];
-                $file['size']     = $item['size'];
-                $file['lastModified'] = new IXR_Date($item['mtime']);
-                $file['isimg']    = $item['isimg'];
-                $file['writable'] = $item['writeable'];
-                $file['perms'] = auth_quickaclcheck(getNS($item['id']).':*');
-                array_push($files, $file);
-            }
-
-            return $files;
-
+            return $data;
         } else {
             return new IXR_Error(1, 'You are not allowed to list media files.');
         }
@@ -329,14 +470,14 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
      * Return a list of backlinks
      */
     function listBackLinks($id){
-        require_once(DOKU_INC.'inc/fulltext.php');
-        return ft_backlinks($id);
+        return ft_backlinks(cleanID($id));
     }
 
     /**
      * Return some basic data about a page
      */
     function pageInfo($id,$rev=''){
+        $id = cleanID($id);
         if(auth_quickaclcheck($id) < AUTH_READ){
             return new IXR_Error(1, 'You are not allowed to read this page');
         }
@@ -361,7 +502,7 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
     /**
      * Save a wiki page
      *
-     * @author Michael Klier <chi@chimeric.de> 
+     * @author Michael Klier <chi@chimeric.de>
      */
     function putPage($id, $text, $params) {
         global $TEXT;
@@ -369,14 +510,14 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
         global $conf;
 
         $id    = cleanID($id);
-        $TEXT  = trim($text);
+        $TEXT  = cleanText($text);
         $sum   = $params['sum'];
         $minor = $params['minor'];
 
         if(empty($id))
             return new IXR_Error(1, 'Empty page ID');
 
-        if(!page_exists($id) && empty($TEXT)) {
+        if(!page_exists($id) && trim($TEXT) == '' ) {
             return new IXR_ERROR(1, 'Refusing to write an empty new wiki page');
         }
 
@@ -388,7 +529,7 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
             return new IXR_Error(1, 'The page is currently locked');
 
         // SPAM check
-        if(checkwordblock()) 
+        if(checkwordblock())
             return new IXR_Error(1, 'Positive wordblock check');
 
         // autoset summary on new pages
@@ -408,161 +549,73 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
         unlock($id);
 
         // run the indexer if page wasn't indexed yet
-        if(!@file_exists(metaFN($id, '.indexed'))) {
-            // try to aquire a lock
-            $lock = $conf['lockdir'].'/_indexer.lock';
-            while(!@mkdir($lock,$conf['dmode'])){
-                usleep(50);
-                if(time()-@filemtime($lock) > 60*5){
-                    // looks like a stale lock - remove it
-                    @rmdir($lock);
-                }else{
-                    return false;
-                }
-            }
-            if($conf['dperm']) chmod($lock, $conf['dperm']);
-
-            require_once(DOKU_INC.'inc/indexer.php');
-
-            // do the work
-            idx_addPage($id);
-
-            // we're finished - save and free lock
-            io_saveFile(metaFN($id,'.indexed'),INDEXER_VERSION);
-            @rmdir($lock);
-        }
+        idx_addPage($id);
 
         return 0;
     }
 
+    /**
+     * Appends text to a wiki page.
+     */
+    function appendPage($id, $text, $params) {
+        $currentpage = $this->rawPage($id);
+        if (!is_string($currentpage)) {
+            return $currentpage;
+        }
+        return $this->putPage($id, $currentpage.$text, $params);
+    }
+
     /**
      * Uploads a file to the wiki.
      *
      * Michael Klier <chi@chimeric.de>
      */
     function putAttachment($id, $file, $params) {
-        global $conf;
-        global $lang;
-
+        $id = cleanID($id);
         $auth = auth_quickaclcheck(getNS($id).':*');
-        if($auth >= AUTH_UPLOAD) {
-            if(!isset($id)) {
-                return new IXR_ERROR(1, 'Filename not given.');
-            }
 
-            $ftmp = $conf['tmpdir'] . '/' . $id;
+        if(!isset($id)) {
+            return new IXR_ERROR(1, 'Filename not given.');
+        }
 
-            // save temporary file
-            @unlink($ftmp);
-            $buff = base64_decode($file);
-            io_saveFile($ftmp, $buff);
+        global $conf;
 
-            // get filename
-            list($iext, $imime,$dl) = mimetype($id);
-            $id = cleanID($id);
-            $fn = mediaFN($id);
+        $ftmp = $conf['tmpdir'] . '/' . md5($id.clientIP());
 
-            // get filetype regexp
-            $types = array_keys(getMimeTypes());
-            $types = array_map(create_function('$q','return preg_quote($q,"/");'),$types);
-            $regex = join('|',$types);
+        // save temporary file
+        @unlink($ftmp);
+        if (preg_match('/^[A-Za-z0-9\+\/]*={0,2}$/', $file) === 1) {
+            // DEPRECATED: Double-decode file if it still looks like base64
+            // after first decoding (which is done by the library)
+            $file = base64_decode($file);
+        }
+        io_saveFile($ftmp, $file);
 
-            // because a temp file was created already
-            if(preg_match('/\.('.$regex.')$/i',$fn)) {
-                //check for overwrite
-                $overwrite = @file_exists($fn);
-                if($overwrite && (!$params['ow'] || $auth < AUTH_DELETE)) {
-                    return new IXR_ERROR(1, $lang['uploadexist']);
-                }
-                // check for valid content
-                @require_once(DOKU_INC.'inc/media.php');
-                $ok = media_contentcheck($ftmp, $imime);
-                if($ok == -1) {
-                    return new IXR_ERROR(1, sprintf($lang['uploadexist'], ".$iext"));
-                } elseif($ok == -2) {
-                    return new IXR_ERROR(1, $lang['uploadspam']);
-                } elseif($ok == -3) {
-                    return new IXR_ERROR(1, $lang['uploadxss']);
-                }
-
-                // prepare event data
-                $data[0] = $ftmp;
-                $data[1] = $fn;
-                $data[2] = $id;
-                $data[3] = $imime;
-                $data[4] = $overwrite;
-
-                // trigger event
-                require_once(DOKU_INC.'inc/events.php');
-                return trigger_event('MEDIA_UPLOAD_FINISH', $data, array($this, '_media_upload_action'), true);
-
-            } else {
-                return new IXR_ERROR(1, $lang['uploadwrong']);
-            }
+        $res = media_save(array('name' => $ftmp), $id, $params['ow'], $auth, 'rename');
+        if (is_array($res)) {
+            return new IXR_ERROR(-$res[1], $res[0]);
         } else {
-            return new IXR_ERROR(1, "You don't have permissions to upload files.");
+            return $res;
         }
     }
-    
+
     /**
      * Deletes a file from the wiki.
-     * 
+     *
      * @author Gina Haeussge <osd@foosel.net>
      */
     function deleteAttachment($id){
+        $id = cleanID($id);
         $auth = auth_quickaclcheck(getNS($id).':*');
-        if($auth < AUTH_DELETE) return new IXR_ERROR(1, "You don't have permissions to delete files.");
-        global $conf;
-        global $lang;
-    
-        // check for references if needed
-        $mediareferences = array();
-        if($conf['refcheck']){
-            require_once(DOKU_INC.'inc/fulltext.php');
-            $mediareferences = ft_mediause($id,$conf['refshow']);
-        }
-    
-        if(!count($mediareferences)){
-            $file = mediaFN($id);
-            if(@unlink($file)){
-                require_once(DOKU_INC.'inc/changelog.php');
-                addMediaLogEntry(time(), $id, DOKU_CHANGE_TYPE_DELETE);
-                io_sweepNS($id,'mediadir');
-                return 0;
-            }
-            //something went wrong
-               return new IXR_ERROR(1, 'Could not delete file');
-        } else {
+        $res = media_delete($id, $auth);
+        if ($res & DOKU_MEDIA_DELETED) {
+            return 0;
+        } elseif ($res & DOKU_MEDIA_NOT_AUTH) {
+            return new IXR_ERROR(1, "You don't have permissions to delete files.");
+        } elseif ($res & DOKU_MEDIA_INUSE) {
             return new IXR_ERROR(1, 'File is still referenced');
-        }
-    }
-
-    /**
-     * Moves the temporary file to its final destination.
-     *
-     * Michael Klier <chi@chimeric.de>
-     */
-    function _media_upload_action($data) {
-        global $conf;
-
-        if(is_array($data) && count($data)===5) {
-            io_createNamespace($data[2], 'media');
-            if(rename($data[0], $data[1])) {
-                chmod($data[1], $conf['fmode']);
-                media_notify($data[2], $data[1], $data[3]);
-                // add a log entry to the media changelog
-                require_once(DOKU_INC.'inc/changelog.php');
-                if ($data[4]) {
-                    addMediaLogEntry(time(), $data[2], DOKU_CHANGE_TYPE_EDIT);
-                } else {
-                    addMediaLogEntry(time(), $data[2], DOKU_CHANGE_TYPE_CREATE);
-                }
-                return $data[2];
-            } else {
-                return new IXR_ERROR(1, 'Upload failed.');
-            }
         } else {
-            return new IXR_ERROR(1, 'Upload failed.');
+            return new IXR_ERROR(1, 'Could not delete file');
         }
     }
 
@@ -570,6 +623,7 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
     * Returns the permissions of a given wiki page
     */
     function aclCheck($id) {
+        $id = cleanID($id);
         return auth_quickaclcheck($id);
     }
 
@@ -579,13 +633,14 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
      * @author Michael Klier <chi@chimeric.de>
      */
     function listLinks($id) {
+        $id = cleanID($id);
         if(auth_quickaclcheck($id) < AUTH_READ){
             return new IXR_Error(1, 'You are not allowed to read this page');
         }
         $links = array();
 
         // resolve page instructions
-        $ins   = p_cached_instructions(wikiFN(cleanID($id)));
+        $ins   = p_cached_instructions(wikiFN($id));
 
         // instantiate new Renderer - needed for interwiki links
         include(DOKU_INC.'inc/parser/xhtml.php');
@@ -607,7 +662,7 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
                     $link['page'] = $in[1][0];
                     $link['href'] = $in[1][0];
                     array_push($links,$link);
-                    break;    
+                    break;
                 case 'interwikilink':
                     $url = $Renderer->_resolveInterWiki($in[1][2],$in[1][3]);
                     $link['type'] = 'extern';
@@ -631,9 +686,6 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
         if(strlen($timestamp) != 10)
             return new IXR_Error(20, 'The provided value is not a valid timestamp');
 
-        require_once(DOKU_INC.'inc/changelog.php');
-        require_once(DOKU_INC.'inc/pageutils.php');
-
         $recents = getRecentsSince($timestamp);
 
         $changes = array();
@@ -654,7 +706,7 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
         } else {
             // in case we still have nothing at this point
             return new IXR_Error(30, 'There are no changes in the specified timeframe');
-        } 
+        }
     }
 
     /**
@@ -667,9 +719,6 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
         if(strlen($timestamp) != 10)
             return new IXR_Error(20, 'The provided value is not a valid timestamp');
 
-        require_once(DOKU_INC.'inc/changelog.php');
-        require_once(DOKU_INC.'inc/pageutils.php');
-
         $recents = getRecentsSince($timestamp, null, '', RECENTS_MEDIA_CHANGES);
 
         $changes = array();
@@ -681,7 +730,7 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
             $change['author']       = $recent['user'];
             $change['version']      = $recent['date'];
             $change['perms']        = $recent['perms'];
-            $change['size']         = @filesize(wikiFN($recent['id']));
+            $change['size']         = @filesize(mediaFN($recent['id']));
             array_push($changes, $change);
         }
 
@@ -690,7 +739,7 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
         } else {
             // in case we still have nothing at this point
             return new IXR_Error(30, 'There are no changes in the specified timeframe');
-        } 
+        }
     }
 
     /**
@@ -699,6 +748,10 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
      * @author Michael Klier <chi@chimeric.de>
      */
     function pageVersions($id, $first) {
+        $id = cleanID($id);
+        if(auth_quickaclcheck($id) < AUTH_READ){
+            return new IXR_Error(1, 'You are not allowed to read this page');
+        }
         global $conf;
 
         $versions = array();
@@ -706,8 +759,6 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
         if(empty($id))
             return new IXR_Error(1, 'Empty page ID');
 
-        require_once(DOKU_INC.'inc/changelog.php');
-
         $revisions = getRevisions($id, $first, $conf['recent']+1);
 
         if(count($revisions)==0 && $first!=0) {
@@ -748,7 +799,7 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
             }
             return $versions;
         } else {
-            return array(); 
+            return array();
         }
     }
 
@@ -758,8 +809,80 @@ class dokuwiki_xmlrpc_server extends IXR_IntrospectionServer {
     function wiki_RPCVersion(){
         return 2;
     }
+
+
+    /**
+     * Locks or unlocks a given batch of pages
+     *
+     * Give an associative array with two keys: lock and unlock. Both should contain a
+     * list of pages to lock or unlock
+     *
+     * Returns an associative array with the keys locked, lockfail, unlocked and
+     * unlockfail, each containing lists of pages.
+     */
+    function setLocks($set){
+        $locked     = array();
+        $lockfail   = array();
+        $unlocked   = array();
+        $unlockfail = array();
+
+        foreach((array) $set['lock'] as $id){
+            $id = cleanID($id);
+            if(auth_quickaclcheck($id) < AUTH_EDIT || checklock($id)){
+                $lockfail[] = $id;
+            }else{
+                lock($id);
+                $locked[] = $id;
+            }
+        }
+
+        foreach((array) $set['unlock'] as $id){
+            $id = cleanID($id);
+            if(auth_quickaclcheck($id) < AUTH_EDIT || !unlock($id)){
+                $unlockfail[] = $id;
+            }else{
+                $unlocked[] = $id;
+            }
+        }
+
+        return array(
+            'locked'     => $locked,
+            'lockfail'   => $lockfail,
+            'unlocked'   => $unlocked,
+            'unlockfail' => $unlockfail,
+        );
+    }
+
+    function getAPIVersion(){
+        return DOKU_XMLRPC_API_VERSION;
+    }
+
+    function login($user,$pass){
+        global $conf;
+        global $auth;
+        if(!$conf['useacl']) return 0;
+        if(!$auth) return 0;
+
+        @session_start(); // reopen session for login
+        if($auth->canDo('external')){
+            $ok = $auth->trustExternal($user,$pass,false);
+        }else{
+            $evdata = array(
+                'user'     => $user,
+                'password' => $pass,
+                'sticky'   => false,
+                'silent'   => true,
+            );
+            $ok = trigger_event('AUTH_LOGIN_CHECK', $evdata, 'auth_login_wrapper');
+        }
+        session_write_close(); // we're done with the session
+
+        return $ok;
+    }
+
+
 }
 
 $server = new dokuwiki_xmlrpc_server();
 
-// vim:ts=4:sw=4:et:enc=utf-8:
+// vim:ts=4:sw=4:et:
