@@ -10,9 +10,6 @@
 // must be run within Dokuwiki
 if(!defined('DOKU_INC')) die();
 
-if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
-require_once(DOKU_PLUGIN.'admin.php');
-
 /**
  * All DokuWiki plugins to extend the admin function
  * need to inherit from this class
@@ -20,24 +17,19 @@ require_once(DOKU_PLUGIN.'admin.php');
 class admin_plugin_acl extends DokuWiki_Admin_Plugin {
     var $acl = null;
     var $ns  = null;
+    /**
+     * The currently selected item, associative array with id and type.
+     * Populated from (in this order):
+     * $_REQUEST['current_ns']
+     * $_REQUEST['current_id']
+     * $ns
+     * $ID
+     */
+    var $current_item = null;
     var $who = '';
     var $usersgroups = array();
     var $specials = array();
 
-    /**
-     * return some info
-     */
-    function getInfo(){
-        return array(
-            'author' => 'Andreas Gohr',
-            'email'  => 'andi@splitbrain.org',
-            'date'   => '2008-12-16',
-            'name'   => 'ACL',
-            'desc'   => 'Manage Page Access Control Lists',
-            'url'    => 'http://dokuwiki.org/plugin:acl',
-        );
-    }
-
     /**
      * return prompt for admin menu
      */
@@ -62,9 +54,12 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
     function handle() {
         global $AUTH_ACL;
         global $ID;
+        global $auth;
+        global $config_cascade;
 
         // fresh 1:1 copy without replacements
-        $AUTH_ACL = file(DOKU_CONF.'acl.auth.php');
+        $AUTH_ACL = file($config_cascade['acl']['default']);
+
 
         // namespace given?
         if($_REQUEST['ns'] == '*'){
@@ -73,12 +68,25 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
             $this->ns = cleanID($_REQUEST['ns']);
         }
 
+        if ($_REQUEST['current_ns']) {
+            $this->current_item = array('id' => cleanID($_REQUEST['current_ns']), 'type' => 'd');
+        } elseif ($_REQUEST['current_id']) {
+            $this->current_item = array('id' => cleanID($_REQUEST['current_id']), 'type' => 'f');
+        } elseif ($this->ns) {
+            $this->current_item = array('id' => $this->ns, 'type' => 'd');
+        } else {
+            $this->current_item = array('id' => $ID, 'type' => 'f');
+        }
+
         // user or group choosen?
         $who = trim($_REQUEST['acl_w']);
         if($_REQUEST['acl_t'] == '__g__' && $who){
-            $this->who = '@'.ltrim($who,'@');
+            $this->who = '@'.ltrim($auth->cleanGroup($who),'@');
         }elseif($_REQUEST['acl_t'] == '__u__' && $who){
             $this->who = ltrim($who,'@');
+            if($this->who != '%USER%'){ #keep wildcard as is
+                $this->who = $auth->cleanUser($this->who);
+            }
         }elseif($_REQUEST['acl_t'] &&
                 $_REQUEST['acl_t'] != '__u__' &&
                 $_REQUEST['acl_t'] != '__g__'){
@@ -88,7 +96,8 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         }
 
         // handle modifications
-        if(isset($_REQUEST['cmd'])){
+        if(isset($_REQUEST['cmd']) && checkSecurityToken()){
+
             // scope for modifications
             if($this->ns){
                 if($this->ns == '*'){
@@ -127,16 +136,23 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
                 // re-add all rules
                 foreach((array) $_REQUEST['acl'] as $where => $opt){
                     foreach($opt as $who => $perm){
+                        if ($who[0]=='@') {
+                            if ($who!='@ALL') {
+                                $who = '@'.ltrim($auth->cleanGroup($who),'@');
+                            }
+                        } elseif ($who != '%USER%'){ #keep wildcard as is
+                            $who = $auth->cleanUser($who);
+                        }
                         $who = auth_nameencode($who,true);
                         $lines[] = "$where\t$who\t$perm\n";
                     }
                 }
                 // save it
-                io_saveFile(DOKU_CONF.'acl.auth.php', join('',$lines));
+                io_saveFile($config_cascade['acl']['default'], join('',$lines));
             }
 
             // reload ACL config
-            $AUTH_ACL = file(DOKU_CONF.'acl.auth.php');
+            $AUTH_ACL = file($config_cascade['acl']['default']);
         }
 
         // initialize ACL array
@@ -160,7 +176,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         echo '<div class="level1">'.NL;
 
         echo '<div id="acl__tree">'.NL;
-        $this->_html_explorer($_REQUEST['ns']);
+        $this->_html_explorer();
         echo '</div>'.NL;
 
         echo '<div id="acl__detail">'.NL;
@@ -206,7 +222,6 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
      * @author Andreas Gohr <andi@splitbrain.org>
      */
     function _html_explorer(){
-        require_once(DOKU_INC.'inc/search.php');
         global $conf;
         global $ID;
         global $lang;
@@ -221,28 +236,85 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         }
         $ns  = utf8_encodeFN(str_replace(':','/',$ns));
 
-
-        $data = array();
-        search($data,$conf['datadir'],'search_index',array('ns' => $ns));
-
+        $data = $this->_get_tree($ns);
 
         // wrap a list with the root level around the other namespaces
-        $item = array( 'level' => 0, 'id' => '*', 'type' => 'd',
-                   'open' =>'true', 'label' => '['.$lang['mediaroot'].']');
+        array_unshift($data, array( 'level' => 0, 'id' => '*', 'type' => 'd',
+                   'open' =>'true', 'label' => '['.$lang['mediaroot'].']'));
 
-        echo '<ul class="acltree">';
-        echo $this->_html_li_acl($item);
-        echo '<div class="li">';
-        echo $this->_html_list_acl($item);
-        echo '</div>';
         echo html_buildlist($data,'acl',
                             array($this,'_html_list_acl'),
                             array($this,'_html_li_acl'));
-        echo '</li>';
-        echo '</ul>';
 
     }
 
+    /**
+     * get a combined list of media and page files
+     *
+     * @param string $folder an already converted filesystem folder of the current namespace
+     * @param string $limit  limit the search to this folder
+     */
+    function _get_tree($folder,$limit=''){
+        global $conf;
+
+        // read tree structure from pages and media
+        $data = array();
+        search($data,$conf['datadir'],'search_index',array('ns' => $folder),$limit);
+        $media = array();
+        search($media,$conf['mediadir'],'search_index',array('ns' => $folder, 'nofiles' => true),$limit);
+        $data = array_merge($data,$media);
+        unset($media);
+
+        // combine by sorting and removing duplicates
+        usort($data,array($this,'_tree_sort'));
+        $count = count($data);
+        if($count>0) for($i=1; $i<$count; $i++){
+            if($data[$i-1]['id'] == $data[$i]['id'] && $data[$i-1]['type'] == $data[$i]['type']) unset($data[$i]);
+        }
+        return $data;
+    }
+
+    /**
+     * usort callback
+     *
+     * Sorts the combined trees of media and page files
+     */
+    function _tree_sort($a,$b){
+        // handle the trivial cases first
+        if ($a['id'] == '') return -1;
+        if ($b['id'] == '') return 1;
+        // split up the id into parts
+        $a_ids = explode(':', $a['id']);
+        $b_ids = explode(':', $b['id']);
+        // now loop through the parts
+        while (count($a_ids) && count($b_ids)) {
+            // compare each level from upper to lower
+            // until a non-equal component is found
+            $cur_result = strcmp(array_shift($a_ids), array_shift($b_ids));
+            if ($cur_result) {
+                // if one of the components is the last component and is a file
+                // and the other one is either of a deeper level or a directory,
+                // the file has to come after the deeper level or directory
+                if (empty($a_ids) && $a['type'] == 'f' && (count($b_ids) || $b['type'] == 'd')) return 1;
+                if (empty($b_ids) && $b['type'] == 'f' && (count($a_ids) || $a['type'] == 'd')) return -1;
+                return $cur_result;
+            }
+        }
+        // The two ids seem to be equal. One of them might however refer
+        // to a page, one to a namespace, the namespace needs to be first.
+        if (empty($a_ids) && empty($b_ids)) {
+            if ($a['type'] == $b['type']) return 0;
+            if ($a['type'] == 'f') return 1;
+            return -1;
+        }
+        // Now the empty part is either a page in the parent namespace
+        // that obviously needs to be after the namespace
+        // Or it is the namespace that contains the other part and should be
+        // before that other part.
+        if (empty($a_ids)) return ($a['type'] == 'd') ? -1 : 1;
+        if (empty($b_ids)) return ($b['type'] == 'd') ? 1 : -1;
+    }
+
     /**
      * Display the current ACL for selected where/who combination with
      * selectors and modification form
@@ -270,6 +342,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         echo '<input type="hidden" name="id" value="'.hsc($ID).'" />'.NL;
         echo '<input type="hidden" name="do" value="admin" />'.NL;
         echo '<input type="hidden" name="page" value="acl" />'.NL;
+        echo '<input type="hidden" name="sectok" value="'.getSecurityToken().'" />'.NL;
         echo '</div></form>'.NL;
     }
 
@@ -355,7 +428,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
             $user   = '';
             $groups = array(ltrim($who,'@'));
         }else{
-            $user = auth_nameencode($who);
+            $user = $who;
             $info = $auth->getUserData($user);
             if($info === false){
                 $groups = array();
@@ -427,8 +500,8 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         }
 
         // highlight?
-        if( ($item['type']=='d' && $item['id'] == $this->ns) ||
-            ($item['type']!='d' && $item['id'] == $ID)) $cl = ' cur';
+        if( ($item['type']== $this->current_item['type'] && $item['id'] == $this->current_item['id']))
+            $cl = ' cur';
 
         // namespace or page?
         if($item['type']=='d'){
@@ -440,11 +513,11 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
                 $alt   = '+';
             }
             $ret .= '<img src="'.$img.'" alt="'.$alt.'" />';
-            $ret .= '<a href="'.wl('',$this->_get_opts(array('ns'=>$item['id']))).'" class="idx_dir'.$cl.'">';
+            $ret .= '<a href="'.wl('',$this->_get_opts(array('ns'=>$item['id'],'sectok'=>getSecurityToken()))).'" class="idx_dir'.$cl.'">';
             $ret .= $base;
             $ret .= '</a>';
         }else{
-            $ret .= '<a href="'.wl('',$this->_get_opts(array('id'=>$item['id'],'ns'=>''))).'" class="wikilink1'.$cl.'">';
+            $ret .= '<a href="'.wl('',$this->_get_opts(array('id'=>$item['id'],'ns'=>'','sectok'=>getSecurityToken()))).'" class="wikilink1'.$cl.'">';
             $ret .= noNS($item['id']);
             $ret .= '</a>';
         }
@@ -453,7 +526,8 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
 
 
     function _html_li_acl($item){
-            return '<li class="level'.$item['level'].'">';
+        return '<li class="level' . $item['level'] . ' ' .
+               ($item['open'] ? 'open' : 'closed') . '">';
     }
 
 
@@ -522,6 +596,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         echo '<input type="hidden" name="acl_w" value="'.hsc($this->who).'" />'.NL;
         echo '<input type="hidden" name="do" value="admin" />'.NL;
         echo '<input type="hidden" name="page" value="acl" />'.NL;
+        echo '<input type="hidden" name="sectok" value="'.getSecurityToken().'" />'.NL;
         echo '<table class="inline">';
         echo '<tr>';
         echo '<th>'.$this->getLang('where').'</th>';
@@ -602,7 +677,8 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
      * @author  Frank Schubert <frank@schokilade.de>
      */
     function _acl_add($acl_scope, $acl_user, $acl_level){
-        $acl_config = file_get_contents(DOKU_CONF.'acl.auth.php');
+        global $config_cascade;
+        $acl_config = file_get_contents($config_cascade['acl']['default']);
         $acl_user = auth_nameencode($acl_user,true);
 
         // max level for pagenames is edit
@@ -615,7 +691,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
 
         $new_config = $acl_config.$new_acl;
 
-        return io_saveFile(DOKU_CONF.'acl.auth.php', $new_config);
+        return io_saveFile($config_cascade['acl']['default'], $new_config);
     }
 
     /**
@@ -624,7 +700,8 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
      * @author  Frank Schubert <frank@schokilade.de>
      */
     function _acl_del($acl_scope, $acl_user){
-        $acl_config = file(DOKU_CONF.'acl.auth.php');
+        global $config_cascade;
+        $acl_config = file($config_cascade['acl']['default']);
         $acl_user = auth_nameencode($acl_user,true);
 
         $acl_pattern = '^'.preg_quote($acl_scope,'/').'\s+'.$acl_user.'\s+[0-8].*$';
@@ -632,7 +709,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         // save all non!-matching
         $new_config = preg_grep("/$acl_pattern/", $acl_config, PREG_GREP_INVERT);
 
-        return io_saveFile(DOKU_CONF.'acl.auth.php', join('',$new_config));
+        return io_saveFile($config_cascade['acl']['default'], join('',$new_config));
     }
 
     /**
@@ -668,7 +745,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
 
             //build code
             $ret .= '<label for="pbox'.$label.'" title="'.$this->getLang('acl_perm'.$perm).'"'.$class.'>';
-            $ret .= '<input '.html_attbuild($atts).' />&nbsp;';
+            $ret .= '<input '.buildAttributes($atts).' />&nbsp;';
             $ret .= $this->getLang('acl_perm'.$perm);
             $ret .= '</label>'.NL;
         }
@@ -703,38 +780,42 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         echo '<select name="acl_t" class="edit">'.NL;
         echo '  <option value="__g__" class="aclgroup"'.$gsel.'>'.$this->getLang('acl_group').':</option>'.NL;
         echo '  <option value="__u__"  class="acluser"'.$usel.'>'.$this->getLang('acl_user').':</option>'.NL;
-        echo '  <optgroup label="&nbsp;">'.NL;
-        foreach($this->specials as $ug){
-            if($ug == $this->who){
-                $sel    = ' selected="selected"';
-                $inlist = true;
-            }else{
-                $sel = '';
-            }
+        if (!empty($this->specials)) {
+            echo '  <optgroup label="&nbsp;">'.NL;
+            foreach($this->specials as $ug){
+                if($ug == $this->who){
+                    $sel    = ' selected="selected"';
+                    $inlist = true;
+                }else{
+                    $sel = '';
+                }
 
-            if($ug{0} == '@'){
-                    echo '  <option value="'.hsc($ug).'" class="aclgroup"'.$sel.'>'.hsc($ug).'</option>'.NL;
-            }else{
-                    echo '  <option value="'.hsc($ug).'" class="acluser"'.$sel.'>'.hsc($ug).'</option>'.NL;
+                if($ug{0} == '@'){
+                        echo '  <option value="'.hsc($ug).'" class="aclgroup"'.$sel.'>'.hsc($ug).'</option>'.NL;
+                }else{
+                        echo '  <option value="'.hsc($ug).'" class="acluser"'.$sel.'>'.hsc($ug).'</option>'.NL;
+                }
             }
+            echo '  </optgroup>'.NL;
         }
-        echo '  </optgroup>'.NL;
-        echo '  <optgroup label="&nbsp;">'.NL;
-        foreach($this->usersgroups as $ug){
-            if($ug == $this->who){
-                $sel    = ' selected="selected"';
-                $inlist = true;
-            }else{
-                $sel = '';
-            }
+        if (!empty($this->usersgroups)) {
+            echo '  <optgroup label="&nbsp;">'.NL;
+            foreach($this->usersgroups as $ug){
+                if($ug == $this->who){
+                    $sel    = ' selected="selected"';
+                    $inlist = true;
+                }else{
+                    $sel = '';
+                }
 
-            if($ug{0} == '@'){
-                    echo '  <option value="'.hsc($ug).'" class="aclgroup"'.$sel.'>'.hsc($ug).'</option>'.NL;
-            }else{
-                    echo '  <option value="'.hsc($ug).'" class="acluser"'.$sel.'>'.hsc($ug).'</option>'.NL;
+                if($ug{0} == '@'){
+                        echo '  <option value="'.hsc($ug).'" class="aclgroup"'.$sel.'>'.hsc($ug).'</option>'.NL;
+                }else{
+                        echo '  <option value="'.hsc($ug).'" class="acluser"'.$sel.'>'.hsc($ug).'</option>'.NL;
+                }
             }
+            echo '  </optgroup>'.NL;
         }
-        echo '  </optgroup>'.NL;
         echo '</select>'.NL;
         return $inlist;
     }
