@@ -11,6 +11,13 @@
  * @author Rune M. Andersen <rune.andersen@gmail.com>
  * @author Jakob Vad Nielsen (me@jakobnielsen.net)
  * @author Kjell Tore Næsgaard  <kjell.t.nasgaard@ntnu.no>
+ * @author Knut Staring <knutst@gmail.com>
+ * @author Lisa Ditlefsen <lisa@vervesearch.com>
+ * @author Erik Pedersen <erik.pedersen@shaw.ca>
+ * @author Erik Bjørn Pedersen <erik.pedersen@shaw.ca>
+ * @author Rune Rasmussen syntaxerror.no@gmail.com
+ * @author Jon Bøe <jonmagneboe@hotmail.com>
+ * @author Egil Hansen <egil@rosetta.no>
  */
 $lang['admin_acl']             = 'Administrasjon av lister for adgangskontroll (ACL)';
 $lang['acl_group']             = 'Gruppe';
@@ -27,15 +34,16 @@ $lang['p_choose_id']           = '<b>Før inn en bruker eller gruppe</b> i skjem
 $lang['p_choose_ns']           = '<b>Før inn en bruker eller gruppe</b> i skjemaet over for å vise eller redigere tillatelser satt for navnerommet <b class="aclns">%s</b>.';
 $lang['p_inherited']           = 'Merk: Disse tillatelser ble ikke eksplisitt satt, men ble arvet fra andre grupper eller høyere navnerom.';
 $lang['p_isadmin']             = 'Merk: Den valgte gruppen eller bruker har altid fulle tillatelser fordi vedkommende er konfigurert som superbruker.';
-$lang['current']               = 'Någjeldende ACL-regler';
+$lang['p_include']             = 'Høyere tillgangsrettigheter inkluderer lavere. Rettigheter for å opprette, laste opp og slette gjelder bare  for navnerom, ikke enkeltsider.';
+$lang['current']               = 'Gjeldende ACL-regler';
 $lang['where']                 = 'Side/Navnerom';
 $lang['who']                   = 'Bruker/Gruppe';
-$lang['perm']                  = 'Tillatelser';
+$lang['perm']                  = 'Rettigheter';
 $lang['acl_perm0']             = 'Ingen';
 $lang['acl_perm1']             = 'Lese';
 $lang['acl_perm2']             = 'Redigere';
-$lang['acl_perm4']             = 'Lage';
+$lang['acl_perm4']             = 'Opprette';
 $lang['acl_perm8']             = 'Laste opp';
 $lang['acl_perm16']            = 'Slette';
 $lang['acl_new']               = 'Legg til ny oppføring';
-$lang['acl_mod']               = 'Modifiser oppføring';
+$lang['acl_mod']               = 'Endre oppføring';
