@@ -22,7 +22,7 @@ $lang['_header_plugin']        = 'Настройки на приставки';
 $lang['_header_template']      = 'Настройки на шаблони';
 $lang['_header_undefined']     = 'Неопределени настройки';
 $lang['_basic']                = 'Основни настройки';
-$lang['_display']              = 'Настройки на показването';
+$lang['_display']              = 'Настройки за изобразяване';
 $lang['_authentication']       = 'Настройки за удостоверяване';
 $lang['_anti_spam']            = 'Настройки за борба със SPAM-ма';
 $lang['_editing']              = 'Настройки за редактиране';
@@ -30,8 +30,8 @@ $lang['_links']                = 'Настройки на препратките
 $lang['_media']                = 'Настройки на медията';
 $lang['_advanced']             = 'Допълнителни настройки';
 $lang['_network']              = 'Мрежови настройки';
-$lang['_plugin_sufix']         = 'Настройки на приставки';
-$lang['_template_sufix']       = 'Настройки на шаблони';
+$lang['_plugin_sufix']         = ' - настройки на приставката';
+$lang['_template_sufix']       = ' - настройки на шаблона';
 $lang['_msg_setting_undefined'] = 'Няма метаданни за настройките.';
 $lang['_msg_setting_no_class'] = 'Няма клас настройки.';
 $lang['_msg_setting_no_default'] = 'Няма стандартна стойност.';
@@ -41,6 +41,7 @@ $lang['lang']                  = 'Език';
 $lang['basedir']               = 'Главна директория (напр. <code>/dokuwiki/</code>). Оставете празно, за да бъде засечена автоматично.';
 $lang['baseurl']               = 'URL адрес (напр. <code>http://www.yourserver.com</code>). Оставете празно, за да бъде засечен автоматично.';
 $lang['savedir']               = 'Директория за записване на данните';
+$lang['cookiedir']             = 'Път за бисквитките. Оставите ли полето празно ще се ползва горния URL адрес.';
 $lang['start']                 = 'Име на началната страница';
 $lang['title']                 = 'Име на Wiki-то';
 $lang['template']              = 'Шаблон';
@@ -49,38 +50,39 @@ $lang['fullpath']              = 'Показване на пълния път д
 $lang['recent']                = 'Скорошни промени';
 $lang['breadcrumbs']           = 'Брой на следите';
 $lang['youarehere']            = 'Йерархични следи';
-$lang['typography']            = 'Поправяне на разместени букви';
+$lang['typography']            = 'Замяна на последователност от символи с типографски еквивалент';
 $lang['htmlok']                = 'Разрешаване вграждането на HTML код';
 $lang['phpok']                 = 'Разрешаване вграждането на PHP код';
 $lang['dformat']               = 'Формат на датата (виж. <a href="http://www.php.net/strftime">strftime</a> функцията на PHP)';
 $lang['signature']             = 'Подпис';
-$lang['toptoclevel']           = 'Главно ниво за съдържанието';
-$lang['tocminheads']           = 'Минимален брой заглавия, определящ дали съдържанието е създадено';
-$lang['maxtoclevel']           = 'Максимално ниво на съдържанието';
-$lang['maxseclevel']           = 'Максимално ниво за редактиране на секция';
+$lang['toptoclevel']           = 'Главно ниво (заглавие) за съдържанието';
+$lang['tocminheads']           = 'Минимален брой заглавия, определящ дали да бъде създадено съдържание';
+$lang['maxtoclevel']           = 'Максимален брой нива (заглавия) за включване в съдържанието';
+$lang['maxseclevel']           = 'Максимален брой нива предоставяни за самостоятелно редактиране';
 $lang['camelcase']             = 'Ползване на CamelCase за линкове';
 $lang['deaccent']              = 'Почистване имената на страниците (на файловете)';
 $lang['useheading']            = 'Ползване на първото заглавие за име на страница';
-$lang['refcheck']              = 'Проверка за препратка на медия';
+$lang['refcheck']              = 'Проверка за препратка към медия, преди да бъде изтрита';
 $lang['refshow']               = 'Брой на показваните медийни препратки';
-$lang['allowdebug']            = 'Включване на debug <b>изключете, ако не е нужен!</b>';
+$lang['allowdebug']            = 'Включване на режи debug - <b>изключете, ако не е нужен!</b>';
+$lang['mediarevisions']        = 'Да се пазят ли стари версии на качените файлове (Mediarevisions)?';
 $lang['usewordblock']          = 'Блокиране на SPAM въз основа на на списък от думи';
 $lang['indexdelay']            = 'Забавяне преди индексиране (сек)';
 $lang['relnofollow']           = 'Ползване на rel="nofollow" за външни препратки';
 $lang['mailguard']             = 'Промяна на адресите на ел. поща (във форма непозволяваща пращането на SPAM)';
-$lang['iexssprotect']          = 'Проверяване на качените файлове за възможно зловреден JavaScript и HTML код';
+$lang['iexssprotect']          = 'Проверяване на качените файлове за вероятен зловреден JavaScript и HTML код';
 $lang['showuseras']            = 'Какво да се показва за потребителя, който последно е променил страницата';
 $lang['useacl']                = 'Ползване на списъци за достъп';
-$lang['autopasswd']            = 'Автоматично генериране на пароли';
+$lang['autopasswd']            = 'Автоматично генериране на пароли, на нови потребители и пращане по пощата';
 $lang['authtype']              = 'Метод за удостоверяване';
 $lang['passcrypt']             = 'Метод за криптиране на паролите';
 $lang['defaultgroup']          = 'Стандартна група';
-$lang['superuser']             = 'Супер потребител - група или потребител с пълен достъп до всички страници и функции без значение от настройките на списъците за достъп (ACL)';
-$lang['manager']               = 'Управител - група или потребител, с достъп до определени управляващи фунции ';
+$lang['superuser']             = 'Супер потребител -  група, потребител или списък със стойности разделени чрез запетая (user1,@group1,user2) с пълен достъп до всички страници и функции без значение от настройките на списъците за достъп (ACL)';
+$lang['manager']               = 'Управител - група, потребител или списък със стойности разделени чрез запетая (user1,@group1,user2) с достъп до определени управленски функции ';
 $lang['profileconfirm']        = 'Потвърждаване на промени в профила с парола';
-$lang['disableactions']        = 'Изключване на DokuWiki функции';
+$lang['disableactions']        = 'Изключване функции на DokuWiki';
 $lang['disableactions_check']  = 'Проверка';
-$lang['disableactions_subscription'] = 'Записване/Отписване';
+$lang['disableactions_subscription'] = 'Абониране/Отписване';
 $lang['disableactions_wikicode'] = 'Преглед на кода/Експортиране на оригинална версия';
 $lang['disableactions_other']  = 'Други действия (разделени със запетая)';
 $lang['sneaky_index']          = 'Стандартно DokuWiki ще показва всички именни пространства в индекса. Опцията скрива тези, за които потребителят няма права за четене. Това може да доведе и до скриване на иначе достъпни подименни пространства. С определени настройки на списъците за контрол на достъпа (ACL) може да направи индекса неизползваем. ';
@@ -94,24 +96,25 @@ $lang['userewrite']            = 'Ползване на nice URL адреси';
 $lang['useslash']              = 'Ползване на наклонена черта за разделител на именните пространства в URL';
 $lang['usedraft']              = 'Автоматично запазване на чернова по време на редактиране';
 $lang['sepchar']               = 'Разделител между думите в имената на страници';
-$lang['canonical']             = 'Ползване на напълно уеднаквени URL адреси';
+$lang['canonical']             = 'Ползване на напълно уеднаквени URL адреси (абсолютни адреси - http://server/path)';
 $lang['fnencode']              = 'Метод за кодиране на не-ASCII именуваните файлове.';
 $lang['autoplural']            = 'Проверяване за множествено число в препратките';
 $lang['compression']           = 'Метод за компресия на attic файлове';
 $lang['cachetime']             = 'Макс. период за съхраняване на кеша (сек)';
 $lang['locktime']              = 'Макс. период за съхраняване на заключените файлове (сек)';
 $lang['fetchsize']             = 'Максимален размер (байтове), който fetch.php може да сваля';
-$lang['notify']                = 'Пращане на съобщения за промени на тази eл. поща';
-$lang['registernotify']        = 'Пращане информация за нови потребители на тази ел. поща';
+$lang['notify']                = 'Пращане на съобщения за промени по страниците на следната eл. поща';
+$lang['registernotify']        = 'Пращане на информация за нови потребители на следната ел. поща';
 $lang['mailfrom']              = 'Ел. поща, която да се ползва за автоматично изпращане на ел. писма';
 $lang['mailprefix']            = 'Представка за темите (поле subject) на автоматично изпращаните ел. писма';
 $lang['gzip_output']           = 'Кодиране на съдържанието с gzip за xhtml';
 $lang['gdlib']                 = 'Версия на GD Lib';
 $lang['im_convert']            = 'Път до инструмента за трансформация на ImageMagick';
-$lang['jpg_quality']           = 'Kачество на JPG компресията (0-100)';
+$lang['jpg_quality']           = 'Качество на JPG компресията (0-100)';
 $lang['subscribers']           = 'Включване на поддръжката за абониране към страници';
 $lang['subscribe_time']        = 'Време след което абонаментните списъци и обобщения се изпращат (сек); Трябва да е по-малко от времето определено в recent_days.';
 $lang['compress']              = 'Компактен CSS и javascript изглед';
+$lang['cssdatauri']            = 'Максимален размер, в байтове, до който изображенията посочени в .CSS файл ще бъдат вграждани в стила (stylesheet), за да се намали броя на HTTP заявките. Техниката не работи за версиите на IE преди 8! Препоръчителни стойности: <code>400</code> до <code>600</code> байта. Въведете <code>0</code> за изключване.';
 $lang['hidepages']             = 'Скриване на съвпадащите страници (regular expressions)';
 $lang['send404']               = 'Пращане на "HTTP 404/Page Not Found" за несъществуващи страници';
 $lang['sitemap']               = 'Генериране на Google sitemap (дни)';
@@ -120,7 +123,7 @@ $lang['xsendfile']             = 'Ползване на Х-Sendfile header, за
 $lang['renderer_xhtml']        = 'Представяне на основните изходни данни (xhtml) от wiki-то с';
 $lang['renderer__core']        = '%s (ядрото на DokuWiki)';
 $lang['renderer__plugin']      = '%s (приставка)';
-$lang['rememberme']            = 'Ползване на постоянни бисквитки за вписване (запомни ме)';
+$lang['rememberme']            = 'Ползване на постоянни бисквитки за вписване (за функцията "Запомни ме")';
 $lang['rss_type']              = 'Тип на XML емисията';
 $lang['rss_linkto']            = 'XML емисията препраща към';
 $lang['rss_content']           = 'Какво да показват елементите на XML емисията?';
@@ -143,7 +146,7 @@ $lang['ftp____host']           = 'FTP сървър за хака safemode';
 $lang['ftp____port']           = 'FTP порт за хака safemode';
 $lang['ftp____user']           = 'FTP потребител за хака safemode';
 $lang['ftp____pass']           = 'FTP парола за хака safemode';
-$lang['ftp____root']           = 'FTP главна директория хака safemode';
+$lang['ftp____root']           = 'FTP главна директория за хака safemode';
 $lang['license_o_']            = 'Нищо не е избрано';
 $lang['typography_o_0']        = 'без';
 $lang['typography_o_1']        = 'с изключение на единични кавички';
@@ -179,8 +182,8 @@ $lang['xsendfile_o_2']         = 'Стандартен X-Sendfile header';
 $lang['xsendfile_o_3']         = 'Специфичен Nginx X-Accel-Redirect header за пренасочване';
 $lang['showuseras_o_loginname'] = 'Име за вписване';
 $lang['showuseras_o_username'] = 'Пълно потребителско име';
-$lang['showuseras_o_email']    = 'Ел, поща на потребителите (променени според настройките на mailguard)';
-$lang['showuseras_o_email_link'] = 'Ел. поща на потребителите под формата на mailto: връзки';
+$lang['showuseras_o_email']    = 'Ел, поща (променени според настройките на mailguard)';
+$lang['showuseras_o_email_link'] = 'Ел. поща под формата на връзка тип mailto:';
 $lang['useheading_o_0']        = 'Никога';
 $lang['useheading_o_navigation'] = 'Само за навигация';
 $lang['useheading_o_content']  = 'Само за съдържанието на Wiki-то';
