@@ -13,6 +13,9 @@ $lang['updated']               = 'सेटिंग अद्ययावत 
 $lang['nochoice']              = '( इतर काही पर्याय नाहीत )';
 $lang['locked']                = 'सेटिंगची फाइल अद्ययावत करू शकलो नाही. जर हे सहेतुक नसेल तर, <br />
 सेटिंग च्या फाइल चे नाव व त्यावरील परवानग्या बरोबर असल्याची खात्री करा.';
+$lang['danger']                = 'सावधान : हा पर्याय बदलल्यास तुमची विकी आणि तिचे कॉनफिगरेशन निकामी होऊ शकते.';
+$lang['warning']               = 'सावघान: येथील पर्याय बदल्यास, अनपेक्षीत गोष्टी होऊ शकतात.';
+$lang['security']              = 'सुरक्षा संबंधी सूचना : हा पर्याय बदलल्यास तुमची साईट असुरक्षित होऊ शकते.';
 $lang['_configuration_manager'] = 'कॉन्फिगरेशन व्यवस्थापक';
 $lang['_header_dokuwiki']      = 'डॉक्युविकि सेटिंग';
 $lang['_header_plugin']        = 'प्लगिन सेटिंग';
@@ -46,11 +49,13 @@ $lang['fullpath']              = 'पानांचा पूर्ण पत
 $lang['recent']                = 'अलीकडील बदल';
 $lang['breadcrumbs']           = 'ब्रेडक्रम्बची संख्या';
 $lang['youarehere']            = 'प्रतवार ब्रेडक्रम्ब';
+$lang['typography']            = 'अनवधानाने झालेल्या चुका बदला';
 $lang['htmlok']                = 'अंतर्गत HTML टाकायची परवानगी असू दे';
 $lang['phpok']                 = 'अंतर्गत PHP टाकायची परवानगी असू दे';
 $lang['dformat']               = 'दिनांकाची पद्धत ( PHP चं <a href="http://www.php.net/strftime">strftime</a> हे फंक्शन पाहा )';
 $lang['signature']             = 'हस्ताक्षर';
 $lang['toptoclevel']           = 'अनुक्रमणिकेची सर्वोच्च पातळी';
+$lang['tocminheads']           = 'कमीत कमी किती शीर्षके असल्यास अनुक्रमणिका बनवावी';
 $lang['maxtoclevel']           = 'अनुक्रमणिकेची जास्तीत जास्त पातळी  ';
 $lang['maxseclevel']           = 'विभागीय संपादनाची जास्तीतजास्त पातळी';
 $lang['camelcase']             = 'लिंकसाठी कॅमलकेस वापरा.';
@@ -76,13 +81,14 @@ $lang['profileconfirm']        = 'प्रोफाइल मधील बद
 $lang['disableactions']        = 'डॉक्युविकीच्या क्रिया बंद ठेवा';
 $lang['disableactions_check']  = 'तपासा';
 $lang['disableactions_subscription'] = 'सब्सक्राईब / अन्-सब्सक्राईब';
-$lang['disableactions_nssubscription'] = 'नेमस्पेस सब्सक्राईब / अन्-सब्सक्राईब';
 $lang['disableactions_wikicode'] = 'स्त्रोत पहा / कच्च्या स्वरूपात एक्सपोर्ट करा';
 $lang['disableactions_other']  = 'इतर क्रिया ( स्वल्पविरामाने अलग केलेल्या )';
 $lang['sneaky_index']          = 'सूची दृश्यामधे डिफॉल्ट स्वरूपात डॉक्युविकी सगळे नेमस्पेस दाखवते. हा पर्याय चालू केल्यास सदस्याला वाचण्याची परवानगी नसलेले नेमस्पेस दिसणार नाहीत. यामुळे परवानगी असलेले उप - नेमस्पेस न दिसण्याची शक्यता आहे. यामुळे काही विशिष्ठ ACL सेटिंगसाठी सूची वापरता येण्यासारखी राहणार नाही.';
 $lang['auth_security_timeout'] = 'अधिकृत करण्याच्या प्रक्रियेची कालमर्यादा';
 $lang['securecookie']          = 'HTTPS वापरून सेट केलेले कूकीज ब्राउजरने HTTPS द्वाराच पाठवले पाहिजेत का? जर तुमच्या विकीचं फ़क्त लॉगिन पानच SSL वापरून सुरक्षित केलं असेल व पानांचं ब्राउजिंग असुरक्षित असेल तर हा पर्याय चालू करू नका.';
-$lang['updatecheck']           = 'अपडेट आणि सुरक्षिततेविशयी सूचनान्वर पाळत ठेऊ का? या सुविधेसाठी डॉक्युविकीला splitbrain.org शी संपर्क साधावा लागेल.';
+$lang['xmlrpc']                = 'XML-RPC इंटरफेस चालू/बंद करा';
+$lang['xmlrpcuser']            = 'XML-RPC सुविधा फ़क्त इथे स्वल्पविरामाने अलग करून दिलेल्या गट किंवा वापरकर्त्याला उपलब्ध आहेत. सर्वाना ही सुविधा देण्यासाठी ही जागा रिकामी सोडा.';
+$lang['updatecheck']           = 'अपडेट आणि सुरक्षिततेविशयी सूचनान्वर पाळत ठेऊ का? या सुविधेसाठी डॉक्युविकीला update.dokuwiki.org शी संपर्क साधावा लागेल.';
 $lang['userewrite']            = 'छान छान URL वापर';
 $lang['useslash']              = 'URL  मधे नेमस्पेस अलग करण्यासाठी \'/\' चिह्न वापरा';
 $lang['usedraft']              = 'संपादन करताना मसुदा आपोआप सुरक्षित करा';
@@ -107,7 +113,6 @@ $lang['send404']               = 'अस्तित्वात नसलेल
 $lang['sitemap']               = 'गूगल साईट-मॅप बनवा';
 $lang['broken_iua']            = 'ignore_user_abort फंक्शन तुमच्या सिस्टम वर चालत नाही का? यामुळे शोध सूची निकामी होऊ शकते. IIS + PHP/CGI वर हे काम करत नाही हे नक्की झाले आहे. अधिक माहितीसाठी <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">बग ८५२</a> पहा.';
 $lang['xsendfile']             = 'सर्वर कडून स्थिर फाइल पाठवली जाण्यासाठी X-Sendfile शीर्षक ( header ) वापरू का ? तुमच्या वेब सर्वर मधे ही सुविधा असली पाहिजे.';
-$lang['xmlrpc']                = 'XML-RPC इंटरफेस चालू/बंद करा';
 $lang['renderer_xhtml']        = 'मुख्य ( xhtml ) विकी आउट्पुट साथी वापरायचा चित्रक ( renderer )';
 $lang['renderer__core']        = '%s (डॉक्युविकीचा मूलभूत)';
 $lang['renderer__plugin']      = '%s (प्लगिन)';
@@ -146,6 +151,7 @@ $lang['deaccent_o_1']          = 'एक्सेंट काढून टा
 $lang['deaccent_o_2']          = 'रोमन लिपित बदला';
 $lang['gdlib_o_0']             = 'GD Lib  उपलब्ध नाही';
 $lang['gdlib_o_1']             = 'आवृत्ती १.x';
+$lang['gdlib_o_2']             = 'आपोआप ओळखा';
 $lang['rss_type_o_rss']        = 'RSS 0.91';
 $lang['rss_type_o_rss1']       = 'RSS 1.0';
 $lang['rss_type_o_rss2']       = 'RSS 2.0';
@@ -171,4 +177,6 @@ $lang['showuseras_o_username'] = 'सदस्याचे पूर्ण न
 $lang['showuseras_o_email']    = 'सदस्याचा ईमेल ( मेल सुरक्षिततेच्या सेटिंग अनुसार दुर्बोध केलेला ) ';
 $lang['showuseras_o_email_link'] = 'सदस्याचा ईमेल maito: लिंक   स्वरूपात';
 $lang['useheading_o_0']        = 'कधीच नाही';
+$lang['useheading_o_navigation'] = 'फ़क्त मार्गदर्शन';
+$lang['useheading_o_content']  = 'फ़क्त विकी मजकूर';
 $lang['useheading_o_1']        = 'नेहमी';
