@@ -37,9 +37,10 @@ $lang['_msg_setting_no_default'] = 'Žiadna predvolená hodnota.';
 $lang['fmode']                 = 'Spôsob vytvárania súborov';
 $lang['dmode']                 = 'Spôsob vytvárania adresárov';
 $lang['lang']                  = 'Jazyk';
-$lang['basedir']               = 'Základný adresár';
-$lang['baseurl']               = 'Základná URL';
+$lang['basedir']               = 'Hlavný adresár (napr. <code>/dokuwiki/</code>). Prázdna hodnota znamená použitie autodetekcie.';
+$lang['baseurl']               = 'Adresa servera (napr. <code>http://www.yourserver.com</code>). Prázdna hodnota znamená použitie autodetekcie.';
 $lang['savedir']               = 'Adresár pre ukladanie dát';
+$lang['cookiedir']             = 'Cesta k cookies. Prázdna hodnota znamená použitie adresy servera.';
 $lang['start']                 = 'Názov štartovacej stránky';
 $lang['title']                 = 'Názov wiki';
 $lang['template']              = 'Šablóna';
@@ -63,6 +64,7 @@ $lang['useheading']            = 'Použiť nadpis pre názov stránky';
 $lang['refcheck']              = 'Kontrolovať odkazy na médiá (pred vymazaním)';
 $lang['refshow']               = 'Počet zobrazených odkazov na médiá';
 $lang['allowdebug']            = 'Povoliť ladenie chýb <b>deaktivujte, ak nie je potrebné!</b>';
+$lang['mediarevisions']        = 'Povoliť verzie súborov?';
 $lang['usewordblock']          = 'Blokovať spam na základe zoznamu známych slov';
 $lang['indexdelay']            = 'Časové oneskorenie pred indexovaním (sek)';
 $lang['relnofollow']           = 'Používať rel="nofollow" pre externé odkazy';
@@ -110,6 +112,7 @@ $lang['jpg_quality']           = 'Kvalita JPG kompresie (0-100)';
 $lang['subscribers']           = 'Povoliť podporu informovania o zmenách stránky';
 $lang['subscribe_time']        = 'Časový inteval, po uplynutí ktorého sú zasielané informácie o zmenách stránky alebo menného priestoru (sek); hodnota by mala byť menšia ako čas zadaný pri položke recent_days.';
 $lang['compress']              = 'Komprimovať CSS a javascript výstup';
+$lang['cssdatauri']            = 'Veľkosť v bytoch, do ktorej by mali byť obrázky s odkazom v CSS vložené priamo do štýlu z dôvodu obmedzenia HTTP požiadaviek. Tento postup nefunguje v IE verzie 7 a nižšie! Vhodná hodnota je od <code>400</code> do <code>600</code> bytov. Hodnota <code>0</code> deaktivuje túto metódu.';
 $lang['hidepages']             = 'Skryť zodpovedajúce stránky (regulárne výrazy)';
 $lang['send404']               = 'Poslať "HTTP 404/Page Not Found" pre neexistujúce stránky';
 $lang['sitemap']               = 'Generovať Google sitemap (dni)';
