@@ -9,9 +9,10 @@
  * @author Erik Pedersen <erik.pedersen@shaw.ca>
  * @author Robert Bogenschneider <robog@GMX.de>
  * @author Robert BOGENSCHNEIDER <robog@gmx.de>
+ * @author Robert BOGENSCHNEIDER <bogi@UEA.org>
  */
 $lang['name']                  = 'Populareca enketo (eble la ŝargo prokrastos iomete)';
-$lang['submit']                = 'Sendi datenaron';
+$lang['submit']                = 'Sendi datumaron';
 $lang['autosubmit']            = 'Aŭtomate sendi datumaron monate';
 $lang['submissionFailed']      = 'La datumaro ne povis esti sendata pro la jena eraro:';
 $lang['submitDirectly']        = 'Vi povas sendi vi mem la datumaron per la sekva informilo.';
