@@ -6,8 +6,12 @@
  * @author Li-Jiun Huang <ljhuang.tw@gmail.com>
  * @author http://www.chinese-tools.com/tools/converter-simptrad.html
  * @author Wayne San <waynesan@zerozone.tw>
+ * @author Li-Jiun Huang <ljhuang.tw@gmai.com>
+ * @author Cheng-Wei Chien <e.cwchien@gmail.com>
+ * @author Danny Lin <danny0838@pchome.com.tw>
+ * @author Shuo-Ting Jian <shoting@gmail.com>
  */
-$lang['menu']                  = '帳號管理員(User Manager)';
+$lang['menu']                  = '帳號管理員';
 $lang['noauth']                = '(帳號認證尚未開放)';
 $lang['nosupport']             = '(尚不支援帳號管理)';
 $lang['badauth']               = '錯誤的認證機制';
@@ -26,25 +30,25 @@ $lang['edit_prompt']           = '修改該帳號';
 $lang['modify']                = '儲存變更';
 $lang['search']                = '搜尋';
 $lang['search_prompt']         = '開始搜尋';
-$lang['clear']                 = '重新設定搜尋的條件';
+$lang['clear']                 = '重設篩選條件';
 $lang['filter']                = '篩選條件(Filter)';
-$lang['summary']               = '顯示帳號 %1$d 至 %2$d 共 %3$d 筆符合. 總共有 %4$d 個帳號';
-$lang['nonefound']             = '找不到該用戶(共 %d 帳號)。';
+$lang['summary']               = '顯示帳號 %1$d-%2$d，共 %3$d 筆符合。共有 %4$d 個帳號。';
+$lang['nonefound']             = '找不到帳號。共有 %d 個帳號。';
 $lang['delete_ok']             = '已刪除 %d 個帳號';
 $lang['delete_fail']           = '%d 個帳號刪除失敗';
 $lang['update_ok']             = '成功更新該帳號';
 $lang['update_fail']           = '更新該帳號時失敗';
-$lang['update_exists']         = '變更帳號名稱 (%s) 時失敗，應該是已有同名的帳號，不過除了帳號名稱之外的其他修改仍會儲存。';
+$lang['update_exists']         = '變更帳號名稱 (%s) 失敗，因為有同名帳號存在（其他修改已套用）。';
 $lang['start']                 = '開始';
-$lang['prev']                  = '上一步';
-$lang['next']                  = '下一步';
-$lang['last']                  = '最後步驟';
-$lang['edit_usermissing']      = '找不到所選的帳號，該帳號可能已經被刪除或是改為其他名稱喔。';
+$lang['prev']                  = '上一頁';
+$lang['next']                  = '下一頁';
+$lang['last']                  = '最後一頁';
+$lang['edit_usermissing']      = '找不到選取的帳號，可能已被刪除或改為其他名稱。';
 $lang['user_notify']           = '通知使用者';
-$lang['note_notify']           = '通知信只有在給予使用者新密碼時寄送。';
+$lang['note_notify']           = '通知信只會在指定使用者新密碼時寄送。';
 $lang['note_group']            = '如果沒有指定群組，新使用者將會被加入到預設群組(%s)當中。';
 $lang['note_pass']             = '如果沒有輸入這個欄位而且有勾選通知使用者，則會自動產生一組密碼。';
 $lang['add_ok']                = '新增使用者成功';
 $lang['add_fail']              = '新增使用者失敗';
 $lang['notify_ok']             = '通知信已寄出';
-$lang['notify_fail']           = '通知信無法被寄出';
+$lang['notify_fail']           = '通知信無法寄出';
